@@ -1,3 +1,4 @@
+// SPDX-License-Identifier: LGPL-3.0-or-later
 /*
  * Copyright © 2012-2014, CohortFS, LLC.
  * Author: Adam C. Emerson <aemerson@linuxbox.com>
@@ -60,10 +61,8 @@ static bool initiate_recall(vinodeno_t vi, bool write, void *opaque)
 	struct ceph_handle *handle = (struct ceph_handle *)opaque;
 	/* Return code from upcall operation */
 	state_status_t status = STATE_SUCCESS;
-	struct gsh_buffdesc key = {
-		.addr = &handle->vi,
-		.len = sizeof(vinodeno_t)
-	};
+	struct gsh_buffdesc key = { .addr = &handle->vi,
+				    .len = sizeof(vinodeno_t) };
 	struct pnfs_segment segment = {
 		.offset = 0,
 		.length = UINT64_MAX,
@@ -93,8 +92,8 @@ static bool initiate_recall(vinodeno_t vi, bool write, void *opaque)
  * @return Valid error codes in RFC 5661, p. 365.
  */
 
-static nfsstat4 getdeviceinfo(struct fsal_export *export_pub,
-			      XDR *da_addr_body, const layouttype4 type,
+static nfsstat4 getdeviceinfo(struct fsal_export *export_pub, XDR *da_addr_body,
+			      const layouttype4 type,
 			      const struct pnfs_deviceid *deviceid)
 {
 	/* Full 'private' export */
@@ -142,21 +141,19 @@ static nfsstat4 getdeviceinfo(struct fsal_export *export_pub,
 
 	if (!inline_xdr_u_int32_t(da_addr_body, &stripes)) {
 		LogCrit(COMPONENT_PNFS,
-			"Failed to encode length of stripe_indices array: %"
-			PRIu32 ".", stripes);
+			"Failed to encode length of stripe_indices array: %" PRIu32
+			".",
+			stripes);
 		return NFS4ERR_SERVERFAULT;
 	}
 
 	for (stripe = 0; stripe < stripes; stripe++) {
-		uint32_t stripe_osd = stripe_osd =
-		    ceph_ll_get_stripe_osd(export->cmount,
-					   vinode,
-					   stripe,
-					   &file_layout);
+		uint32_t stripe_osd = stripe_osd = ceph_ll_get_stripe_osd(
+			export->cmount, vinode, stripe, &file_layout);
 		if (stripe_osd < 0) {
 			LogCrit(COMPONENT_PNFS,
-				"Failed to retrieve OSD for stripe %lu of file %"
-				PRIu64 ".  Error: %u",
+				"Failed to retrieve OSD for stripe %lu of file %" PRIu64
+				".  Error: %u",
 				stripe, deviceid->devid, -stripe_osd);
 			return NFS4ERR_SERVERFAULT;
 		}
@@ -214,8 +211,8 @@ static nfsstat4 getdeviceinfo(struct fsal_export *export_pub,
  */
 
 static nfsstat4 getdevicelist(struct fsal_export *export_pub, layouttype4 type,
-			      void *opaque, bool(*cb) (void *opaque,
-						       const uint64_t id),
+			      void *opaque,
+			      bool (*cb)(void *opaque, const uint64_t id),
 			      struct fsal_getdevicelist_res *res)
 {
 	res->eof = true;
@@ -318,7 +315,6 @@ void export_ops_pnfs(struct export_ops *ops)
  * ignore it otherwise.
  *
  * @param[in]     obj_pub  Public object handle
- * @param[in]     req_ctx  Request context
  * @param[out]    loc_body An XDR stream to which the FSAL must encode
  *                         the layout specific portion of the granted
  *                         layout segment.
@@ -328,14 +324,13 @@ void export_ops_pnfs(struct export_ops *ops)
  * @return Valid error codes in RFC 5661, pp. 366-7.
  */
 
-static nfsstat4 layoutget(struct fsal_obj_handle *obj_pub,
-			  struct req_op_context *req_ctx, XDR *loc_body,
+static nfsstat4 layoutget(struct fsal_obj_handle *obj_pub, XDR *loc_body,
 			  const struct fsal_layoutget_arg *arg,
 			  struct fsal_layoutget_res *res)
 {
 	/* The private 'full' export */
 	struct ceph_export *export =
-		container_of(req_ctx->fsal_export, struct ceph_export, export);
+		container_of(op_ctx->fsal_export, struct ceph_export, export);
 	/* The private 'full' object handle */
 	struct ceph_handle *handle =
 		container_of(obj_pub, struct ceph_handle, handle);
@@ -355,19 +350,16 @@ static nfsstat4 layoutget(struct fsal_obj_handle *obj_pub,
 	/* DS wire handle */
 	struct ds_wire ds_wire;
 	/* Descriptor for DS handle */
-	struct gsh_buffdesc ds_desc = {.addr = &ds_wire,
-		.len = sizeof(struct ds_wire)
-	};
+	struct gsh_buffdesc ds_desc = { .addr = &ds_wire,
+					.len = sizeof(struct ds_wire) };
 	/* The smallest layout the client will accept */
 	struct pnfs_segment smallest_acceptable = {
 		.io_mode = res->segment.io_mode,
 		.offset = res->segment.offset,
 		.length = arg->minlength
 	};
-	struct pnfs_segment forbidden_area = {
-		.io_mode = res->segment.io_mode,
-		.length = NFS4_UINT64_MAX
-	};
+	struct pnfs_segment forbidden_area = { .io_mode = res->segment.io_mode,
+					       .length = NFS4_UINT64_MAX };
 
 	/* We support only LAYOUT4_NFSV4_1_FILES layouts */
 
@@ -394,14 +386,13 @@ static nfsstat4 layoutget(struct fsal_obj_handle *obj_pub,
 	   Otherwise, make sure the required layout doesn't go beyond
 	   what can be accessed through pNFS. This is a preliminary
 	   check before even talking to Ceph. */
-	if (!
-	    ((res->segment.offset == 0)
-	     && (res->segment.length == NFS4_UINT64_MAX))) {
-		if (pnfs_segments_overlap
-		    (&smallest_acceptable, &forbidden_area)) {
+	if (!((res->segment.offset == 0) &&
+	      (res->segment.length == NFS4_UINT64_MAX))) {
+		if (pnfs_segments_overlap(&smallest_acceptable,
+					  &forbidden_area)) {
 			LogCrit(COMPONENT_PNFS,
-				"Required layout extends beyond allowed region. offset: %"
-				PRIu64 ", minlength: %" PRIu64 ".",
+				"Required layout extends beyond allowed region. offset: %" PRIu64
+				", minlength: %" PRIu64 ".",
 				res->segment.offset, arg->minlength);
 			return NFS4ERR_BADLAYOUT;
 		}
@@ -420,8 +411,9 @@ static nfsstat4 layoutget(struct fsal_obj_handle *obj_pub,
 
 	if ((stripe_width & ~NFL4_UFLG_STRIPE_UNIT_SIZE_MASK) != 0) {
 		LogCrit(COMPONENT_PNFS,
-			"Ceph returned stripe width that is disallowed by NFS: %"
-			PRIu32 ".", stripe_width);
+			"Ceph returned stripe width that is disallowed by NFS: %" PRIu32
+			".",
+			stripe_width);
 		return NFS4ERR_SERVERFAULT;
 	}
 	util = stripe_width;
@@ -462,14 +454,14 @@ static nfsstat4 layoutget(struct fsal_obj_handle *obj_pub,
 			}
 		}
 		forbidden_area.offset = handle->rw_max_len;
-		if (pnfs_segments_overlap
-		    (&smallest_acceptable, &forbidden_area)) {
+		if (pnfs_segments_overlap(&smallest_acceptable,
+					  &forbidden_area)) {
 			PTHREAD_RWLOCK_unlock(&handle->handle.obj_lock);
 			return NFS4ERR_BADLAYOUT;
 		}
-#if CLIENTS_WILL_ACCEPT_SEGMENTED_LAYOUTS	/* sigh */
+#if CLIENTS_WILL_ACCEPT_SEGMENTED_LAYOUTS /* sigh */
 		res->segment.length =
-		    (handle->rw_max_len - res->segment.offset);
+			(handle->rw_max_len - res->segment.offset);
 #endif
 		++handle->rw_issued;
 	}
@@ -491,7 +483,7 @@ static nfsstat4 layoutget(struct fsal_obj_handle *obj_pub,
 	ds_wire.snapseq = ceph_ll_snap_seq(export->cmount, handle->wire.vi);
 
 	nfs_status = FSAL_encode_file_layout(loc_body, &deviceid, util, 0, 0,
-					     &req_ctx->export->export_id, 1,
+					     &op_ctx->export->export_id, 1,
 					     &ds_desc);
 	if (nfs_status != NFS4_OK) {
 		LogCrit(COMPONENT_PNFS,
@@ -507,7 +499,7 @@ static nfsstat4 layoutget(struct fsal_obj_handle *obj_pub,
 
 	return NFS4_OK;
 
- relinquish:
+relinquish:
 
 	/* If we failed in encoding the lo_content, relinquish what we
 	   reserved for it. */
@@ -544,20 +536,18 @@ static nfsstat4 layoutget(struct fsal_obj_handle *obj_pub,
  * pins to release, always succeed
  *
  * @param[in] obj_pub  Public object handle
- * @param[in] req_ctx  Request context
  * @param[in] lrf_body Nothing for us
  * @param[in] arg      Input arguments of the function
  *
  * @return Valid error codes in RFC 5661, p. 367.
  */
 
-static nfsstat4 layoutreturn(struct fsal_obj_handle *obj_pub,
-			     struct req_op_context *req_ctx, XDR *lrf_body,
+static nfsstat4 layoutreturn(struct fsal_obj_handle *obj_pub, XDR *lrf_body,
 			     const struct fsal_layoutreturn_arg *arg)
 {
 	/* The private 'full' export */
 	struct ceph_export *export =
-		container_of(req_ctx->fsal_export, struct ceph_export, export);
+		container_of(op_ctx->fsal_export, struct ceph_export, export);
 	/* The private 'full' object handle */
 	struct ceph_handle *handle =
 		container_of(obj_pub, struct ceph_handle, handle);
@@ -602,7 +592,6 @@ static nfsstat4 layoutreturn(struct fsal_obj_handle *obj_pub,
  * Update the size and time for a file accessed through a layout.
  *
  * @param[in]     obj_pub  Public object handle
- * @param[in]     req_ctx  Request context
  * @param[in]     lou_body An XDR stream containing the layout
  *                         type-specific portion of the LAYOUTCOMMIT
  *                         arguments.
@@ -612,14 +601,13 @@ static nfsstat4 layoutreturn(struct fsal_obj_handle *obj_pub,
  * @return Valid error codes in RFC 5661, p. 366.
  */
 
-static nfsstat4 layoutcommit(struct fsal_obj_handle *obj_pub,
-			     struct req_op_context *req_ctx, XDR *lou_body,
+static nfsstat4 layoutcommit(struct fsal_obj_handle *obj_pub, XDR *lou_body,
 			     const struct fsal_layoutcommit_arg *arg,
 			     struct fsal_layoutcommit_res *res)
 {
 	/* The private 'full' export */
 	struct ceph_export *export =
-		container_of(req_ctx->fsal_export, struct ceph_export, export);
+		container_of(op_ctx->fsal_export, struct ceph_export, export);
 	/* The private 'full' object handle */
 	struct ceph_handle *handle =
 		container_of(obj_pub, struct ceph_handle, handle);
@@ -643,12 +631,14 @@ static nfsstat4 layoutcommit(struct fsal_obj_handle *obj_pub,
 	   Ceph caps, but we need to hack at the client to expose
 	   those before it can work. */
 	ceph_status = fsal_ceph_ll_getattr(export->cmount, handle->wire.vi,
-			&stxold, CEPH_STATX_SIZE|CEPH_STATX_MTIME,
-			op_ctx->creds);
+					   &stxold,
+					   CEPH_STATX_SIZE | CEPH_STATX_MTIME,
+					   op_ctx->creds);
 	if (ceph_status < 0) {
 		LogCrit(COMPONENT_PNFS,
-			"Error %d in attempt to get attributes of file %"
-			PRIu64 ".", -ceph_status, handle->wire.vi.ino.val);
+			"Error %d in attempt to get attributes of file %" PRIu64
+			".",
+			-ceph_status, handle->wire.vi.ino.val);
 		return posix2nfs4_error(-ceph_status);
 	}
 
@@ -681,11 +671,12 @@ static nfsstat4 layoutcommit(struct fsal_obj_handle *obj_pub,
 	attrmask |= CEPH_SETATTR_MTIME;
 
 	ceph_status = fsal_ceph_ll_setattr(export->cmount, handle->wire.vi,
-					&stxnew, attrmask, op_ctx->creds);
+					   &stxnew, attrmask, op_ctx->creds);
 	if (ceph_status < 0) {
 		LogCrit(COMPONENT_PNFS,
-			"Error %d in attempt to get attributes of file %"
-			PRIu64 ".", -ceph_status, handle->wire.vi.ino.val);
+			"Error %d in attempt to get attributes of file %" PRIu64
+			".",
+			-ceph_status, handle->wire.vi.ino.val);
 		return posix2nfs4_error(-ceph_status);
 	}
 
@@ -703,4 +694,4 @@ void handle_ops_pnfs(struct fsal_obj_ops *ops)
 	ops->layoutcommit = layoutcommit;
 }
 
-#endif				/* CEPH_PNFS */
+#endif /* CEPH_PNFS */
