@@ -47,6 +47,7 @@
 #include <time.h>
 #include <pthread.h>
 #include <string.h>
+#include <sal_data.h>
 
 /** File cache configuration, settable in the CacheInode/MDCACHE
     stanza. */
@@ -54,46 +55,46 @@
 struct mdcache_parameter mdcache_param;
 
 static struct config_item mdcache_params[] = {
-	CONF_ITEM_UI32("NParts", 1, 32633, 7,
-		       mdcache_parameter, nparts),
-	CONF_ITEM_UI32("Cache_Size", 1, UINT32_MAX, 32633,
-		       mdcache_parameter, cache_size),
+	CONF_ITEM_UI32("NParts", 1, 32633, 7, mdcache_parameter, nparts),
+	CONF_ITEM_UI32("Cache_Size", 1, UINT32_MAX, 32633, mdcache_parameter,
+		       cache_size),
 	CONF_ITEM_BOOL("Use_Getattr_Directory_Invalidation", false,
 		       mdcache_parameter, getattr_dir_invalidation),
-	CONF_ITEM_UI32("Dir_Chunk", 0, UINT32_MAX, 128,
-		       mdcache_parameter, dir.avl_chunk),
-	CONF_ITEM_UI32("Detached_Mult", 1, UINT32_MAX, 1,
-		       mdcache_parameter, dir.avl_detached_mult),
+	CONF_ITEM_UI32("Dir_Chunk", 0, UINT32_MAX, 128, mdcache_parameter,
+		       dir.avl_chunk),
+	CONF_ITEM_UI32("Detached_Mult", 1, UINT32_MAX, 1, mdcache_parameter,
+		       dir.avl_detached_mult),
 	CONF_ITEM_UI32("Entries_HWMark", 1, UINT32_MAX, 100000,
 		       mdcache_parameter, entries_hwmark),
 	CONF_ITEM_UI32("Entries_Release_Size", 0, UINT32_MAX, 100,
 		       mdcache_parameter, entries_release_size),
-	CONF_ITEM_UI32("Chunks_HWMark", 1, UINT32_MAX, 1000,
-		       mdcache_parameter, chunks_hwmark),
-	CONF_ITEM_UI32("Chunks_LWMark", 1, UINT32_MAX, 1000,
-		       mdcache_parameter, chunks_lwmark),
-	CONF_ITEM_UI32("LRU_Run_Interval", 1, 24 * 3600, 90,
-		       mdcache_parameter, lru_run_interval),
-	CONF_ITEM_BOOL("Cache_FDs", true,
-		       mdcache_parameter, Cache_FDs),
-	CONF_ITEM_UI32("FD_Limit_Percent", 0, 100, 99,
-		       mdcache_parameter, fd_limit_percent),
-	CONF_ITEM_UI32("FD_HWMark_Percent", 0, 100, 90,
-		       mdcache_parameter, fd_hwmark_percent),
-	CONF_ITEM_UI32("FD_LWMark_Percent", 0, 100, 50,
-		       mdcache_parameter, fd_lwmark_percent),
-	CONF_ITEM_UI32("Reaper_Work", 1, 2000, 0,
-		       mdcache_parameter, reaper_work),
+	CONF_ITEM_UI32("Chunks_HWMark", 1, UINT32_MAX, 1000, mdcache_parameter,
+		       chunks_hwmark),
+	CONF_ITEM_UI32("Chunks_LWMark", 1, UINT32_MAX, 1000, mdcache_parameter,
+		       chunks_lwmark),
+	CONF_ITEM_UI32("LRU_Run_Interval", 1, 24 * 3600, 90, mdcache_parameter,
+		       lru_run_interval),
+	CONF_ITEM_BOOL("Cache_FDs", true, mdcache_parameter, Cache_FDs),
+	CONF_ITEM_UI32("FD_Limit_Percent", 0, 100, 99, mdcache_parameter,
+		       fd_limit_percent),
+	CONF_ITEM_UI32("FD_HWMark_Percent", 0, 100, 90, mdcache_parameter,
+		       fd_hwmark_percent),
+	CONF_ITEM_UI32("FD_LWMark_Percent", 0, 100, 50, mdcache_parameter,
+		       fd_lwmark_percent),
+	CONF_ITEM_UI32("Reaper_Work", 1, 2000, 0, mdcache_parameter,
+		       reaper_work),
 	CONF_ITEM_UI32("Reaper_Work_Per_Lane", 1, UINT32_MAX, 50,
 		       mdcache_parameter, reaper_work_per_lane),
-	CONF_ITEM_UI32("Biggest_Window", 1, 100, 40,
-		       mdcache_parameter, biggest_window),
-	CONF_ITEM_UI32("Required_Progress", 1, 50, 5,
-		       mdcache_parameter, required_progress),
-	CONF_ITEM_UI32("Futility_Count", 1, 50, 8,
-		       mdcache_parameter, futility_count),
-	CONF_ITEM_UI32("Dirmap_HWMark", 1, UINT32_MAX, 10000,
-		       mdcache_parameter, dirmap_hwmark),
+	CONF_ITEM_UI32("Biggest_Window", 1, 100, 40, mdcache_parameter,
+		       biggest_window),
+	CONF_ITEM_UI32("Required_Progress", 1, 50, 5, mdcache_parameter,
+		       required_progress),
+	CONF_ITEM_UI32("Futility_Count", 1, 50, 8, mdcache_parameter,
+		       futility_count),
+	CONF_ITEM_UI32("Dirmap_HWMark", 1, UINT32_MAX, 10000, mdcache_parameter,
+		       dirmap_hwmark),
+	CONF_ITEM_I32("Files_Delegatable_Percent", 10, INT32_MAX, 90,
+		      mdcache_parameter, files_delegatable_percent),
 	CONFIG_EOL
 };
 
@@ -131,7 +132,7 @@ struct config_block mdcache_param_blk = {
 	.blk_desc.name = "MDCACHE",
 	.blk_desc.altname = "CacheInode",
 	.blk_desc.type = CONFIG_BLOCK,
-	.blk_desc.flags = CONFIG_UNIQUE,  /* too risky to have more */
+	.blk_desc.flags = CONFIG_UNIQUE, /* too risky to have more */
 	.blk_desc.u.blk.init = mdcache_param_init,
 	.blk_desc.u.blk.params = mdcache_params,
 	.blk_desc.u.blk.commit = mdcache_param_commit
@@ -140,11 +141,8 @@ struct config_block mdcache_param_blk = {
 int mdcache_set_param_from_conf(config_file_t parse_tree,
 				struct config_error_type *err_type)
 {
-	(void) load_config_from_parse(parse_tree,
-				      &mdcache_param_blk,
-				      NULL,
-				      true,
-				      err_type);
+	(void)load_config_from_parse(parse_tree, &mdcache_param_blk, NULL, true,
+				     err_type);
 	if (!config_error_is_harmless(err_type)) {
 		LogCrit(COMPONENT_INIT,
 			"Error while parsing MDCACHE specific configuration");
@@ -159,7 +157,12 @@ int mdcache_set_param_from_conf(config_file_t parse_tree,
 
 	/* Compute avl_detached_max from avl_chunk and avl_detached_mult */
 	mdcache_param.dir.avl_detached_max =
-	    mdcache_param.dir.avl_chunk * mdcache_param.dir.avl_detached_mult;
+		mdcache_param.dir.avl_chunk *
+		mdcache_param.dir.avl_detached_mult;
+
+	g_max_files_delegatable = (mdcache_param.files_delegatable_percent *
+				   mdcache_param.entries_hwmark) /
+				  100;
 
 	return 0;
 }
