@@ -70,7 +70,7 @@
 #include "client_mgr.h"
 #include "export_mgr.h"
 #ifdef USE_CAPS
-#include <sys/capability.h>	/* For capget/capset */
+#include <sys/capability.h> /* For capget/capset */
 #endif
 #include "uid2grp.h"
 #include "netgroup_cache.h"
@@ -81,6 +81,9 @@
 #include <urcu-bp.h>
 #include "conf_url.h"
 #include "FSAL/fsal_localfs.h"
+#ifdef USE_MONITORING
+#include "nfs_metrics.h"
+#endif
 
 pthread_mutexattr_t default_mutex_attr;
 pthread_rwlockattr_t default_rwlock_attr;
@@ -103,8 +106,8 @@ static struct _nfs_health healthstats;
 struct timespec nfs_ServerBootTime;
 time_t nfs_ServerEpoch;
 
-verifier4 NFS4_write_verifier;	/* NFS V4 write verifier */
-writeverf3 NFS3_write_verifier;	/* NFS V3 write verifier */
+verifier4 NFS4_write_verifier; /* NFS V4 write verifier */
+writeverf3 NFS3_write_verifier; /* NFS V3 write verifier */
 
 /* node ID used to identify an individual node in a cluster */
 int g_nodeid;
@@ -142,7 +145,7 @@ char *nfs_config_path = GANESHA_CONFIG_PATH;
 
 char *nfs_pidfile_path = GANESHA_PIDFILE_PATH;
 
-char cid_server_owner[MAXNAMLEN+1]; /* max hostname length */
+char cid_server_owner[MAXNAMLEN + 1]; /* max hostname length */
 char *cid_server_scope;
 
 /**
@@ -161,10 +164,208 @@ char *cid_server_scope;
 
 struct config_error_type err_type;
 
+#ifdef _HAVE_GSSAPI
+
+/**
+ * @brief Set up the server-principal and creds to be used for GSS forechannel
+ */
+static void gss_principal_init(enum log_components log_component)
+{
+	gss_buffer_desc gss_service_buf;
+	OM_uint32 maj_stat, min_stat;
+	char gssError[MAXNAMLEN + 1];
+
+	gss_service_buf.value = nfs_param.krb5_param.svc.principal;
+	gss_service_buf.length = strlen(nfs_param.krb5_param.svc.principal) + 1;
+	/* The '+1' is not to be forgotten, for the '\0' at the end */
+
+	maj_stat = gss_import_name(&min_stat, &gss_service_buf,
+				   (gss_OID)GSS_C_NT_HOSTBASED_SERVICE,
+				   &nfs_param.krb5_param.svc.gss_name);
+
+	if (maj_stat != GSS_S_COMPLETE) {
+		log_sperror_gss(gssError, maj_stat, min_stat);
+		LogFatal(log_component,
+			 "Error importing gss principal %s is %s",
+			 nfs_param.krb5_param.svc.principal, gssError);
+	}
+
+	if (nfs_param.krb5_param.svc.gss_name == GSS_C_NO_NAME) {
+		LogInfo(log_component,
+			"Regression:  svc.gss_name == GSS_C_NO_NAME");
+	}
+
+	LogInfo(log_component, "gss principal \"%s\" successfully set",
+		nfs_param.krb5_param.svc.principal);
+
+	/* Set the principal to GSSRPC */
+	if (!svcauth_gss_set_svc_name(nfs_param.krb5_param.svc.gss_name)) {
+		LogFatal(log_component,
+			 "Impossible to set gss principal to GSSRPC");
+	}
+	/* Don't release name until shutdown, it will be used by the
+	 * backchannel.
+	 */
+
+	/* Trying to acquire credentials, while checking name's validity */
+	if (!svcauth_gss_acquire_cred()) {
+		LogCrit(log_component,
+			"Cannot acquire credentials for principal %s",
+			nfs_param.krb5_param.svc.principal);
+	} else {
+		LogInfo(log_component,
+			"Principal %s is suitable for acquiring credentials",
+			nfs_param.krb5_param.svc.principal);
+	}
+}
+
+/**
+ * @brief Enable nfs_krb5 functionality
+ *
+ * This functionality includes gss based authentication for forechannel
+ * and gss based callbacks.
+ */
+static void enable_nfs_krb5(nfs_krb5_parameter_t krb5_param,
+			    enum log_components log_component)
+{
+	char gssError[MAXNAMLEN + 1];
+
+	/* Update global nfs_param.krb5_param */
+	nfs_param.krb5_param = krb5_param;
+
+	/* Enable gss based callbacks */
+	nfs_rpc_cb_set_gss_status(true);
+
+	/* Setup keytab */
+#ifdef HAVE_KRB5
+	OM_uint32 gss_status =
+		krb5_gss_register_acceptor_identity(krb5_param.keytab);
+	if (gss_status != GSS_S_COMPLETE) {
+		log_sperror_gss(gssError, gss_status, 0);
+		LogFatal(log_component,
+			 "Error setting krb5 keytab to value %s is %s",
+			 krb5_param.keytab, gssError);
+	}
+	LogInfo(log_component, "krb5 keytab path successfully set to %s",
+		krb5_param.keytab);
+#endif /* HAVE_KRB5 */
+
+	/* Set up gss principal to use with GSSAPI */
+	gss_principal_init(log_component);
+
+	/* Set rpcsec_gss fore-channel authentication status as ON */
+	svcauth_gss_set_status(true);
+
+	LogInfo(log_component, "nfs_krb5 functionality is now enabled");
+}
+
+/**
+ * @brief Disable nfs_krb5 functionality
+ *
+ * This functionality includes gss based authentication for forechannel
+ * and gss based callbacks.
+ */
+static void disable_nfs_krb5(nfs_krb5_parameter_t krb5_param,
+			     log_components_t log_component)
+{
+	char gss_error[MAXNAMLEN + 1];
+	OM_uint32 maj_stat, min_stat;
+
+	nfs_param.krb5_param.active_krb5 = false;
+
+#ifdef HAVE_KRB5
+	/* Clear keytab used by gss/krb5 lib */
+	OM_uint32 gss_status = krb5_gss_register_acceptor_identity(NULL);
+
+	if (gss_status != GSS_S_COMPLETE) {
+		log_sperror_gss(gss_error, gss_status, 0);
+		LogCrit(log_component, "Error clearing krb5 keytab: %s",
+			gss_error);
+	} else {
+		LogInfo(log_component, "krb5 keytab path successfully cleared");
+	}
+#endif /* HAVE_KRB5 */
+
+	/* Clear gss_name */
+	if (nfs_param.krb5_param.svc.gss_name != GSS_C_NO_NAME) {
+		maj_stat = gss_release_name(&min_stat,
+					    &nfs_param.krb5_param.svc.gss_name);
+		if (maj_stat != GSS_S_COMPLETE) {
+			LogCrit(log_component,
+				"Error freeing svc.gss_name major=%u minor=%u",
+				maj_stat, min_stat);
+		}
+		nfs_param.krb5_param.svc.gss_name = NULL;
+	}
+
+	/* Set rpcsec_gss fore-channel authentication status as OFF */
+	svcauth_gss_set_status(false);
+	LogInfo(log_component, "svcauth_gss is now disabled");
+
+	/* Disable gss based callbacks */
+	nfs_rpc_cb_set_gss_status(false);
+
+	LogInfo(log_component, "nfs_krb5 functionality is now disabled");
+}
+
+/**
+ * @brief Handle nfs_krb5 configuration update
+ *
+ * This function detects changes against the existing nfs_krb5 configuration,
+ * and makes the required Ganesha-wide changes.
+ *
+ * @note We only support dynamic toggling of the krb5 functionality from the
+ * states -- OFF to OFF, OFF to ON and ON to OFF. ON to ON with an updated
+ * configuration is not supported.
+ */
+static void handle_krb5_config_update(nfs_krb5_parameter_t new_krb5_param)
+{
+	if (!nfs_param.krb5_param.active_krb5) {
+		if (!new_krb5_param.active_krb5) {
+			LogInfo(COMPONENT_CONFIG,
+				"NFSv4-KRB5 state: OFF --> OFF. No action required");
+			return;
+		}
+		LogInfo(COMPONENT_CONFIG,
+			"NFSv4-KRB5 state: OFF --> ON. Enabling KRB5");
+		enable_nfs_krb5(new_krb5_param, COMPONENT_CONFIG);
+		return;
+	}
+
+	/* At this point, existing nfs_param.krb5_param.active_krb5 is true */
+
+	if (new_krb5_param.active_krb5) {
+		/* No action needed if new and old configs are the same */
+		if (!strcmp(nfs_param.krb5_param.keytab,
+			    new_krb5_param.keytab) &&
+		    !strcmp(nfs_param.krb5_param.ccache_dir,
+			    new_krb5_param.ccache_dir) &&
+		    !strcmp(nfs_param.krb5_param.svc.principal,
+			    new_krb5_param.svc.principal)) {
+			LogInfo(COMPONENT_CONFIG,
+				"NFSv4-KRB5 state: ON --> ON (same config). No action required");
+			return;
+		}
+		LogCrit(COMPONENT_CONFIG,
+			"NFSv4-KRB5 state: ON --> ON (updated config). Reload does not support it!");
+		/* For backward compatibility, we release gss-creds on reload */
+		svcauth_gss_release_cred();
+		return;
+	}
+	LogInfo(COMPONENT_CONFIG,
+		"NFSv4-KRB5 state: ON --> OFF. Disabling KRB5");
+	disable_nfs_krb5(new_krb5_param, COMPONENT_CONFIG);
+}
+
+#endif /* _HAVE_GSSAPI */
+
 bool reread_config(void)
 {
 	int status = 0;
 	config_file_t config_struct;
+#ifdef _HAVE_GSSAPI
+	nfs_krb5_parameter_t new_krb5_param;
+#endif
 
 	/* If no configuration file is given, then the caller must want to
 	 * reparse the configuration file from startup.
@@ -185,7 +386,7 @@ bool reread_config(void)
 		LogCrit(COMPONENT_CONFIG,
 			"Error while parsing new configuration file %s",
 			nfs_config_path);
-		(void) report_config_errors(&err_type, NULL, config_errs_to_log);
+		(void)report_config_errors(&err_type, NULL, config_errs_to_log);
 		return false;
 	}
 
@@ -198,12 +399,41 @@ bool reread_config(void)
 
 	/* Update the export configuration */
 	status = reread_exports(config_struct, &err_type);
-	if (status < 0) {
+	if (status < 0 || !config_error_is_harmless(&err_type)) {
 		LogCrit(COMPONENT_CONFIG, "Error while parsing EXPORT entries");
 		return false;
 	}
 
-	(void) report_config_errors(&err_type, NULL, config_errs_to_log);
+	/* Reread directory_services configuration */
+	(void)load_config_from_parse(config_struct, &directory_services_param,
+				     &nfs_param.directory_services_param, true,
+				     &err_type);
+	if (!config_error_is_harmless(&err_type)) {
+		LogCrit(COMPONENT_CONFIG,
+			"Error while parsing DIRECTORY_SERVICES configuration");
+		return false;
+	}
+
+	/* Set idmapping status based on directory_services configuration */
+	status = set_idmapping_status(
+		nfs_param.directory_services_param.idmapping_active);
+	if (!status)
+		LogFatal(COMPONENT_CONFIG, "Failed to set idmapping status");
+
+#ifdef _HAVE_GSSAPI
+	/* Reread NFS kerberos5 configuration */
+	(void)load_config_from_parse(config_struct, &krb5_param,
+				     &new_krb5_param, true, &err_type);
+	if (!config_error_is_harmless(&err_type)) {
+		LogCrit(COMPONENT_CONFIG,
+			"Error while parsing NFSv4-KRB5 configuration section");
+		return false;
+	}
+
+	handle_krb5_config_update(new_krb5_param);
+#endif /* _HAVE_GSSAPI */
+
+	(void)report_config_errors(&err_type, NULL, config_errs_to_log);
 	config_Free(config_struct);
 	return true;
 }
@@ -235,12 +465,10 @@ static void *sigmgr_thread(void *UnusedArg)
 			continue;
 		}
 		if (signal_caught == SIGHUP) {
-			LogEvent(COMPONENT_MAIN,
-				 "SIGHUP_HANDLER: Received SIGHUP.... initiating export list reload");
+			LogEvent(
+				COMPONENT_MAIN,
+				"SIGHUP_HANDLER: Received SIGHUP.... initiating export list reload");
 			reread_config();
-#ifdef _HAVE_GSSAPI
-			svcauth_gss_release_cred();
-#endif /* _HAVE_GSSAPI */
 		}
 	}
 	LogDebug(COMPONENT_THREAD, "sigmgr thread exiting");
@@ -252,9 +480,11 @@ static void *sigmgr_thread(void *UnusedArg)
 	return NULL;
 }
 
-
 static void crash_handler(int signo, siginfo_t *info, void *ctx)
 {
+	/* Already in the process of shutting down, skip backtraces & cores */
+	if (admin_shutdown)
+		return;
 #ifdef USE_UNWIND
 	gsh_libunwind();
 #else
@@ -294,6 +524,22 @@ static void init_crash_handlers(void)
 	install_sighandler(SIGQUIT, crash_handler);
 }
 
+void nfs_prereq_init_mutexes(void)
+{
+	PTHREAD_MUTEXATTR_init(&default_mutex_attr);
+#if defined(__linux__)
+	PTHREAD_MUTEXATTR_settype(&default_mutex_attr,
+				  PTHREAD_MUTEX_ADAPTIVE_NP);
+#endif
+
+	PTHREAD_RWLOCKATTR_init(&default_rwlock_attr);
+#if defined(__linux__)
+	PTHREAD_RWLOCKATTR_setkind_np(
+		&default_rwlock_attr,
+		PTHREAD_RWLOCK_PREFER_WRITER_NONRECURSIVE_NP);
+#endif
+}
+
 /**
  * @brief Initialize NFSd prerequisites
  *
@@ -307,18 +553,7 @@ void nfs_prereq_init(const char *program_name, const char *host_name,
 		     int debug_level, const char *log_path, bool dump_trace,
 		     unsigned long stack_size)
 {
-	PTHREAD_MUTEXATTR_init(&default_mutex_attr);
-#if defined(__linux__)
-	PTHREAD_MUTEXATTR_settype(&default_mutex_attr,
-				  PTHREAD_MUTEX_ADAPTIVE_NP);
-#endif
-
-	PTHREAD_RWLOCKATTR_init(&default_rwlock_attr);
-#if defined(__linux__)
-	PTHREAD_RWLOCKATTR_setkind_np(
-				&default_rwlock_attr,
-				PTHREAD_RWLOCK_PREFER_WRITER_NONRECURSIVE_NP);
-#endif
+	nfs_prereq_init_mutexes();
 
 	PTHREAD_stack_size = stack_size;
 
@@ -379,16 +614,16 @@ void nfs_print_param_config(void)
 	printf("\tDRC_UDP_Checksum = %u ;\n",
 	       nfs_param.core_param.drc.udp.checksum);
 	printf("\tBlocked_Lock_Poller_Interval = %" PRIu64 " ;\n",
-	       (uint64_t) nfs_param.core_param.blocked_lock_poller_interval);
+	       (uint64_t)nfs_param.core_param.blocked_lock_poller_interval);
 
 	printf("\tManage_Gids_Expiration = %" PRIu64 " ;\n",
-	       (uint64_t) nfs_param.core_param.manage_gids_expiration);
+	       (uint64_t)nfs_param.core_param.manage_gids_expiration);
 
 	printf("\tDrop_IO_Errors = %s ;\n",
-	       nfs_param.core_param.drop_io_errors ?  "true" : "false");
+	       nfs_param.core_param.drop_io_errors ? "true" : "false");
 
 	printf("\tDrop_Inval_Errors = %s ;\n",
-	       nfs_param.core_param.drop_inval_errors ?  "true" : "false");
+	       nfs_param.core_param.drop_inval_errors ? "true" : "false");
 
 	printf("\tDrop_Delay_Errors = %s ;\n",
 	       nfs_param.core_param.drop_delay_errors ? "true" : "false");
@@ -416,6 +651,10 @@ int nfs_set_param_from_conf(config_file_t parse_tree,
 			    nfs_start_info_t *p_start_info,
 			    struct config_error_type *err_type)
 {
+	const time_t unset_time_validity = -1;
+	directory_services_param_t *ds_param =
+		&nfs_param.directory_services_param;
+
 	/*
 	 * Initialize exports and clients so config parsing can use them
 	 * early.
@@ -426,11 +665,8 @@ int nfs_set_param_from_conf(config_file_t parse_tree,
 	server_pkginit();
 
 	/* Core parameters */
-	(void) load_config_from_parse(parse_tree,
-				      &nfs_core,
-				      &nfs_param.core_param,
-				      true,
-				      err_type);
+	(void)load_config_from_parse(parse_tree, &nfs_core,
+				     &nfs_param.core_param, true, err_type);
 	if (!config_error_is_harmless(err_type)) {
 		LogCrit(COMPONENT_INIT,
 			"Error while parsing core configuration");
@@ -440,11 +676,8 @@ int nfs_set_param_from_conf(config_file_t parse_tree,
 	/* Worker parameters: ip/name hash table and expiration
 	 * for each entry
 	 */
-	(void) load_config_from_parse(parse_tree,
-				      &nfs_ip_name,
-				      NULL,
-				      true,
-				      err_type);
+	(void)load_config_from_parse(parse_tree, &nfs_ip_name, NULL, true,
+				     err_type);
 	if (!config_error_is_harmless(err_type)) {
 		LogCrit(COMPONENT_INIT,
 			"Error while parsing IP/name configuration");
@@ -453,11 +686,8 @@ int nfs_set_param_from_conf(config_file_t parse_tree,
 
 #ifdef _HAVE_GSSAPI
 	/* NFS kerberos5 configuration */
-	(void) load_config_from_parse(parse_tree,
-				      &krb5_param,
-				      &nfs_param.krb5_param,
-				      true,
-				      err_type);
+	(void)load_config_from_parse(parse_tree, &krb5_param,
+				     &nfs_param.krb5_param, true, err_type);
 	if (!config_error_is_harmless(err_type)) {
 		LogCrit(COMPONENT_INIT,
 			"Error while parsing NFS/KRB5 configuration for RPCSEC_GSS");
@@ -465,24 +695,69 @@ int nfs_set_param_from_conf(config_file_t parse_tree,
 	}
 #endif
 
+	/* Directory Services specific configuration */
+	(void)load_config_from_parse(parse_tree, &directory_services_param,
+				     ds_param, true, err_type);
+	if (!config_error_is_harmless(err_type)) {
+		LogCrit(COMPONENT_INIT,
+			"Error while parsing DIRECTORY_SERVICES configuration");
+		return -1;
+	}
+
 	/* NFSv4 specific configuration */
-	(void) load_config_from_parse(parse_tree,
-				      &version4_param,
-				      &nfs_param.nfsv4_param,
-				      true,
-				      err_type);
+	(void)load_config_from_parse(parse_tree, &version4_param,
+				     &nfs_param.nfsv4_param, true, err_type);
 	if (!config_error_is_harmless(err_type)) {
 		LogCrit(COMPONENT_INIT,
 			"Error while parsing NFSv4 specific configuration");
 		return -1;
 	}
+	/* Use `domainname` from `nfsv4` config section, if it is not set under
+	 * `directory_services` section. Otherwise, ignore the `nfsv4` value.
+	 */
+	if (ds_param->domainname == NULL) {
+		LogWarn(COMPONENT_INIT,
+			"domainname in NFSv4 config section will soon be deprecated, define it under DIRECTORY_SERVICES section");
+		ds_param->domainname = nfs_param.nfsv4_param.domainname;
+	} else {
+		/* TODO: Remove below log when NFSv4/domainname is removed */
+		LogWarn(COMPONENT_INIT,
+			"Using domainname from DIRECTORY_SERVICES config section, instead of NFSv4");
+	}
+
+	/* For backward compatibility, use `manage_gids_expiration` from
+	 * `nfs_core_param` config section, if `idmapped_user_time_validity` or
+	 * `idmapped_group_time_validity` is not set under `directory_services`
+	 * section. Otherwise, ignore the `manage_gids_expiration` value.
+	 */
+	if (ds_param->idmapped_user_time_validity == unset_time_validity) {
+		LogWarn(COMPONENT_INIT,
+			"Use idmapped_user_time_validity under DIRECTORY_SERVICES section to configure time validity of idmapped users");
+		ds_param->idmapped_user_time_validity =
+			nfs_param.core_param.manage_gids_expiration;
+	} else {
+		/* TODO: Remove below log when NFS_CORE_PARAM/
+		 * manage_gids_expiration is deprecated for user validity.
+		 */
+		LogWarn(COMPONENT_INIT,
+			"Using idmapped_user_time_validity from DIRECTORY_SERVICES config section, instead of manage_gids_expiration from NFS_CORE_PARAM");
+	}
+	if (ds_param->idmapped_group_time_validity == unset_time_validity) {
+		LogWarn(COMPONENT_INIT,
+			"Use idmapped_group_time_validity under DIRECTORY_SERVICES section to configure time validity of idmapped groups");
+		ds_param->idmapped_group_time_validity =
+			nfs_param.core_param.manage_gids_expiration;
+	} else {
+		/* TODO: Remove below log when NFS_CORE_PARAM/
+		 * manage_gids_expiration is deprecated for group validity.
+		 */
+		LogWarn(COMPONENT_INIT,
+			"Using idmapped_group_time_validity from DIRECTORY_SERVICES config section, instead of manage_gids_expiration from NFS_CORE_PARAM");
+	}
 
 #ifdef _USE_9P
-	(void) load_config_from_parse(parse_tree,
-				      &_9p_param_blk,
-				      NULL,
-				      true,
-				      err_type);
+	(void)load_config_from_parse(parse_tree, &_9p_param_blk, NULL, true,
+				     err_type);
 	if (!config_error_is_harmless(err_type)) {
 		LogCrit(COMPONENT_INIT,
 			"Error while parsing 9P specific configuration");
@@ -548,6 +823,12 @@ int init_server_pkgs(void)
 		LogCrit(COMPONENT_INIT, "Failed initializing ID Mapper.");
 		return -1;
 	}
+	/* Set idmapping status based on directory_services configuration */
+	if (!set_idmapping_status(
+		    nfs_param.directory_services_param.idmapping_active)) {
+		LogCrit(COMPONENT_INIT, "Failed to set idmapping status");
+		return -1;
+	}
 	LogEvent(COMPONENT_INIT, "ID Mapper successfully initialized.");
 	return 0;
 }
@@ -589,9 +870,10 @@ static void nfs_Start_threads(void)
 		rc = PTHREAD_create(&_9p_dispatcher_thrid, &attr_thr,
 				    _9p_dispatcher_thread, NULL);
 		if (rc != 0) {
-			LogFatal(COMPONENT_THREAD,
-				 "Could not create  9P/TCP dispatcher, error = %d (%s)",
-				 errno, strerror(errno));
+			LogFatal(
+				COMPONENT_THREAD,
+				"Could not create  9P/TCP dispatcher, error = %d (%s)",
+				errno, strerror(errno));
 		}
 		LogEvent(COMPONENT_THREAD,
 			 "9P/TCP dispatcher thread was started successfully");
@@ -605,9 +887,10 @@ static void nfs_Start_threads(void)
 		rc = PTHREAD_create(&_9p_rdma_dispatcher_thrid, &attr_thr,
 				    _9p_rdma_dispatcher_thread, NULL);
 		if (rc != 0) {
-			LogFatal(COMPONENT_THREAD,
-				 "Could not create  9P/RDMA dispatcher, error = %d (%s)",
-				 errno, strerror(errno));
+			LogFatal(
+				COMPONENT_THREAD,
+				"Could not create  9P/RDMA dispatcher, error = %d (%s)",
+				errno, strerror(errno));
 		}
 		LogEvent(COMPONENT_THREAD,
 			 "9P/RDMA dispatcher thread was started successfully");
@@ -655,7 +938,6 @@ static void nfs_Start_threads(void)
 	PTHREAD_ATTR_destroy(&attr_thr);
 }
 
-
 /**
  * @brief Initialise NFSv4 specific parameters.
  *
@@ -673,17 +955,15 @@ int nfsv4_init_params(void)
 	/* Set up the server owner string */
 	if (nfs_param.nfsv4_param.server_owner == NULL) {
 		/* If the server owner param is NULL, set it to hostname */
-		if (gsh_gethostname(
-			cid_server_owner, sizeof(cid_server_owner),
-			nfs_param.core_param.enable_AUTHSTATS) == -1) {
-			LogCrit(COMPONENT_NFS_V4,
-				"gsh_gethostname failed");
+		if (gsh_gethostname(cid_server_owner, sizeof(cid_server_owner),
+				    nfs_param.core_param.enable_AUTHSTATS) ==
+		    -1) {
+			LogCrit(COMPONENT_NFS_V4, "gsh_gethostname failed");
 			return -1;
 		}
 	} else {
-		rc = snprintf(cid_server_owner,
-				sizeof(cid_server_owner), "%s",
-				nfs_param.nfsv4_param.server_owner);
+		rc = snprintf(cid_server_owner, sizeof(cid_server_owner), "%s",
+			      nfs_param.nfsv4_param.server_owner);
 		/* Assert that server owner conf param is not too long.
 		 * this should never happen since it is validated during
 		 * conf parsing */
@@ -699,9 +979,8 @@ int nfsv4_init_params(void)
 		scope_len = owner_len + ss_suffix_len;
 		cid_server_scope = gsh_malloc(scope_len + 1);
 		memcpy(cid_server_scope, cid_server_owner, owner_len);
-		memcpy(cid_server_scope + owner_len,
-				cid_server_scope_suffix,
-				ss_suffix_len + 1);
+		memcpy(cid_server_scope + owner_len, cid_server_scope_suffix,
+		       ss_suffix_len + 1);
 	} else {
 		cid_server_scope = nfs_param.nfsv4_param.server_scope;
 	}
@@ -716,12 +995,6 @@ int nfsv4_init_params(void)
 
 static void nfs_Init(const nfs_start_info_t *p_start_info)
 {
-#ifdef _HAVE_GSSAPI
-	gss_buffer_desc gss_service_buf;
-	OM_uint32 maj_stat, min_stat;
-	char GssError[MAXNAMLEN + 1];
-#endif
-
 #ifdef USE_DBUS
 	/* DBUS init */
 	gsh_dbus_pkginit();
@@ -730,6 +1003,10 @@ static void nfs_Init(const nfs_start_info_t *p_start_info)
 	dbus_cache_init();
 #endif
 
+#ifdef USE_MONITORING
+	nfs_metrics__init();
+#endif
+
 	/* acls cache may be needed by exports_pkginit */
 	LogDebug(COMPONENT_INIT, "Now building NFSv4 ACL cache");
 	if (nfs4_acls_init() != 0)
@@ -740,71 +1017,12 @@ static void nfs_Init(const nfs_start_info_t *p_start_info)
 	 */
 	exports_pkginit();
 
-	nfs41_session_pool =
-	    pool_basic_init("NFSv4.1 session pool", sizeof(nfs41_session_t));
+	nfs41_session_pool = pool_basic_init("NFSv4.1 session pool",
+					     sizeof(nfs41_session_t));
 
-	/* If rpcsec_gss is used, set the path to the keytab */
-#ifdef _HAVE_GSSAPI
-#ifdef HAVE_KRB5
-	if (nfs_param.krb5_param.active_krb5) {
-		OM_uint32 gss_status = GSS_S_COMPLETE;
-
-		if (strcmp(nfs_param.krb5_param.keytab, DEFAULT_NFS_KEYTAB))
-			gss_status = krb5_gss_register_acceptor_identity(
-						nfs_param.krb5_param.keytab);
-
-		if (gss_status != GSS_S_COMPLETE) {
-			log_sperror_gss(GssError, gss_status, 0);
-			LogFatal(COMPONENT_INIT,
-				 "Error setting krb5 keytab to value %s is %s",
-				 nfs_param.krb5_param.keytab, GssError);
-		}
-		LogInfo(COMPONENT_INIT,
-			"krb5 keytab path successfully set to %s",
-			nfs_param.krb5_param.keytab);
-#endif				/* HAVE_KRB5 */
-
-		/* Set up principal to be use for GSSAPPI within GSSRPC/KRB5 */
-		gss_service_buf.value = nfs_param.krb5_param.svc.principal;
-		gss_service_buf.length =
-			strlen(nfs_param.krb5_param.svc.principal) + 1;
-		/* The '+1' is not to be forgotten, for the '\0' at the end */
-
-		maj_stat = gss_import_name(&min_stat, &gss_service_buf,
-					   (gss_OID) GSS_C_NT_HOSTBASED_SERVICE,
-					   &nfs_param.krb5_param.svc.gss_name);
-		if (maj_stat != GSS_S_COMPLETE) {
-			log_sperror_gss(GssError, maj_stat, min_stat);
-			LogFatal(COMPONENT_INIT,
-				 "Error importing gss principal %s is %s",
-				 nfs_param.krb5_param.svc.principal, GssError);
-		}
-
-		if (nfs_param.krb5_param.svc.gss_name == GSS_C_NO_NAME)
-			LogInfo(COMPONENT_INIT,
-				"Regression:  svc.gss_name == GSS_C_NO_NAME");
-
-		LogInfo(COMPONENT_INIT, "gss principal \"%s\" successfully set",
-			nfs_param.krb5_param.svc.principal);
-
-		/* Set the principal to GSSRPC */
-		if (!svcauth_gss_set_svc_name
-		    (nfs_param.krb5_param.svc.gss_name)) {
-			LogFatal(COMPONENT_INIT,
-				 "Impossible to set gss principal to GSSRPC");
-		}
-
-		/* Don't release name until shutdown, it will be used by the
-		 * backchannel. */
-
-#ifdef HAVE_KRB5
-	}			/*  if( nfs_param.krb5_param.active_krb5 ) */
-#endif				/* HAVE_KRB5 */
-#endif				/* _HAVE_GSSAPI */
 	/* Init the NFSv4 Clientid cache */
 	LogDebug(COMPONENT_INIT, "Now building NFSv4 clientid cache");
-	if (nfs_Init_client_id() !=
-	    CLIENT_ID_SUCCESS) {
+	if (nfs_Init_client_id() != CLIENT_ID_SUCCESS) {
 		LogFatal(COMPONENT_INIT,
 			 "Error while initializing NFSv4 clientid cache");
 	}
@@ -876,11 +1094,11 @@ static void nfs_Init(const nfs_start_info_t *p_start_info)
 	if (nfs_param.core_param.core_options & CORE_OPTION_NFSV4) {
 		/* Initialise NFSv4 specific parameters */
 		if (nfsv4_init_params() != 0) {
-			LogFatal(COMPONENT_INIT,
-			  "Error while initializing NFSv4 specific parameter");
+			LogFatal(
+				COMPONENT_INIT,
+				"Error while initializing NFSv4 specific parameter");
 		}
-		LogInfo(COMPONENT_INIT,
-			"NFSv4 specific parameter initialized");
+		LogInfo(COMPONENT_INIT, "NFSv4 specific parameter initialized");
 	}
 #ifdef _USE_9P
 	LogDebug(COMPONENT_INIT, "Now building 9P resources");
@@ -889,7 +1107,7 @@ static void nfs_Init(const nfs_start_info_t *p_start_info)
 			 "Error while initializing 9P Resources");
 	}
 	LogInfo(COMPONENT_INIT, "9P resources successfully initialized");
-#endif				/* _USE_9P */
+#endif /* _USE_9P */
 
 	/* Creates the pseudo fs */
 	LogDebug(COMPONENT_INIT, "Now building pseudo fs");
@@ -911,11 +1129,20 @@ static void nfs_Init(const nfs_start_info_t *p_start_info)
 
 	/* callback dispatch */
 	nfs_rpc_cb_pkginit();
+
+	/* If rpcsec_gss is used, setup nfs-krb5 */
+#ifdef _HAVE_GSSAPI
+	if (nfs_param.krb5_param.active_krb5)
+		enable_nfs_krb5(nfs_param.krb5_param, COMPONENT_INIT);
+	else
+		disable_nfs_krb5(nfs_param.krb5_param, COMPONENT_INIT);
+#endif
+
 #ifdef _USE_CB_SIMULATOR
 	nfs_rpc_cbsim_pkginit();
-#endif				/*  _USE_CB_SIMULATOR */
+#endif /*  _USE_CB_SIMULATOR */
 
-}				/* nfs_Init */
+} /* nfs_Init */
 
 #ifdef USE_CAPS
 /**
@@ -928,7 +1155,7 @@ static void nfs_Init(const nfs_start_info_t *p_start_info)
 
 static void lower_my_caps(void)
 {
-	cap_value_t cap_values[] = {CAP_SYS_RESOURCE};
+	cap_value_t cap_values[] = { CAP_SYS_RESOURCE };
 	cap_t cap;
 	char *cap_text;
 	ssize_t capstrlen = 0;
@@ -941,32 +1168,32 @@ static void lower_my_caps(void)
 
 	cap = cap_get_proc();
 	if (cap == NULL) {
-		LogFatal(COMPONENT_INIT,
-			 "cap_get_proc() failed, %s", strerror(errno));
+		LogFatal(COMPONENT_INIT, "cap_get_proc() failed, %s",
+			 strerror(errno));
 	}
 
 	ret = cap_set_flag(cap, CAP_EFFECTIVE,
 			   sizeof(cap_values) / sizeof(cap_values[0]),
 			   cap_values, CAP_CLEAR);
 	if (ret != 0) {
-		LogFatal(COMPONENT_INIT,
-			 "cap_set_flag() failed, %s", strerror(errno));
+		LogFatal(COMPONENT_INIT, "cap_set_flag() failed, %s",
+			 strerror(errno));
 	}
 
 	ret = cap_set_flag(cap, CAP_PERMITTED,
 			   sizeof(cap_values) / sizeof(cap_values[0]),
 			   cap_values, CAP_CLEAR);
 	if (ret != 0) {
-		LogFatal(COMPONENT_INIT,
-			 "cap_set_flag() failed, %s", strerror(errno));
+		LogFatal(COMPONENT_INIT, "cap_set_flag() failed, %s",
+			 strerror(errno));
 	}
 
 	ret = cap_set_flag(cap, CAP_INHERITABLE,
 			   sizeof(cap_values) / sizeof(cap_values[0]),
 			   cap_values, CAP_CLEAR);
 	if (ret != 0) {
-		LogFatal(COMPONENT_INIT,
-			 "cap_set_flag() failed, %s", strerror(errno));
+		LogFatal(COMPONENT_INIT, "cap_set_flag() failed, %s",
+			 strerror(errno));
 	}
 
 	ret = cap_set_proc(cap);
@@ -976,8 +1203,9 @@ static void lower_my_caps(void)
 			 strerror(errno));
 	}
 
-	LogEvent(COMPONENT_INIT,
-		 "CAP_SYS_RESOURCE was successfully removed for proper quota management in FSAL");
+	LogEvent(
+		COMPONENT_INIT,
+		"CAP_SYS_RESOURCE was successfully removed for proper quota management in FSAL");
 
 	/* Print newly set capabilities (same as what CLI "getpcaps" displays */
 	cap_text = cap_to_text(cap, &capstrlen);
@@ -992,14 +1220,14 @@ static void lower_my_caps(void)
 #define THIRTY_MIN 1800000000000UL
 static void do_malloc_trim(void *param)
 {
-	LogDebug(COMPONENT_MAIN, malloc_trim(0) ?
-		 "malloc_trim() released some memory" :
-		 "malloc_trim() was not able to release memory");
-	(void) delayed_submit(do_malloc_trim, 0, THIRTY_MIN);
+	LogDebug(COMPONENT_MAIN,
+		 malloc_trim(0) ?
+			 "malloc_trim() released some memory" :
+			 "malloc_trim() was not able to release memory");
+	(void)delayed_submit(do_malloc_trim, 0, THIRTY_MIN);
 }
 #endif
 
-
 /**
  * @brief Start NFS service
  *
@@ -1026,7 +1254,7 @@ void nfs_start(nfs_start_info_t *p_start_info)
 			uint64_t epoch;
 		} build_verifier;
 
-		build_verifier.epoch = (uint64_t) nfs_ServerEpoch;
+		build_verifier.epoch = get_unique_server_id();
 
 		memcpy(NFS3_write_verifier, build_verifier.NFS3_write_verifier,
 		       sizeof(NFS3_write_verifier));
@@ -1043,7 +1271,7 @@ void nfs_start(nfs_start_info_t *p_start_info)
 	nfs_Start_threads(); /* Spawns service threads */
 
 #if defined(M_TRIM_THRESHOLD)
-	(void) delayed_submit(do_malloc_trim, 0, THIRTY_MIN);
+	(void)delayed_submit(do_malloc_trim, 0, THIRTY_MIN);
 #endif
 
 	nfs_init_complete();
@@ -1149,8 +1377,8 @@ bool nfs_health(void)
 			"Health status is unhealthy. "
 			"enq new: %" PRIu64 ", old: %" PRIu64 "; "
 			"deq new: %" PRIu64 ", old: %" PRIu64,
-			newenq, healthstats.enqueued_reqs,
-			newdeq, healthstats.dequeued_reqs);
+			newenq, healthstats.enqueued_reqs, newdeq,
+			healthstats.dequeued_reqs);
 	}
 
 	healthstats.enqueued_reqs = newenq;
