@@ -36,7 +36,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <pthread.h>
-#include <signal.h>		/* for sigaction */
+#include <signal.h> /* for sigaction */
 #include <errno.h>
 #include "fsal.h"
 #include "log.h"
@@ -48,46 +48,22 @@
 #include "conf_url.h"
 #include "sal_functions.h"
 
-/**
- * @brief LTTng trace enabling magic
- *
- * Every trace include file must be added here regardless whether it
- * is actually used in this source file.  The file must also be
- * included ONLY ONCE.  Failure to do so will create interesting
- * build time failure messages.  The key bit is the definitions of
- * TRACEPOINT_DEFINE and TRACEPOINT_PROBE_DYNAMIC_LINKAGE that are here
- * to trigger the global definitions as a shared object with the right
- * (weak) symbols to make the module loading optional.
- *
- * If and when this file gets some tracepoints of its own, the include
- * here is necessary and sufficient.
- */
-
-#ifdef USE_LTTNG
-#define TRACEPOINT_DEFINE
-#define TRACEPOINT_PROBE_DYNAMIC_LINKAGE
-
-#include "gsh_lttng/logger.h"
-#include "gsh_lttng/mdcache.h"
-#include "gsh_lttng/nfs_rpc.h"
-#include "gsh_lttng/nfs4.h"
-#include "gsh_lttng/state.h"
-#include "gsh_lttng/fsal_mem.h"
-#include "gsh_lttng/fsal_gluster.h"
-#include "gsh_lttng/fsal_ceph.h"
-#endif /* USE_LTTNG */
-
 #ifdef USE_MONITORING
 #include "monitoring.h"
-#endif  /* USE_MONITORING */
+#endif /* USE_MONITORING */
+
+#ifdef LINUX
+#include <sys/prctl.h>
+#ifndef PR_SET_IO_FLUSHER
+#define PR_SET_IO_FLUSHER 57
+#endif
+#endif
 
 /* parameters for NFSd startup and default values */
 
-static nfs_start_info_t my_nfs_start_info = {
-	.dump_default_config = false,
-	.lw_mark_trigger = false,
-	.drop_caps = true
-};
+static nfs_start_info_t my_nfs_start_info = { .dump_default_config = false,
+					      .lw_mark_trigger = false,
+					      .drop_caps = true };
 
 config_file_t nfs_config_struct;
 char *nfs_host_name = "localhost";
@@ -95,7 +71,13 @@ bool config_errors_fatal;
 
 /* command line syntax */
 
-static const char options[] = "v@L:N:S:f:p:FRTE:ChI:x";
+#ifdef USE_LTTNG
+#define LTTNG_OPTION "G"
+#else
+#define LTTNG_OPTION
+#endif /* USE_LTTNG */
+
+static const char options[] = "v@L:N:S:f:p:FRTE:ChI:x" LTTNG_OPTION;
 static const char usage[] =
 	"Usage: %s [-hd][-L <logfile>][-N <dbg_lvl>][-f <config_file>]\n"
 	"\t[-v]                display version information\n"
@@ -112,13 +94,17 @@ static const char usage[] =
 	"\t[-C]                dump trace when segfault\n"
 	"\t[-x]                fatal exit if there are config errors on startup\n"
 	"\t[-h]                display this help\n"
+#ifdef USE_LTTNG
+	"\t[-G]                Load LTTNG traces\n"
+#endif /* USE_LTTNG */
 	"----------------- Signals ----------------\n"
 	"SIGHUP     : Reload LOG and EXPORT config\n"
 	"SIGTERM    : Cleanly terminate the program\n"
 	"------------- Default Values -------------\n"
 	"LogFile    : SYSLOG\n"
-	"PidFile    : "GANESHA_PIDFILE_PATH"\n"
-	"DebugLevel : NIV_EVENT\n" "ConfigFile : "GANESHA_CONFIG_PATH"\n";
+	"PidFile    : " GANESHA_PIDFILE_PATH "\n"
+	"DebugLevel : NIV_EVENT\n"
+	"ConfigFile : " GANESHA_CONFIG_PATH "\n";
 
 static inline char *main_strdup(const char *var, const char *str)
 {
@@ -134,8 +120,8 @@ static inline char *main_strdup(const char *var, const char *str)
 
 static int valid_stack_size(unsigned long stack_size)
 {
-	static unsigned long valid_sizes[] = {
-		16, 32, 64, 128, 256, 512, 1024, 2048, 4096, 8192 };
+	static unsigned long valid_sizes[] = { 16,  32,	  64,	128,  256,
+					       512, 1024, 2048, 4096, 8192 };
 	for (unsigned int i = 0;
 	     i < sizeof(valid_sizes) / sizeof(valid_sizes[0]); i++)
 		if (valid_sizes[i] == stack_size)
@@ -143,6 +129,36 @@ static int valid_stack_size(unsigned long stack_size)
 	return 0;
 }
 
+#ifdef USE_LTTNG
+
+static void load_lttng(void)
+{
+	void *dl = NULL;
+#if defined(LINUX) && !defined(SANITIZE_ADDRESS)
+	dl = dlopen("libganesha_trace.so",
+		    RTLD_NOW | RTLD_LOCAL | RTLD_DEEPBIND);
+#elif defined(BSDBASED) || defined(SANITIZE_ADDRESS)
+	dl = dlopen("libganesha_trace.so", RTLD_NOW | RTLD_LOCAL);
+#endif
+	if (dl == NULL) {
+		fprintf(stderr, "Failed to load libganesha_trace.so\n");
+		exit(1);
+	}
+
+#if defined(LINUX) && !defined(SANITIZE_ADDRESS)
+	dl = dlopen("libntirpc_tracepoints.so",
+		    RTLD_NOW | RTLD_LOCAL | RTLD_DEEPBIND);
+#elif defined(BSDBASED) || defined(SANITIZE_ADDRESS)
+	dl = dlopen("libntirpc_tracepoints.so", RTLD_NOW | RTLD_LOCAL);
+#endif
+	if (dl == NULL) {
+		fprintf(stderr, "Failed to load libntirpc_tracepoints.so\n");
+		exit(1);
+	}
+}
+
+#endif /* USE_LTTNG */
+
 /**
  * main: simply the main function.
  *
@@ -162,7 +178,7 @@ int main(int argc, char *argv[])
 	int c;
 	int dsc;
 	int rc;
-	int pidfile = -1;               /* fd for file to store pid */
+	int pidfile = -1; /* fd for file to store pid */
 	unsigned long stack_size = 8388608; /* 8M, glibc's default */
 	char *log_path = NULL;
 	char *exec_name = "nfs-ganesha";
@@ -178,7 +194,7 @@ int main(int argc, char *argv[])
 
 	/* Set the server's boot time and epoch */
 	now(&nfs_ServerBootTime);
-	nfs_ServerEpoch = (time_t) nfs_ServerBootTime.tv_sec;
+	nfs_ServerEpoch = (time_t)nfs_ServerBootTime.tv_sec;
 	srand(nfs_ServerEpoch);
 
 	tempo_exec_name = strrchr(argv[0], '/');
@@ -217,6 +233,11 @@ int main(int argc, char *argv[])
 			/* Default Log */
 			log_path = main_strdup("log_path", optarg);
 			break;
+#ifdef USE_LTTNG
+		case 'G':
+			load_lttng();
+			break;
+#endif /* USE_LTTNG */
 
 		case 'N':
 			/* debug level */
@@ -279,7 +300,7 @@ int main(int argc, char *argv[])
 			break;
 
 		case 'E':
-			nfs_ServerEpoch = (time_t) atoll(optarg);
+			nfs_ServerEpoch = (time_t)atoll(optarg);
 			break;
 
 		case 'I':
@@ -304,13 +325,12 @@ int main(int argc, char *argv[])
 	nfs_prereq_init(exec_name, nfs_host_name, debug_level, log_path,
 			dump_trace, stack_size);
 #if GANESHA_BUILD_RELEASE
-	LogEvent(COMPONENT_MAIN, "%s Starting: Ganesha Version %s",
-		 exec_name, GANESHA_VERSION);
+	LogEvent(COMPONENT_MAIN, "%s Starting: Ganesha Version %s", exec_name,
+		 GANESHA_VERSION);
 #else
-	LogEvent(COMPONENT_MAIN, "%s Starting: %s",
-		 exec_name,
-		 "Ganesha Version " _GIT_DESCRIBE ", built at "
-		 __DATE__ " " __TIME__ " on " BUILD_HOST);
+	LogEvent(COMPONENT_MAIN, "%s Starting: %s", exec_name,
+		 "Ganesha Version " _GIT_DESCRIBE ", built at " __DATE__
+		 " " __TIME__ " on " BUILD_HOST);
 #endif
 
 	/* initialize nfs_init */
@@ -336,18 +356,20 @@ int main(int argc, char *argv[])
 		switch (son_pid = fork()) {
 		case -1:
 			/* Fork failed */
-			LogFatal(COMPONENT_MAIN,
-				 "Could not start nfs daemon (fork error %d (%s)",
-				 errno, strerror(errno));
+			LogFatal(
+				COMPONENT_MAIN,
+				"Could not start nfs daemon (fork error %d (%s)",
+				errno, strerror(errno));
 			break;
 
 		case 0:
 			/* This code is within the son (that will actually work)
 			 * Let's make it the leader of its group of process */
 			if (setsid() == -1) {
-				LogFatal(COMPONENT_MAIN,
-					 "Could not start nfs daemon (setsid error %d (%s)",
-					 errno, strerror(errno));
+				LogFatal(
+					COMPONENT_MAIN,
+					"Could not start nfs daemon (setsid error %d (%s)",
+					errno, strerror(errno));
 			}
 
 			/* stdin, stdout and stderr should not refer to a tty
@@ -361,7 +383,7 @@ int main(int argc, char *argv[])
 			if (close(STDIN_FILENO) == -1)
 				LogEvent(COMPONENT_MAIN,
 					 "Error while closing stdin: %d (%s)",
-					  errno, strerror(errno));
+					 errno, strerror(errno));
 			else {
 				LogEvent(COMPONENT_MAIN, "stdin closed");
 				dup(dev_null_fd);
@@ -370,7 +392,7 @@ int main(int argc, char *argv[])
 			if (close(STDOUT_FILENO) == -1)
 				LogEvent(COMPONENT_MAIN,
 					 "Error while closing stdout: %d (%s)",
-					  errno, strerror(errno));
+					 errno, strerror(errno));
 			else {
 				LogEvent(COMPONENT_MAIN, "stdout closed");
 				dup(dev_null_fd);
@@ -379,16 +401,17 @@ int main(int argc, char *argv[])
 			if (close(STDERR_FILENO) == -1)
 				LogEvent(COMPONENT_MAIN,
 					 "Error while closing stderr: %d (%s)",
-					  errno, strerror(errno));
+					 errno, strerror(errno));
 			else {
 				LogEvent(COMPONENT_MAIN, "stderr closed");
 				dup(dev_null_fd);
 			}
 
 			if (close(dev_null_fd) == -1)
-				LogFatal(COMPONENT_MAIN,
-					 "Could not close tmp fd to /dev/null: %d (%s)",
-					 errno, strerror(errno));
+				LogFatal(
+					COMPONENT_MAIN,
+					"Could not close tmp fd to /dev/null: %d (%s)",
+					errno, strerror(errno));
 
 			/* In the child process, change the log header
 			 * if not, the header will contain the parent's pid */
@@ -399,8 +422,7 @@ int main(int argc, char *argv[])
 			/* This code is within the parent process,
 			 * it is useless, it must die */
 			LogFullDebug(COMPONENT_MAIN,
-				     "Starting a child of pid %d",
-				     son_pid);
+				     "Starting a child of pid %d", son_pid);
 			exit(0);
 			break;
 		}
@@ -416,11 +438,12 @@ int main(int argc, char *argv[])
 	/* Echo our PID into pidfile: this serves as a lock to prevent */
 	/* multiple instances from starting, so any failure creating   */
 	/* this file is a fatal error.                                 */
-	pidfile = open(nfs_pidfile_path, O_CREAT | O_RDWR, 0644);
+	pidfile = open(nfs_pidfile_path, O_CREAT | O_RDWR | O_TRUNC, 0644);
 	if (pidfile == -1) {
-		LogFatal(COMPONENT_MAIN,
+		LogFatal(
+			COMPONENT_MAIN,
 			"open(%s, O_CREAT | O_RDWR, 0644) failed for pid file, errno was: %s (%d)",
-			 nfs_pidfile_path, strerror(errno), errno);
+			nfs_pidfile_path, strerror(errno), errno);
 		goto fatal_die;
 	} else {
 		struct flock lk;
@@ -429,12 +452,12 @@ int main(int argc, char *argv[])
 		/* Ganesha may already be running.                         */
 		lk.l_type = F_WRLCK;
 		lk.l_whence = SEEK_SET;
-		lk.l_start = (off_t) 0;
-		lk.l_len = (off_t) 0;
+		lk.l_start = (off_t)0;
+		lk.l_len = (off_t)0;
 		if (fcntl(pidfile, F_SETLK, &lk) == -1) {
 			LogFatal(COMPONENT_MAIN,
-				"fcntl(%d) failed, Ganesha already started",
-				pidfile);
+				 "fcntl(%d) failed, Ganesha already started",
+				 pidfile);
 			goto fatal_die;
 		}
 
@@ -442,7 +465,8 @@ int main(int argc, char *argv[])
 		/* to ensure it winds up on the disk.                 */
 		if (dprintf(pidfile, "%u\n", getpid()) < 0 ||
 		    fsync(pidfile) < 0) {
-			LogFatal(COMPONENT_MAIN,
+			LogFatal(
+				COMPONENT_MAIN,
 				"dprintf() or fsync() failed trying to write pid to file %s errno was: %s (%d)",
 				nfs_pidfile_path, strerror(errno), errno);
 			goto fatal_die;
@@ -459,9 +483,24 @@ int main(int argc, char *argv[])
 	if (pthread_sigmask(SIG_BLOCK, &signals_to_block, NULL) != 0) {
 		LogFatal(COMPONENT_MAIN,
 			 "Could not start nfs daemon, pthread_sigmask failed");
-			goto fatal_die;
+		goto fatal_die;
 	}
 
+#ifdef LINUX
+	/* Set thread I/O flusher, see
+	 * https://git.kernel.org/torvalds/p/8d19f1c8e1937baf74e1962aae9f90fa3aeab463
+	 */
+	if (prctl(PR_SET_IO_FLUSHER, 1, 0, 0, 0) == -1) {
+		if (errno != EINVAL) {
+			LogFatal(
+				COMPONENT_MAIN,
+				"Error setting prctl PR_SET_IO_FLUSHER flag: %s",
+				strerror(errno));
+			goto fatal_die;
+		}
+	}
+#endif
+
 	/* init URL package */
 	config_url_init();
 
@@ -472,8 +511,7 @@ int main(int argc, char *argv[])
 	/* Parse the configuration file so we all know what is going on. */
 
 	if (nfs_config_path == NULL || nfs_config_path[0] == '\0') {
-		LogWarn(COMPONENT_INIT,
-			"No configuration file named.");
+		LogWarn(COMPONENT_INIT, "No configuration file named.");
 		nfs_config_struct = NULL;
 	} else
 		nfs_config_struct =
@@ -483,16 +521,14 @@ int main(int argc, char *argv[])
 		char *errstr = err_type_str(&err_type);
 
 		if (!config_error_is_harmless(&err_type)) {
-			LogCrit(COMPONENT_INIT,
-				 "Error %s while parsing (%s)",
-				 errstr != NULL ? errstr : "unknown",
-				 nfs_config_path);
+			LogCrit(COMPONENT_INIT, "Error %s while parsing (%s)",
+				errstr != NULL ? errstr : "unknown",
+				nfs_config_path);
 			if (errstr != NULL)
 				gsh_free(errstr);
 			goto fatal_die;
 		} else
-			LogWarn(COMPONENT_INIT,
-				"Error %s while parsing (%s)",
+			LogWarn(COMPONENT_INIT, "Error %s while parsing (%s)",
 				errstr != NULL ? errstr : "unknown",
 				nfs_config_path);
 		if (errstr != NULL)
@@ -501,7 +537,7 @@ int main(int argc, char *argv[])
 
 	if (read_log_config(nfs_config_struct, &err_type) < 0) {
 		LogCrit(COMPONENT_INIT,
-			 "Error while parsing log configuration");
+			"Error while parsing log configuration");
 		goto fatal_die;
 	}
 
@@ -509,29 +545,27 @@ int main(int argc, char *argv[])
 	 * the list available at exports parsing time.
 	 */
 	if (start_fsals(nfs_config_struct, &err_type) < 0) {
-		LogCrit(COMPONENT_INIT,
-			 "Error starting FSALs.");
+		LogCrit(COMPONENT_INIT, "Error starting FSALs.");
 		goto fatal_die;
 	}
 
 	/* parse configuration file */
 
-	if (nfs_set_param_from_conf(nfs_config_struct,
-				    &my_nfs_start_info,
+	if (nfs_set_param_from_conf(nfs_config_struct, &my_nfs_start_info,
 				    &err_type)) {
 		LogCrit(COMPONENT_INIT,
-			 "Error setting parameters from configuration file.");
+			"Error setting parameters from configuration file.");
 		goto fatal_die;
 	}
 
 #ifdef USE_MONITORING
-	monitoring_init(nfs_param.core_param.monitoring_port);
-#endif  /* USE_MONITORING */
+	monitoring__init(nfs_param.core_param.monitoring_port,
+			 nfs_param.core_param.enable_dynamic_metrics);
+#endif /* USE_MONITORING */
 
 	/* initialize core subsystems and data structures */
 	if (init_server_pkgs() != 0) {
-		LogCrit(COMPONENT_INIT,
-			"Failed to initialize server packages");
+		LogCrit(COMPONENT_INIT, "Failed to initialize server packages");
 		goto fatal_die;
 	}
 	/* Load Data Server entries from parsed file
@@ -539,8 +573,7 @@ int main(int argc, char *argv[])
 	 */
 	dsc = ReadDataServers(nfs_config_struct, &err_type);
 	if (dsc < 0) {
-		LogCrit(COMPONENT_INIT,
-			"Error while parsing DS entries");
+		LogCrit(COMPONENT_INIT, "Error while parsing DS entries");
 		goto fatal_die;
 	}
 
@@ -550,7 +583,7 @@ int main(int argc, char *argv[])
 	rc = nfs4_recovery_init();
 	if (rc) {
 		LogCrit(COMPONENT_INIT,
-			  "Recovery backend initialization failed!");
+			"Recovery backend initialization failed!");
 		goto fatal_die;
 	}
 
@@ -565,8 +598,7 @@ int main(int argc, char *argv[])
 	 */
 	rc = ReadExports(nfs_config_struct, &err_type);
 	if (rc < 0) {
-		LogCrit(COMPONENT_INIT,
-			  "Error while parsing export entries");
+		LogCrit(COMPONENT_INIT, "Error while parsing export entries");
 		goto fatal_die;
 	}
 	if (rc == 0 && dsc == 0)
@@ -600,7 +632,7 @@ int main(int argc, char *argv[])
 	return 0;
 
 fatal_die:
-	(void) report_config_errors(&err_type, NULL, config_errs_to_log);
+	(void)report_config_errors(&err_type, NULL, config_errs_to_log);
 
 	if (tempo_exec_name)
 		free(exec_name);
@@ -612,8 +644,7 @@ fatal_die:
 	/* systemd journal won't display our errors without this */
 	sleep(1);
 
-	LogFatal(COMPONENT_INIT,
-		 "Fatal errors.  Server exiting...");
+	LogFatal(COMPONENT_INIT, "Fatal errors.  Server exiting...");
 	/* NOT REACHED */
 	return 2;
 }
