@@ -61,16 +61,21 @@ static int reap_hash_table(hash_table_t *ht_reap)
 
 	/* For each bucket of the requested hashtable */
 	for (i = 0; i < ht_reap->parameter.index_size; i++) {
+		/* Before starting with traversal of RBT in the bucket,
+		 * if the expired client list gets filled, need reap it first
+		 */
+		count += reap_expired_client_list(NULL);
 		head_rbt = &ht_reap->partitions[i].rbt;
-
 restart:
 		/* acquire mutex */
 		PTHREAD_RWLOCK_wrlock(&ht_reap->partitions[i].ht_lock);
 
 		/* go through all entries in the red-black-tree */
-		RBT_LOOP(head_rbt, pn) {
+		RBT_LOOP(head_rbt, pn)
+		{
 			char str[LOG_BUFF_LEN] = "\0";
-			struct display_buffer dspbuf = {sizeof(str), str, str};
+			struct display_buffer dspbuf = { sizeof(str), str,
+							 str };
 			bool str_valid = false;
 
 			addr = RBT_OPAQ(pn);
@@ -80,7 +85,8 @@ restart:
 
 			PTHREAD_MUTEX_lock(&client_id->cid_mutex);
 
-			if (valid_lease(client_id)) {
+			if (client_id->marked_for_delayed_cleanup ||
+			    valid_lease(client_id, false)) {
 				PTHREAD_MUTEX_unlock(&client_id->cid_mutex);
 				RBT_INCREMENT(pn);
 				continue;
@@ -89,7 +95,7 @@ restart:
 			if (isDebug(COMPONENT_CLIENTID)) {
 				display_client_id_rec(&dspbuf, client_id);
 				LogFullDebug(COMPONENT_CLIENTID,
-					     "Expire index %d %s", i, str);
+					     "Expired index %d %s", i, str);
 				str_valid = true;
 			}
 
@@ -97,17 +103,22 @@ restart:
 			client_rec = client_id->cid_client_record;
 
 			/* get a ref to client_id as we might drop the
-			 * last reference with expiring. This also protects the
-			 * reference to the client_record.
+			 * last reference while expiring. This also protects
+			 * the reference to the client_record.
 			 */
 			inc_client_id_ref(client_id);
 
 			PTHREAD_MUTEX_unlock(&client_id->cid_mutex);
 			PTHREAD_RWLOCK_unlock(&ht_reap->partitions[i].ht_lock);
 
+			/* Before expiring the current client in RBT node,
+			 * if the expired client list gets filled, need reap it
+			 */
+			count += reap_expired_client_list(NULL);
+
 			PTHREAD_MUTEX_lock(&client_rec->cr_mutex);
 
-			nfs_client_id_expire(client_id, false);
+			nfs_client_id_expire(client_id, false, false);
 
 			PTHREAD_MUTEX_unlock(&client_rec->cr_mutex);
 
@@ -115,9 +126,17 @@ restart:
 				if (!str_valid)
 					display_printf(&dspbuf, "clientid %p",
 						       client_id);
-
-				LogFullDebug(COMPONENT_CLIENTID,
-					     "Reaper done, expired {%s}", str);
+				if (client_id->marked_for_delayed_cleanup) {
+					LogFullDebug(
+						COMPONENT_CLIENTID,
+						"Reaper, Parked for later cleanup {%s}",
+						str);
+				} else {
+					LogFullDebug(
+						COMPONENT_CLIENTID,
+						"Reaper done, expired {%s}",
+						str);
+				}
 			}
 
 			/* drop our reference to the client_id */
@@ -146,8 +165,9 @@ static int reap_expired_open_owners(void)
 	 * process, and thus prevent them from expiring.
 	 */
 	while (true) {
-		owner = glist_first_entry(&cached_open_owners, state_owner_t,
-				so_owner.so_nfs4_owner.so_cache_entry);
+		owner = glist_first_entry(
+			&cached_open_owners, state_owner_t,
+			so_owner.so_nfs4_owner.so_cache_entry);
 
 		if (owner == NULL)
 			break;
@@ -158,15 +178,15 @@ static int reap_expired_open_owners(void)
 			/* This owner has not yet expired. */
 			if (isFullDebug(COMPONENT_STATE)) {
 				char str[LOG_BUFF_LEN] = "\0";
-				struct display_buffer dspbuf = {
-						sizeof(str), str, str};
+				struct display_buffer dspbuf = { sizeof(str),
+								 str, str };
 
 				display_owner(&dspbuf, owner);
 
-				LogFullDebug(COMPONENT_STATE,
-					     "Did not release CLOSE_PENDING %d seconds left for {%s}",
-					     (int) (texpire - tnow),
-					     str);
+				LogFullDebug(
+					COMPONENT_STATE,
+					"Did not release CLOSE_PENDING %d seconds left for {%s}",
+					(int)(texpire - tnow), str);
 			}
 
 			/* Because entries are not moved on this list, and
@@ -200,8 +220,8 @@ static size_t get_current_rss(void)
 	if (page_size == 0) {
 		page_size = sysconf(_SC_PAGESIZE);
 		if (page_size <= 0) {
-			LogEvent(COMPONENT_MEMLEAKS,
-				 "_SC_PAGESIZE failed, %d", errno);
+			LogEvent(COMPONENT_MEMLEAKS, "_SC_PAGESIZE failed, %d",
+				 errno);
 			return 0;
 		}
 	}
@@ -218,7 +238,7 @@ static size_t get_current_rss(void)
 	rc = sscanf(buf, "%ld %ld", &vsize, &rss);
 	if (rc != 2) {
 		LogEvent(COMPONENT_MEMLEAKS,
-			"Failed to read data from /proc/self/statm");
+			 "Failed to read data from /proc/self/statm");
 	}
 out:
 	close(fd);
@@ -235,8 +255,7 @@ static void reap_malloc_frag(void)
 		trim_threshold = min_threshold;
 
 	rss = get_current_rss();
-	LogDebug(COMPONENT_MEMLEAKS,
-		 "current rss: %zu MB, threshold: %zu MB",
+	LogDebug(COMPONENT_MEMLEAKS, "current rss: %zu MB, threshold: %zu MB",
 		 rss, trim_threshold);
 
 	if (rss < trim_threshold) {
@@ -301,9 +320,9 @@ static void reaper_run(struct fridgethr_context *ctx)
 #endif
 	}
 
-	rst->count =
-	    (reap_hash_table(ht_confirmed_client_id) +
-	     reap_hash_table(ht_unconfirmed_client_id));
+	rst->count = reap_expired_client_list(NULL);
+	rst->count += (reap_hash_table(ht_confirmed_client_id) +
+		       reap_hash_table(ht_unconfirmed_client_id));
 
 	rst->count += reap_expired_open_owners();
 
@@ -355,9 +374,8 @@ void reaper_wake(void)
 
 int reaper_shutdown(void)
 {
-	int rc = fridgethr_sync_command(reaper_fridge,
-					fridgethr_comm_stop,
-					120);
+	int rc =
+		fridgethr_sync_command(reaper_fridge, fridgethr_comm_stop, 120);
 
 	if (rc == ETIMEDOUT) {
 		LogMajor(COMPONENT_CLIENTID,
