@@ -33,7 +33,7 @@
 #include <string.h>
 #include <pthread.h>
 #include <fcntl.h>
-#include <sys/file.h>		/* for having FNDELAY */
+#include <sys/file.h> /* for having FNDELAY */
 #include "hashtable.h"
 #include "log.h"
 #include "fsal.h"
@@ -46,23 +46,39 @@
 #include "export_mgr.h"
 #include "sal_functions.h"
 
-static void nfs_read_ok(nfs_res_t *res, char *data, uint32_t read_size,
-			struct fsal_obj_handle *obj, int eof)
+static void nfs_read_ok(READ3resok *resok, struct fsal_io_arg *read_arg,
+			struct fsal_obj_handle *obj)
 {
-	if ((read_size == 0) && (data != NULL)) {
-		gsh_free(data);
-		data = NULL;
+	/* Build Post Op Attributes */
+	nfs_SetPostOpAttr(obj, &resok->file_attributes, NULL);
+
+	resok->count = read_arg->io_amount;
+	resok->eof = read_arg->end_of_file;
+
+	if (read_arg->io_amount == 0) {
+		/* We won't need the FSAL's iovec and buffers if it used them */
+		if (read_arg->iov_release != NULL)
+			read_arg->iov_release(read_arg->release_data);
+
+		/* We will use the iov we set up before the call, but set the
+		 * length of the buffer to 0. The io_data->release is already
+		 * set up.
+		 */
+		resok->data.iov[0].iov_len = 0;
+		return;
 	}
 
-	/* Build Post Op Attributes */
-	nfs_SetPostOpAttr(obj,
-			  &res->res_read3.READ3res_u.resok.file_attributes,
-			  NULL);
+	if (read_arg->iov != resok->data.iov) {
+		/* FSAL returned a different iovector */
+		resok->data.iov = read_arg->iov;
+		resok->data.iovcnt = read_arg->iov_count;
+	}
 
-	res->res_read3.READ3res_u.resok.eof = eof;
-	res->res_read3.READ3res_u.resok.count = read_size;
-	res->res_read3.READ3res_u.resok.data.data_val = data;
-	res->res_read3.READ3res_u.resok.data.data_len = read_size;
+	if (read_arg->iov_release != resok->data.release) {
+		/* The FSAL replaced the release */
+		resok->data.release = read_arg->iov_release;
+		resok->data.release_data = read_arg->release_data;
+	}
 }
 
 struct nfs3_read_data {
@@ -84,13 +100,12 @@ static int nfs3_complete_read(struct nfs3_read_data *data)
 {
 	struct fsal_io_arg *read_arg = &data->read_arg;
 	READ3resfail *resfail = &data->res->res_read3.READ3res_u.resfail;
-	int i;
 
 	if (data->rc == NFS_REQ_OK) {
 		if (!op_ctx->fsal_export->exp_ops.fs_supports(
-		     op_ctx->fsal_export, fso_compliant_eof_behavior)
-			&& nfs_param.core_param.getattrs_in_complete_read
-		    && !read_arg->end_of_file) {
+			    op_ctx->fsal_export, fso_compliant_eof_behavior) &&
+		    nfs_param.core_param.getattrs_in_complete_read &&
+		    !read_arg->end_of_file) {
 			/*
 			 * NFS requires to set the EOF flag for all reads that
 			 * reach the EOF, i.e., even the ones returning data.
@@ -108,24 +123,25 @@ static int nfs3_complete_read(struct nfs3_read_data *data)
 
 			if (FSAL_IS_SUCCESS(status)) {
 				read_arg->end_of_file = (read_arg->offset +
-							 read_arg->io_amount)
-							>= attrs.filesize;
+							 read_arg->io_amount) >=
+							attrs.filesize;
 			}
 
 			/* Done with the attrs */
 			fsal_release_attrs(&attrs);
 		}
 
-		nfs_read_ok(data->res, read_arg->iov[0].iov_base,
-			    read_arg->io_amount, data->obj,
-			    read_arg->end_of_file);
+		nfs_read_ok(&data->res->res_read3.READ3res_u.resok, read_arg,
+			    data->obj);
 
 		goto out;
 	}
 
-	for (i = 0; i < read_arg->iov_count; ++i) {
-		gsh_free(read_arg->iov[i].iov_base);
-	}
+	/* Just in case... We won't need the FSAL's iovec and buffers if it used
+	 * them
+	 */
+	if (read_arg->iov_release != NULL)
+		read_arg->iov_release(read_arg->release_data);
 
 	/* If we are here, there was an error */
 	if (data->rc == NFS_REQ_DROP) {
@@ -137,19 +153,19 @@ static int nfs3_complete_read(struct nfs3_read_data *data)
 	/* Now we convert NFS_REQ_ERROR into NFS_REQ_OK */
 	data->rc = NFS_REQ_OK;
 
- out:
+out:
 	/* return references */
 	if (data->obj)
 		data->obj->obj_ops->put_ref(data->obj);
 
-	server_stats_io_done(read_arg->iov[0].iov_len, read_arg->io_amount,
-			     (data->rc == NFS_REQ_OK) ?  true : false, false);
+	server_stats_io_done(read_arg->io_request, read_arg->io_amount,
+			     (data->rc == NFS_REQ_OK) ? true : false, false);
 
 	return data->rc;
 }
 
 static void nfs3_read_cb(struct fsal_obj_handle *obj, fsal_status_t ret,
-			  void *read_data, void *caller_data);
+			 void *read_data, void *caller_data);
 
 static enum xprt_stat nfs3_read_resume(struct svc_req *req)
 {
@@ -163,9 +179,8 @@ static enum xprt_stat nfs3_read_resume(struct svc_req *req)
 
 	if (data->read_arg.fsal_resume) {
 		/* FSAL is requesting another read2 call on resume */
-		atomic_postclear_uint32_t_bits(&data->flags,
-					       ASYNC_PROC_EXIT |
-					       ASYNC_PROC_DONE);
+		atomic_postclear_uint32_t_bits(
+			&data->flags, ASYNC_PROC_EXIT | ASYNC_PROC_DONE);
 
 		data->obj->obj_ops->read2(data->obj, true, nfs3_read_cb,
 					  &data->read_arg, data);
@@ -173,8 +188,8 @@ static enum xprt_stat nfs3_read_resume(struct svc_req *req)
 		/* Only atomically set the flags if we actually call read2,
 		 * otherwise we will have indicated as having been DONE.
 		 */
-		flags =
-		    atomic_postset_uint32_t_bits(&data->flags, ASYNC_PROC_EXIT);
+		flags = atomic_postset_uint32_t_bits(&data->flags,
+						     ASYNC_PROC_EXIT);
 
 		if ((flags & ASYNC_PROC_DONE) != ASYNC_PROC_DONE) {
 			/* The read was not finished before we got here. When
@@ -211,7 +226,7 @@ static enum xprt_stat nfs3_read_resume(struct svc_req *req)
  * @param[in] caller_data	Data for caller
  */
 static void nfs3_read_cb(struct fsal_obj_handle *obj, fsal_status_t ret,
-			  void *read_data, void *caller_data)
+			 void *read_data, void *caller_data)
 {
 	struct nfs3_read_data *data = caller_data;
 	uint32_t flags;
@@ -248,6 +263,11 @@ static void nfs3_read_cb(struct fsal_obj_handle *obj, fsal_status_t ret,
 	}
 }
 
+static void read3_io_data_release(void *release_data)
+{
+	/* Nothing to do */
+}
+
 /**
  *
  * @brief The NFSPROC3_READ
@@ -268,7 +288,7 @@ int nfs3_read(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 {
 	struct fsal_obj_handle *obj;
 	pre_op_attr pre_attr;
-	fsal_status_t fsal_status = {0, 0};
+	fsal_status_t fsal_status = { 0, 0 };
 	uint64_t offset = arg->arg_read3.offset;
 	size_t size = arg->arg_read3.count;
 	uint64_t MaxRead = atomic_fetch_uint64_t(&op_ctx->ctx_export->MaxRead);
@@ -280,22 +300,18 @@ int nfs3_read(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 	nfs_request_t *reqdata = container_of(req, nfs_request_t, svc);
 	int rc = NFS_REQ_OK;
 	uint32_t flags;
+	READ3resok *resok = &res->res_read3.READ3res_u.resok;
 
 	LogNFS3_Operation(COMPONENT_NFSPROTO, req, &arg->arg_read3.file,
-		" start: %"PRIx64 " len: %zu",
-		offset, size);
+			  " start: %" PRIx64 " len: %zu", offset, size);
 
 	/* to avoid setting it on each error case */
-	resfail->file_attributes.attributes_follow =  FALSE;
+	resfail->file_attributes.attributes_follow = FALSE;
 
 	/* initialize for read of size 0 */
-	res->res_read3.READ3res_u.resok.eof = FALSE;
-	res->res_read3.READ3res_u.resok.count = 0;
-	res->res_read3.READ3res_u.resok.data.data_val = NULL;
-	res->res_read3.READ3res_u.resok.data.data_len = 0;
-	res->res_read3.status = NFS3_OK;
-	obj = nfs3_FhandleToCache(&arg->arg_read3.file,
-				  &res->res_read3.status, &rc);
+	memset(&res->res_read3, 0, sizeof(res->res_read3));
+	obj = nfs3_FhandleToCache(&arg->arg_read3.file, &res->res_read3.status,
+				  &rc);
 
 	if (obj == NULL) {
 		/* Status and rc have been set by nfs3_FhandleToCache */
@@ -305,15 +321,14 @@ int nfs3_read(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 
 	nfs_SetPreOpAttr(obj, &pre_attr);
 
-	fsal_status =
-	    obj->obj_ops->test_access(obj, FSAL_READ_ACCESS, NULL, NULL, true);
+	fsal_status = obj->obj_ops->test_access(obj, FSAL_READ_ACCESS, NULL,
+						NULL, true);
 
 	if (fsal_status.major == ERR_FSAL_ACCESS) {
 		/* Test for execute permission */
-		fsal_status = fsal_access(obj,
-				       FSAL_MODE_MASK_SET(FSAL_X_OK) |
-				       FSAL_ACE4_MASK_SET
-				       (FSAL_ACE_PERM_EXECUTE));
+		fsal_status = fsal_access(
+			obj, FSAL_MODE_MASK_SET(FSAL_X_OK) |
+				     FSAL_ACE4_MASK_SET(FSAL_ACE_PERM_EXECUTE));
 	}
 
 	if (FSAL_IS_ERROR(fsal_status)) {
@@ -339,11 +354,11 @@ int nfs3_read(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 			     offset, size, MaxOffsetRead);
 
 		if ((offset + size) > MaxOffsetRead) {
-			LogEvent(COMPONENT_NFSPROTO,
-				 "A client tried to violate max file size %"
-				 PRIu64 " for exportid #%hu",
-				 MaxOffsetRead,
-				 op_ctx->ctx_export->export_id);
+			LogEvent(
+				COMPONENT_NFSPROTO,
+				"A client tried to violate max file size %" PRIu64
+				" for exportid #%hu",
+				MaxOffsetRead, op_ctx->ctx_export->export_id);
 
 			res->res_read3.status = NFS3ERR_FBIG;
 
@@ -363,7 +378,11 @@ int nfs3_read(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 	}
 
 	if (size == 0) {
-		nfs_read_ok(res, NULL, 0, obj, 0);
+		struct fsal_io_arg read_arg;
+
+		memset(&read_arg, 0, sizeof(read_arg));
+
+		nfs_read_ok(&res->res_read3.READ3res_u.resok, &read_arg, obj);
 		goto return_ok;
 	}
 
@@ -373,18 +392,28 @@ int nfs3_read(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 		goto return_ok;
 	}
 
-	/* Set up args, allocate from heap, iov_count will be 1 */
-	read_data = gsh_calloc(1, sizeof(*read_data) + sizeof(struct iovec));
+	/* Set up result using internal iovec of length 1 that allows FSAL
+	 * layer to allocate the read buffer.
+	 */
+	resok->data.data_len = size;
+	resok->data.iovcnt = 1;
+	resok->data.iov = &resok->iov0;
+	resok->data.iov[0].iov_len = size;
+	resok->data.iov[0].iov_base = NULL;
+	resok->data.last_iov_buf_size = 0;
+	resok->data.release = read3_io_data_release;
+
+	/* Set up args, allocate from heap */
+	read_data = gsh_calloc(1, sizeof(*read_data));
 	read_arg = &read_data->read_arg;
 
 	read_arg->info = NULL;
 	/** @todo for now pass NULL state */
 	read_arg->state = NULL;
 	read_arg->offset = offset;
-	read_arg->iov_count = 1;
-	read_arg->iov[0].iov_len = size;
-	/* Must allocate buffer as a multiple of BYTES_PER_XDR_UNIT */
-	read_arg->iov[0].iov_base = gsh_malloc(RNDUP(size));
+	read_arg->iov_count = resok->data.iovcnt;
+	read_arg->iov = resok->data.iov;
+	read_arg->last_iov_buf_size = &resok->data.last_iov_buf_size;
 	read_arg->io_amount = 0;
 	read_arg->end_of_file = false;
 
@@ -397,13 +426,13 @@ int nfs3_read(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 again:
 
 	/* Do the actual read */
-	obj->obj_ops->read2(obj, true, nfs3_read_cb, read_arg, read_data);
+	fsal_read2(obj, true, nfs3_read_cb, read_arg, read_data);
 
 	/* Only atomically set the flags if we actually call read2, otherwise
 	 * we will have indicated as having been DONE.
 	 */
-	flags =
-	    atomic_postset_uint32_t_bits(&read_data->flags, ASYNC_PROC_EXIT);
+	flags = atomic_postset_uint32_t_bits(&read_data->flags,
+					     ASYNC_PROC_EXIT);
 
 	if ((flags & ASYNC_PROC_DONE) != ASYNC_PROC_DONE) {
 		/* The read was not finished before we got here. When the
@@ -417,9 +446,8 @@ again:
 
 	if (read_arg->fsal_resume) {
 		/* FSAL is requesting another read2 call */
-		atomic_postclear_uint32_t_bits(&read_data->flags,
-					       ASYNC_PROC_EXIT |
-					       ASYNC_PROC_DONE);
+		atomic_postclear_uint32_t_bits(
+			&read_data->flags, ASYNC_PROC_EXIT | ASYNC_PROC_DONE);
 		/* Make the call with the same params, though the FSAL will be
 		 * signaled by fsal_resume being set.
 		 */
@@ -444,7 +472,7 @@ return_ok:
 	server_stats_io_done(size, 0, true, false);
 
 	return NFS_REQ_OK;
-}				/* nfs3_read */
+} /* nfs3_read */
 
 /**
  * @brief Free the result structure allocated for nfs3_read.
@@ -455,8 +483,5 @@ return_ok:
  */
 void nfs3_read_free(nfs_res_t *res)
 {
-	if ((res->res_read3.status == NFS3_OK)
-	    && (res->res_read3.READ3res_u.resok.data.data_len != 0)) {
-		gsh_free(res->res_read3.READ3res_u.resok.data.data_val);
-	}
+	/* Nothing to clean up. */
 }
