@@ -34,6 +34,59 @@
 #include "nfs_convert.h"
 #include "nfs_proto_functions.h"
 
+/**
+ * @brief Bind connection to the session's backchannel
+ */
+static nfsstat4 bind_conn_to_session_backchannel(SVCXPRT *rq_xprt,
+						 nfs41_session_t *session)
+{
+	char session_str[NFS4_SESSIONID_BUFFER_SIZE] = "\0";
+	struct display_buffer db_session = { sizeof(session_str), session_str,
+					     session_str };
+	char xprt_addr_str[SOCK_NAME_MAX] = "\0";
+	struct display_buffer db_xprt = { sizeof(xprt_addr_str), xprt_addr_str,
+					  xprt_addr_str };
+
+	display_session_id(&db_session, session->session_id);
+	display_xprt_sockaddr(&db_xprt, rq_xprt);
+
+	LogInfo(COMPONENT_SESSIONS,
+		"Set up session: %s backchannel and bind it to current xprt FD: %d socket-address: %s",
+		session_str, rq_xprt->xp_fd, xprt_addr_str);
+
+	/* For state-protection other than SP4_NONE, there needs to be further
+	 * validation (RFC 5661 section-2.10.8.3) before backchannel setup.
+	 * Since Ganesha supports only SP4_NONE as of now, we skip processing
+	 * of other mechanisms.
+	 */
+	if (session->clientid_record->cid_state_protect_how == SP4_NONE) {
+		int rc;
+
+		LogInfo(COMPONENT_SESSIONS,
+			"Creating backchannel for session: %s", session_str);
+
+		/* Create backchannel */
+		rc = nfs_rpc_create_chan_v41(
+			rq_xprt, session, session->cb_sec_parms.sec_parms_len,
+			session->cb_sec_parms.sec_parms_val);
+
+		if (unlikely(rc == EINVAL || rc == EPERM))
+			return NFS4ERR_INVAL;
+
+		if (unlikely(rc != 0))
+			return NFS4ERR_SERVERFAULT;
+
+		LogInfo(COMPONENT_SESSIONS,
+			"Created backchannel for session: %s", session_str);
+		return NFS4_OK;
+	}
+	/* We always set SP4_NONE during client-record creation */
+	LogFatal(
+		COMPONENT_SESSIONS,
+		"Only SP4_NONE state protection is supported. Code flow should not reach here");
+	return NFS4ERR_SERVERFAULT;
+}
+
 /**
  * @brief the NFS4_OP_BIND_CONN_TO_SESSION operation
  *
@@ -50,13 +103,18 @@ enum nfs_req_result nfs4_op_bind_conn(struct nfs_argop4 *op,
 				      compound_data_t *data,
 				      struct nfs_resop4 *resp)
 {
-	BIND_CONN_TO_SESSION4args * const arg_BIND_CONN_TO_SESSION4 =
-	    &op->nfs_argop4_u.opbind_conn_to_session;
-	BIND_CONN_TO_SESSION4res * const res_BIND_CONN_TO_SESSION4 =
-	    &resp->nfs_resop4_u.opbind_conn_to_session;
-	BIND_CONN_TO_SESSION4resok * const resok_BIND_CONN_TO_SESSION4 =
-	    &res_BIND_CONN_TO_SESSION4->BIND_CONN_TO_SESSION4res_u.bctsr_resok4;
+	BIND_CONN_TO_SESSION4args *const arg_BIND_CONN_TO_SESSION4 =
+		&op->nfs_argop4_u.opbind_conn_to_session;
+	BIND_CONN_TO_SESSION4res *const res_BIND_CONN_TO_SESSION4 =
+		&resp->nfs_resop4_u.opbind_conn_to_session;
+	BIND_CONN_TO_SESSION4resok *const resok_BIND_CONN_TO_SESSION4 =
+		&res_BIND_CONN_TO_SESSION4->BIND_CONN_TO_SESSION4res_u
+			 .bctsr_resok4;
 	nfs41_session_t *session;
+	channel_dir_from_client4 client_channel_dir;
+	channel_dir_from_server4 server_channel_dir;
+	nfsstat4 bind_to_backchannel;
+	bool added_conn_to_session;
 
 	resp->resop = NFS4_OP_BIND_CONN_TO_SESSION;
 	res_BIND_CONN_TO_SESSION4->bctsr_status = NFS4_OK;
@@ -72,25 +130,25 @@ enum nfs_req_result nfs4_op_bind_conn(struct nfs_argop4 *op,
 		LogDebugAlt(COMPONENT_SESSIONS, COMPONENT_CLIENTID,
 			    "BIND_CONN_TO_SESSION returning status %s",
 			    nfsstat4_to_str(
-				res_BIND_CONN_TO_SESSION4->bctsr_status));
+				    res_BIND_CONN_TO_SESSION4->bctsr_status));
 
 		return NFS_REQ_ERROR;
 	}
 
 	/* session->refcount +1 */
 
-	LogDebug(COMPONENT_SESSIONS,
-		 "BIND_CONN_TO_SESSION session=%p", session);
+	LogDebug(COMPONENT_SESSIONS, "BIND_CONN_TO_SESSION session=%p",
+		 session);
 
 	/* Check if lease is expired and reserve it */
-	if (!reserve_lease_or_expire(session->clientid_record, false)) {
+	if (!reserve_lease_or_expire(session->clientid_record, false, NULL)) {
 		dec_session_ref(session);
 		res_BIND_CONN_TO_SESSION4->bctsr_status = NFS4ERR_EXPIRED;
 
 		LogDebugAlt(COMPONENT_SESSIONS, COMPONENT_CLIENTID,
 			    "BIND_CONN_TO_SESSION returning status %s",
 			    nfsstat4_to_str(
-				res_BIND_CONN_TO_SESSION4->bctsr_status));
+				    res_BIND_CONN_TO_SESSION4->bctsr_status));
 
 		return NFS_REQ_ERROR;
 	}
@@ -104,27 +162,58 @@ enum nfs_req_result nfs4_op_bind_conn(struct nfs_argop4 *op,
 	data->session = session;
 	data->slotid = UINT32_MAX;
 
+	/* Check and bind the connection to session */
+	added_conn_to_session = check_session_conn(session, data, true);
+	if (!added_conn_to_session) {
+		LogWarn(COMPONENT_SESSIONS,
+			"Unable to add connection to the session");
+		res_BIND_CONN_TO_SESSION4->bctsr_status = NFS4ERR_INVAL;
+		return NFS_REQ_ERROR;
+	}
+
 	memcpy(resok_BIND_CONN_TO_SESSION4->bctsr_sessid,
 	       arg_BIND_CONN_TO_SESSION4->bctsa_sessid,
 	       sizeof(resok_BIND_CONN_TO_SESSION4->bctsr_sessid));
 
-	switch (arg_BIND_CONN_TO_SESSION4->bctsa_dir) {
+	client_channel_dir = arg_BIND_CONN_TO_SESSION4->bctsa_dir;
+
+	switch (client_channel_dir) {
 	case CDFC4_FORE:
-		resok_BIND_CONN_TO_SESSION4->bctsr_dir = CDFS4_FORE;
+		server_channel_dir = CDFS4_FORE;
 		break;
 	case CDFC4_BACK:
-		resok_BIND_CONN_TO_SESSION4->bctsr_dir = CDFS4_BACK;
-		break;
 	case CDFC4_FORE_OR_BOTH:
-		resok_BIND_CONN_TO_SESSION4->bctsr_dir = CDFS4_BOTH;
-		break;
 	case CDFC4_BACK_OR_BOTH:
-		resok_BIND_CONN_TO_SESSION4->bctsr_dir = CDFS4_BOTH;
+		bind_to_backchannel = bind_conn_to_session_backchannel(
+			data->req->rq_xprt, session);
+
+		if (bind_to_backchannel != NFS4_OK) {
+			if (client_channel_dir == CDFC4_FORE_OR_BOTH) {
+				/* Since it is not mandatory to bind connection
+				 * to backchannel in this scenario, we return
+				 * only successful forechannel creation.
+				 */
+				server_channel_dir = CDFS4_FORE;
+				break;
+			}
+			LogCrit(COMPONENT_SESSIONS,
+				"Mandatory backchannel creation failed");
+			res_BIND_CONN_TO_SESSION4->bctsr_status =
+				bind_to_backchannel;
+			return NFS_REQ_ERROR;
+		}
+		if (client_channel_dir == CDFC4_BACK_OR_BOTH ||
+		    client_channel_dir == CDFC4_FORE_OR_BOTH) {
+			server_channel_dir = CDFS4_BOTH;
+			break;
+		}
+		server_channel_dir = CDFS4_BACK;
 		break;
 	}
 
+	resok_BIND_CONN_TO_SESSION4->bctsr_dir = server_channel_dir;
 	resok_BIND_CONN_TO_SESSION4->bctsr_use_conn_in_rdma_mode =
-			arg_BIND_CONN_TO_SESSION4->bctsa_use_conn_in_rdma_mode;
+		arg_BIND_CONN_TO_SESSION4->bctsa_use_conn_in_rdma_mode;
 
 #if 0
 	if (nfs_rpc_get_chan(session->clientid_record, 0) == NULL) {
@@ -139,12 +228,9 @@ enum nfs_req_result nfs4_op_bind_conn(struct nfs_argop4 *op,
 	 */
 	op_ctx->clientid = &data->session->clientid;
 
-	/* Add the session connection */
-	(void) check_session_conn(session, data, true);
-
 	res_BIND_CONN_TO_SESSION4->bctsr_status = NFS4_OK;
 	return NFS_REQ_OK;
-}				/* nfs4_op_bind_conn */
+} /* nfs4_op_bind_conn */
 
 /**
  * @brief Free memory allocated for BIND_CONN_TO_SESSION result
