@@ -42,26 +42,92 @@
 #include "nfs_creds.h"
 #include "client_mgr.h"
 #include "fsal.h"
-#ifdef USE_LTTNG
-#include "gsh_lttng/nfs4.h"
+
+#include "gsh_lttng/gsh_lttng.h"
+#if defined(USE_LTTNG) && !defined(LTTNG_PARSING)
+#include "gsh_lttng/generated_traces/nfs4.h"
 #endif
 
-#define log_channel_attributes(component, chan_attrs, name) \
-	LogFullDebug(component,					\
-		     "%s attributes ca_headerpadsize %"PRIu32	\
-		     " ca_maxrequestsize %"PRIu32		\
-		     " ca_maxresponsesize %"PRIu32		\
-		     " ca_maxresponsesize_cached %"PRIu32	\
-		     " ca_maxoperations %"PRIu32		\
-		     " ca_maxrequests %"PRIu32,			\
-		     name,					\
-		     (chan_attrs)->ca_headerpadsize,		\
-		     (chan_attrs)->ca_maxrequestsize,		\
-		     (chan_attrs)->ca_maxresponsesize,		\
-		     (chan_attrs)->ca_maxresponsesize_cached,	\
-		     (chan_attrs)->ca_maxoperations,		\
+#define log_channel_attributes(component, chan_attrs, name)                   \
+	LogFullDebug(component,                                               \
+		     "%s attributes ca_headerpadsize %" PRIu32                \
+		     " ca_maxrequestsize %" PRIu32                            \
+		     " ca_maxresponsesize %" PRIu32                           \
+		     " ca_maxresponsesize_cached %" PRIu32                    \
+		     " ca_maxoperations %" PRIu32 " ca_maxrequests %" PRIu32, \
+		     name, (chan_attrs)->ca_headerpadsize,                    \
+		     (chan_attrs)->ca_maxrequestsize,                         \
+		     (chan_attrs)->ca_maxresponsesize,                        \
+		     (chan_attrs)->ca_maxresponsesize_cached,                 \
+		     (chan_attrs)->ca_maxoperations,                          \
 		     (chan_attrs)->ca_maxrequests)
 
+/**
+ * @brief Populate nfs41_session with callback params
+ */
+static void populate_callback_params_in_session(
+	uint32_t sec_parms_len, const callback_sec_parms4 *sec_parms_val,
+	uint32_t cb_program, nfs41_session_t *nfs41_session,
+	log_components_t component)
+{
+	int sp_itr;
+	callback_sec_parms4 *const extracted_sec_params =
+		gsh_malloc(sec_parms_len * sizeof(callback_sec_parms4));
+
+	for (sp_itr = 0; sp_itr < sec_parms_len; ++sp_itr) {
+		const callback_sec_parms4 input_sp = sec_parms_val[sp_itr];
+		callback_sec_parms4 *const curr_sp =
+			&extracted_sec_params[sp_itr];
+
+		curr_sp->cb_secflavor = input_sp.cb_secflavor;
+		if (curr_sp->cb_secflavor == AUTH_NONE) {
+			/* Do nothing */
+		} else if (curr_sp->cb_secflavor == AUTH_SYS) {
+			int gids_itr;
+			size_t machname_len;
+			struct authunix_parms curr_cb_sys_creds;
+			struct authunix_parms input_cb_sys_creds =
+				input_sp.callback_sec_parms4_u.cbsp_sys_cred;
+
+			curr_cb_sys_creds.aup_uid = input_cb_sys_creds.aup_uid;
+			curr_cb_sys_creds.aup_gid = input_cb_sys_creds.aup_gid;
+			curr_cb_sys_creds.aup_time =
+				input_cb_sys_creds.aup_time;
+
+			/* Populate aup_machname */
+			machname_len = strnlen(input_cb_sys_creds.aup_machname,
+					       MAX_MACHINE_NAME);
+			curr_cb_sys_creds.aup_machname =
+				gsh_malloc(machname_len + 1);
+			memcpy(curr_cb_sys_creds.aup_machname,
+			       input_cb_sys_creds.aup_machname, machname_len);
+			curr_cb_sys_creds.aup_machname[machname_len] = '\0';
+
+			curr_cb_sys_creds.aup_len = input_cb_sys_creds.aup_len;
+			curr_cb_sys_creds.aup_gids = gsh_malloc(
+				curr_cb_sys_creds.aup_len * sizeof(gid_t));
+
+			for (gids_itr = 0;
+			     gids_itr < input_cb_sys_creds.aup_len;
+			     ++gids_itr) {
+				curr_cb_sys_creds.aup_gids[gids_itr] =
+					input_cb_sys_creds.aup_gids[gids_itr];
+			}
+			curr_sp->callback_sec_parms4_u.cbsp_sys_cred =
+				curr_cb_sys_creds;
+
+#ifdef _HAVE_GSSAPI
+		} else if (curr_sp->cb_secflavor == RPCSEC_GSS) {
+			LogWarn(component,
+				"We do not support GSS callbacks, skip GSS callback setup");
+#endif
+		}
+	}
+	nfs41_session->cb_sec_parms.sec_parms_val = extracted_sec_params;
+	nfs41_session->cb_sec_parms.sec_parms_len = sec_parms_len;
+	nfs41_session->cb_program = cb_program;
+}
+
 /**
  *
  * @brief The NFS4_OP_CREATE_SESSION operation
@@ -82,7 +148,7 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 {
 	/* Result of looking up the clientid in the confirmed ID
 	   table */
-	nfs_client_id_t *conf = NULL;	/* XXX these are not good names */
+	nfs_client_id_t *conf = NULL; /* XXX these are not good names */
 	/* Result of looking up the clientid in the unconfirmed ID
 	   table */
 	nfs_client_id_t *unconf = NULL;
@@ -99,26 +165,28 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 	/* The client name, for gratuitous logging */
 	char str_client[CLIENTNAME_BUFSIZE];
 	/* Display buffer for client name */
-	struct display_buffer dspbuf_client = {
-		sizeof(str_client), str_client, str_client};
+	struct display_buffer dspbuf_client = { sizeof(str_client), str_client,
+						str_client };
 	/* The clientid4 broken down into fields */
 	char str_clientid4[DISPLAY_CLIENTID_SIZE];
 	/* Display buffer for clientid4 */
-	struct display_buffer dspbuf_clientid4 = {
-		sizeof(str_clientid4), str_clientid4, str_clientid4};
+	struct display_buffer dspbuf_clientid4 = { sizeof(str_clientid4),
+						   str_clientid4,
+						   str_clientid4 };
 	/* Return code from clientid calls */
 	int i, rc = 0;
 	/* Component for logging */
 	log_components_t component = COMPONENT_CLIENTID;
 	/* Abbreviated alias for arguments */
-	CREATE_SESSION4args * const arg_CREATE_SESSION4 =
-	    &op->nfs_argop4_u.opcreate_session;
+	CREATE_SESSION4args *const arg_CREATE_SESSION4 =
+		&op->nfs_argop4_u.opcreate_session;
 	/* Abbreviated alias for response */
-	CREATE_SESSION4res * const res_CREATE_SESSION4 =
-	    &resp->nfs_resop4_u.opcreate_session;
+	CREATE_SESSION4res *const res_CREATE_SESSION4 =
+		&resp->nfs_resop4_u.opcreate_session;
 	/* Abbreviated alias for successful response */
-	CREATE_SESSION4resok * const res_CREATE_SESSION4ok =
-	    &res_CREATE_SESSION4->CREATE_SESSION4res_u.csr_resok4;
+	CREATE_SESSION4resok *const res_CREATE_SESSION4ok =
+		&res_CREATE_SESSION4->CREATE_SESSION4res_u.csr_resok4;
+	bool added_conn_to_session;
 
 	/* Make sure str_client is always printable even
 	 * if log level changes midstream.
@@ -144,8 +212,8 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 	}
 
 	LogInfo(component,
-		 "CREATE_SESSION client addr=%s clientid=%s -------------------",
-		 str_client_addr, str_clientid4);
+		"CREATE_SESSION client addr=%s clientid=%s -------------------",
+		str_client_addr, str_clientid4);
 
 	/* First try to look up unconfirmed record */
 	rc = nfs_client_id_get_unconfirmed(clientid, &unconf);
@@ -157,15 +225,14 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 		rc = nfs_client_id_get_confirmed(clientid, &conf);
 		if (rc != CLIENT_ID_SUCCESS) {
 			/* No record whatsoever of this clientid */
-			LogDebug(component,
-				 "%s clientid=%s",
+			LogDebug(component, "%s clientid=%s",
 				 clientid_error_to_str(rc), str_clientid4);
 
 			if (rc == CLIENT_ID_EXPIRED)
 				rc = CLIENT_ID_STALE;
 
 			res_CREATE_SESSION4->csr_status =
-			    clientid_error_to_nfsstat_no_expire(rc);
+				clientid_error_to_nfsstat_no_expire(rc);
 
 			return NFS_REQ_ERROR;
 		}
@@ -180,15 +247,14 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 
 	if (isInfo(component)) {
 		char str[LOG_BUFF_LEN] = "\0";
-		struct display_buffer dspbuf = {sizeof(str), str, str};
+		struct display_buffer dspbuf = { sizeof(str), str, str };
 
 		display_client_record(&dspbuf, client_record);
 
 		LogInfo(component,
-			     "Client Record %s cr_confirmed_rec=%p cr_unconfirmed_rec=%p",
-			     str,
-			     client_record->cr_confirmed_rec,
-			     client_record->cr_unconfirmed_rec);
+			"Client Record %s cr_confirmed_rec=%p cr_unconfirmed_rec=%p",
+			str, client_record->cr_confirmed_rec,
+			client_record->cr_unconfirmed_rec);
 	}
 
 	/* At this point one and only one of conf and unconf is
@@ -198,25 +264,25 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 
 	LogDebug(component,
 		 "CREATE_SESSION clientid=%s csa_sequence=%" PRIu32
-		 " clientid_cs_seq=%" PRIu32
-		 " data_oppos=%d",
+		 " clientid_cs_seq=%" PRIu32 " data_oppos=%d",
 		 str_clientid4, arg_CREATE_SESSION4->csa_sequence,
 		 found->cid_create_session_sequence, data->oppos);
 
 	if (isFullDebug(component)) {
 		char str[LOG_BUFF_LEN] = "\0";
-		struct display_buffer dspbuf = {sizeof(str), str, str};
+		struct display_buffer dspbuf = { sizeof(str), str, str };
 
 		display_client_id_rec(&dspbuf, found);
 		LogFullDebug(component, "Found %s", str);
 	}
 
 	if ((arg_CREATE_SESSION4->csa_sequence + 1) ==
-	     found->cid_create_session_sequence) {
+	    found->cid_create_session_sequence) {
 		*res_CREATE_SESSION4 = found->cid_create_session_slot;
 
-		LogDebug(component,
-			 "CREATE_SESSION special replay case, used response in cid_create_session_slot");
+		LogDebug(
+			component,
+			"CREATE_SESSION special replay case, used response in cid_create_session_slot");
 		goto out;
 	} else if (arg_CREATE_SESSION4->csa_sequence !=
 		   found->cid_create_session_sequence) {
@@ -236,13 +302,13 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 
 				if (unconf->gsh_client != NULL)
 					unconfirmed_addr =
-					    unconf->gsh_client->hostaddr_str;
+						unconf->gsh_client->hostaddr_str;
 
-				LogDebug(component,
-					 "Unconfirmed ClientId %s->'%s': Principals do not match... unconfirmed addr=%s Return NFS4ERR_CLID_INUSE",
-					 str_clientid4,
-					 str_client_addr,
-					 unconfirmed_addr);
+				LogDebug(
+					component,
+					"Unconfirmed ClientId %s->'%s': Principals do not match... unconfirmed addr=%s Return NFS4ERR_CLID_INUSE",
+					str_clientid4, str_client_addr,
+					unconfirmed_addr);
 			}
 
 			res_CREATE_SESSION4->csr_status = NFS4ERR_CLID_INUSE;
@@ -262,12 +328,13 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 
 				if (conf->gsh_client != NULL)
 					confirmed_addr =
-					    conf->gsh_client->hostaddr_str;
+						conf->gsh_client->hostaddr_str;
 
-				LogDebug(component,
-					 "Confirmed ClientId %s->%s addr=%s: Principals do not match... confirmed addr=%s Return NFS4ERR_CLID_INUSE",
-					 str_clientid4, str_client,
-					 str_client_addr, confirmed_addr);
+				LogDebug(
+					component,
+					"Confirmed ClientId %s->%s addr=%s: Principals do not match... confirmed addr=%s Return NFS4ERR_CLID_INUSE",
+					str_clientid4, str_client,
+					str_client_addr, confirmed_addr);
 			}
 
 			res_CREATE_SESSION4->csr_status = NFS4ERR_CLID_INUSE;
@@ -290,11 +357,10 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 
 	/* Check flags value (test CSESS15) */
 	if (arg_CREATE_SESSION4->csa_flags &
-			~(CREATE_SESSION4_FLAG_PERSIST |
-			  CREATE_SESSION4_FLAG_CONN_BACK_CHAN |
-			  CREATE_SESSION4_FLAG_CONN_RDMA)) {
-		LogDebug(component,
-			 "Invalid create session flags %" PRIu32,
+	    ~(CREATE_SESSION4_FLAG_PERSIST |
+	      CREATE_SESSION4_FLAG_CONN_BACK_CHAN |
+	      CREATE_SESSION4_FLAG_CONN_RDMA)) {
+		LogDebug(component, "Invalid create session flags %" PRIu32,
 			 arg_CREATE_SESSION4->csa_flags);
 		res_CREATE_SESSION4->csr_status = NFS4ERR_INVAL;
 		goto out;
@@ -309,21 +375,20 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 
 	/* Let's verify the channel attributes for the session first. */
 	if (arg_CREATE_SESSION4->csa_fore_chan_attrs.ca_maxrequestsize <
-						NFS41_MIN_REQUEST_SIZE ||
+		    NFS41_MIN_REQUEST_SIZE ||
 	    arg_CREATE_SESSION4->csa_fore_chan_attrs.ca_maxresponsesize <
-						NFS41_MIN_RESPONSE_SIZE ||
+		    NFS41_MIN_RESPONSE_SIZE ||
 	    arg_CREATE_SESSION4->csa_fore_chan_attrs.ca_maxoperations <
-						NFS41_MIN_OPERATIONS ||
+		    NFS41_MIN_OPERATIONS ||
 	    arg_CREATE_SESSION4->csa_fore_chan_attrs.ca_maxrequests == 0 ||
 	    arg_CREATE_SESSION4->csa_back_chan_attrs.ca_maxrequestsize <
-						NFS41_MIN_REQUEST_SIZE ||
+		    NFS41_MIN_REQUEST_SIZE ||
 	    arg_CREATE_SESSION4->csa_back_chan_attrs.ca_maxresponsesize <
-						NFS41_MIN_RESPONSE_SIZE ||
+		    NFS41_MIN_RESPONSE_SIZE ||
 	    arg_CREATE_SESSION4->csa_back_chan_attrs.ca_maxoperations <
-						NFS41_MIN_OPERATIONS ||
+		    NFS41_MIN_OPERATIONS ||
 	    arg_CREATE_SESSION4->csa_back_chan_attrs.ca_maxrequests == 0) {
-		LogWarnLimited(component,
-			       "Invalid channel attributes for %s",
+		LogWarnLimited(component, "Invalid channel attributes for %s",
 			       data->tagname);
 		res_CREATE_SESSION4->csr_status = NFS4ERR_TOOSMALL;
 		goto out;
@@ -338,15 +403,13 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 		goto out;
 	}
 
-	copy_xprt_addr(&nfs41_session->connections[0], data->req->rq_xprt);
-	nfs41_session->num_conn = 1;
 	nfs41_session->clientid = clientid;
 	nfs41_session->clientid_record = found;
-	nfs41_session->refcount = 2;	/* sentinel ref + call path ref */
+	nfs41_session->refcount = 2; /* sentinel ref + call path ref */
 	nfs41_session->fore_channel_attrs =
-	    arg_CREATE_SESSION4->csa_fore_chan_attrs;
+		arg_CREATE_SESSION4->csa_fore_chan_attrs;
 	nfs41_session->back_channel_attrs =
-	    arg_CREATE_SESSION4->csa_back_chan_attrs;
+		arg_CREATE_SESSION4->csa_back_chan_attrs;
 	nfs41_session->flags = false;
 	nfs41_session->cb_program = 0;
 
@@ -355,8 +418,9 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 	PTHREAD_RWLOCK_init(&nfs41_session->conn_lock, NULL);
 	PTHREAD_MUTEX_init(&nfs41_session->cb_chan.chan_mtx, NULL);
 
-	nfs41_session->nb_slots = MIN(nfs_param.nfsv4_param.nb_slots,
-			nfs41_session->fore_channel_attrs.ca_maxrequests);
+	nfs41_session->nb_slots =
+		MIN(nfs_param.nfsv4_param.nb_slots,
+		    nfs41_session->fore_channel_attrs.ca_maxrequests);
 	nfs41_session->fc_slots = gsh_calloc(nfs41_session->nb_slots,
 					     sizeof(nfs41_session_slot_t));
 	nfs41_session->bc_slots = gsh_calloc(nfs41_session->nb_slots,
@@ -384,18 +448,17 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 	 * change in later versions)
 	 */
 	res_CREATE_SESSION4ok->csr_fore_chan_attrs =
-	    nfs41_session->fore_channel_attrs;
+		nfs41_session->fore_channel_attrs;
 	res_CREATE_SESSION4ok->csr_back_chan_attrs =
-	    nfs41_session->back_channel_attrs;
+		nfs41_session->back_channel_attrs;
 	res_CREATE_SESSION4ok->csr_flags = 0;
 
-	memcpy(res_CREATE_SESSION4ok->csr_sessionid,
-	       nfs41_session->session_id,
+	memcpy(res_CREATE_SESSION4ok->csr_sessionid, nfs41_session->session_id,
 	       NFS4_SESSIONID_SIZE);
 
-#ifdef USE_LTTNG
-	tracepoint(nfs4, session_ref, __func__, __LINE__, nfs41_session, 2);
-#endif
+	GSH_AUTO_TRACEPOINT(nfs4, session_create, TRACE_INFO,
+			    "Create session. Session: {}, refcount: 2",
+			    nfs41_session);
 
 	if (!nfs41_Session_Set(nfs41_session)) {
 		LogDebug(component, "Could not insert session into table");
@@ -410,6 +473,26 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 		goto out;
 	}
 
+	nfs41_session->num_conn = 0;
+	glist_init(&nfs41_session->connection_xprts);
+
+	/* Add the connection to the session */
+	added_conn_to_session = check_session_conn(nfs41_session, data, true);
+
+	if (!added_conn_to_session) {
+		LogCrit(component,
+			"Unable to add connection FD: %d to the session",
+			data->req->rq_xprt->xp_fd);
+
+		/* Need to destroy the session */
+		if (!nfs41_Session_Del(nfs41_session))
+			LogDebug(component,
+				 "nfs41_Session_Del failed during cleanup");
+
+		res_CREATE_SESSION4->csr_status = NFS4ERR_INVAL;
+		goto out;
+	}
+
 	/* Make sure we have a reference to the confirmed clientid
 	   record if any */
 	if (conf == NULL) {
@@ -432,7 +515,8 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 		/* Old confirmed record - need to expire it */
 		if (isDebug(component)) {
 			char str[LOG_BUFF_LEN] = "\0";
-			struct display_buffer dspbuf = {sizeof(str), str, str};
+			struct display_buffer dspbuf = { sizeof(str), str,
+							 str };
 
 			display_client_id_rec(&dspbuf, conf);
 			LogDebug(component, "Expiring %s", str);
@@ -442,7 +526,7 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 		 * NOTE: found MUST NOT BE conf (otherwise clientid would have
 		 *       matched).
 		 */
-		nfs_client_id_expire(conf, false);
+		nfs_client_id_expire(conf, false, true);
 		dec_client_id_ref(conf);
 		conf = NULL;
 	}
@@ -453,8 +537,7 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 		 * unconfirmed record.
 		 */
 		display_clientid(&dspbuf_clientid4, conf->cid_clientid);
-		LogDebug(component,
-			 "Updating clientid %s->%s cb_program=%u",
+		LogDebug(component, "Updating clientid %s->%s cb_program=%u",
 			 str_clientid4, str_client,
 			 arg_CREATE_SESSION4->csa_cb_program);
 
@@ -476,7 +559,8 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 
 		if (isDebug(component)) {
 			char str[LOG_BUFF_LEN] = "\0";
-			struct display_buffer dspbuf = {sizeof(str), str, str};
+			struct display_buffer dspbuf = { sizeof(str), str,
+							 str };
 
 			display_client_id_rec(&dspbuf, conf);
 			LogDebug(component, "Updated %s", str);
@@ -485,7 +569,8 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 		/* This is a new clientid */
 		if (isFullDebug(component)) {
 			char str[LOG_BUFF_LEN] = "\0";
-			struct display_buffer dspbuf = {sizeof(str), str, str};
+			struct display_buffer dspbuf = { sizeof(str), str,
+							 str };
 
 			display_client_id_rec(&dspbuf, unconf);
 			LogFullDebug(component, "Confirming new %s", str);
@@ -495,10 +580,10 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 
 		if (rc != CLIENT_ID_SUCCESS) {
 			res_CREATE_SESSION4->csr_status =
-			    clientid_error_to_nfsstat_no_expire(rc);
+				clientid_error_to_nfsstat_no_expire(rc);
 
 			/* Need to destroy the session */
-			if (!nfs41_Session_Del(nfs41_session->session_id))
+			if (!nfs41_Session_Del(nfs41_session))
 				LogDebug(component,
 					 "Oops nfs41_Session_Del failed");
 
@@ -511,7 +596,8 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 
 		if (isDebug(component)) {
 			char str[LOG_BUFF_LEN] = "\0";
-			struct display_buffer dspbuf = {sizeof(str), str, str};
+			struct display_buffer dspbuf = { sizeof(str), str,
+							 str };
 
 			display_client_id_rec(&dspbuf, conf);
 			LogDebug(component, "Confirmed %s", str);
@@ -521,44 +607,53 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 
 	/* Bump the lease timer */
 	conf->cid_last_renew = time(NULL);
+	/* Once the lease timer is updated then the client is active and
+	 * if the unresponsive client was marked as expired earlier,
+	 * then moving it out of the expired client list
+	 */
+	if (conf->marked_for_delayed_cleanup)
+		remove_client_from_expired_client_list(conf);
 
 	if (isFullDebug(component)) {
 		char str[LOG_BUFF_LEN] = "\0";
-		struct display_buffer dspbuf = {sizeof(str), str, str};
+		struct display_buffer dspbuf = { sizeof(str), str, str };
 
 		display_client_record(&dspbuf, client_record);
-		LogFullDebug(component,
-			     "Client Record %s cr_confirmed_rec=%p cr_unconfirmed_rec=%p",
-			     str,
-			     client_record->cr_confirmed_rec,
-			     client_record->cr_unconfirmed_rec);
+		LogFullDebug(
+			component,
+			"Client Record %s cr_confirmed_rec=%p cr_unconfirmed_rec=%p",
+			str, client_record->cr_confirmed_rec,
+			client_record->cr_unconfirmed_rec);
 	}
 
+	populate_callback_params_in_session(
+		arg_CREATE_SESSION4->csa_sec_parms.csa_sec_parms_len,
+		arg_CREATE_SESSION4->csa_sec_parms.csa_sec_parms_val,
+		arg_CREATE_SESSION4->csa_cb_program, nfs41_session, component);
+
 	/* Handle the creation of the back channel, if the client
 	   requested one. */
 	if (arg_CREATE_SESSION4->csa_flags &
 	    CREATE_SESSION4_FLAG_CONN_BACK_CHAN) {
-		nfs41_session->cb_program = arg_CREATE_SESSION4->csa_cb_program;
 		if (nfs_rpc_create_chan_v41(
-			data->req->rq_xprt, nfs41_session,
-			arg_CREATE_SESSION4->csa_sec_parms.csa_sec_parms_len,
-			arg_CREATE_SESSION4->csa_sec_parms.csa_sec_parms_val)
-		    == 0) {
+			    data->req->rq_xprt, nfs41_session,
+			    nfs41_session->cb_sec_parms.sec_parms_len,
+			    nfs41_session->cb_sec_parms.sec_parms_val) == 0) {
 			res_CREATE_SESSION4ok->csr_flags |=
-			    CREATE_SESSION4_FLAG_CONN_BACK_CHAN;
+				CREATE_SESSION4_FLAG_CONN_BACK_CHAN;
+			LogDebug(component, "Session backchannel created");
 		}
 	}
 
 	if (isDebug(component)) {
 		char str[LOG_BUFF_LEN] = "\0";
-		struct display_buffer dspbuf = {sizeof(str), str, str};
+		struct display_buffer dspbuf = { sizeof(str), str, str };
 
 		display_session(&dspbuf, nfs41_session);
 
-		LogDebug(component,
-			 "success %s csa_flags 0x%X csr_flags 0x%X",
-			  str, arg_CREATE_SESSION4->csa_flags,
-			  res_CREATE_SESSION4ok->csr_flags);
+		LogDebug(component, "success %s csa_flags 0x%X csr_flags 0x%X",
+			 str, arg_CREATE_SESSION4->csa_flags,
+			 res_CREATE_SESSION4ok->csr_flags);
 	}
 
 	/* Successful exit */
@@ -571,7 +666,7 @@ enum nfs_req_result nfs4_op_create_session(struct nfs_argop4 *op,
 	 */
 	conf->cid_create_session_slot = *res_CREATE_SESSION4;
 
- out:
+out:
 
 	/* Release our reference to the found record (confirmed or unconfirmed)
 	 */
