@@ -72,8 +72,8 @@ struct nfs4_read_data {
  */
 
 typedef enum io_direction__ {
-	IO_READ = 1,		/*< Reading */
-	IO_READ_PLUS = 2,	/*< Reading plus */
+	IO_READ = 1, /*< Reading */
+	IO_READ_PLUS = 2, /*< Reading plus */
 } io_direction_t;
 
 static enum nfs_req_result nfs4_complete_read(struct nfs4_read_data *data)
@@ -81,8 +81,10 @@ static enum nfs_req_result nfs4_complete_read(struct nfs4_read_data *data)
 	struct fsal_io_arg *read_arg = &data->read_arg;
 
 	if (data->res_READ4->status == NFS4_OK) {
+		READ4resok *resok = &data->res_READ4->READ4res_u.resok4;
+
 		if (nfs_param.core_param.getattrs_in_complete_read &&
-				!read_arg->end_of_file) {
+		    !read_arg->end_of_file) {
 			/*
 			 * NFS requires to set the EOF flag for all reads that
 			 * reach the EOF, i.e., even the ones returning data.
@@ -100,8 +102,8 @@ static enum nfs_req_result nfs4_complete_read(struct nfs4_read_data *data)
 
 			if (FSAL_IS_SUCCESS(status)) {
 				read_arg->end_of_file = (read_arg->offset +
-							 read_arg->io_amount)
-							>= attrs.filesize;
+							 read_arg->io_amount) >=
+							attrs.filesize;
 			}
 
 			/* Done with the attrs */
@@ -109,30 +111,52 @@ static enum nfs_req_result nfs4_complete_read(struct nfs4_read_data *data)
 		}
 
 		/* Is EOF met or not ? */
-		data->res_READ4->READ4res_u.resok4.eof = read_arg->end_of_file;
+		resok->eof = read_arg->end_of_file;
+		resok->data.data_len = read_arg->io_amount;
 
-		data->res_READ4->READ4res_u.resok4.data.data_len =
-			read_arg->io_amount;
-		data->res_READ4->READ4res_u.resok4.data.data_val =
-			read_arg->iov[0].iov_base;
+		if (read_arg->io_amount == 0) {
+			/* We won't need the FSAL's iovec and buffers if it used
+			 * them
+			 */
+			if (read_arg->iov_release != NULL)
+				read_arg->iov_release(read_arg->release_data);
+
+			/* We will use the iov we set up before the call, but
+			 * set the length of the buffer to 0. The
+			 * io_data->release is already set up.
+			 */
+			resok->data.iov[0].iov_len = 0;
+		} else {
+			if (read_arg->iov != resok->data.iov) {
+				/* FSAL returned a different iovector */
+				resok->data.iov = read_arg->iov;
+				resok->data.iovcnt = read_arg->iov_count;
+			}
+
+			if (read_arg->iov_release != resok->data.release) {
+				/* The FSAL replaced the release */
+				resok->data.release = read_arg->iov_release;
+				resok->data.release_data =
+					read_arg->release_data;
+			}
+		}
 
 		LogFullDebug(COMPONENT_NFS_V4,
 			     "NFS4_OP_READ: offset = %" PRIu64
-			     " read length = %zu eof=%u", read_arg->offset,
-			     read_arg->io_amount, read_arg->end_of_file);
+			     " read length = %zu eof=%u",
+			     read_arg->offset, read_arg->io_amount,
+			     read_arg->end_of_file);
 	} else {
-		int i;
-
-		for (i = 0; i < read_arg->iov_count; ++i) {
-			gsh_free(read_arg->iov[i].iov_base);
-		}
-
-		data->res_READ4->READ4res_u.resok4.data.data_val = NULL;
+		/* Just in case... We won't need the FSAL's iovec and
+		 * buffers if it used them
+		 */
+		if (read_arg->iov_release != NULL)
+			read_arg->iov_release(read_arg->release_data);
 	}
 
-	server_stats_io_done(read_arg->iov[0].iov_len, read_arg->io_amount,
-			     (data->res_READ4->status == NFS4_OK) ? true :
-			     false, false);
+	server_stats_io_done(
+		read_arg->io_request, read_arg->io_amount,
+		(data->res_READ4->status == NFS4_OK) ? true : false, false);
 
 	if (data->owner != NULL) {
 		op_ctx->clientid = NULL;
@@ -148,8 +172,8 @@ static enum nfs_req_result nfs4_complete_read(struct nfs4_read_data *data)
 static void nfs4_complete_read_plus(struct nfs_resop4 *resp,
 				    struct io_info *info)
 {
-	READ4res * const res_READ4 = &resp->nfs_resop4_u.opread;
-	READ_PLUS4res * const res_RPLUS = &resp->nfs_resop4_u.opread_plus;
+	READ4res *const res_READ4 = &resp->nfs_resop4_u.opread;
+	READ_PLUS4res *const res_RPLUS = &resp->nfs_resop4_u.opread_plus;
 	contents *contentp = &res_RPLUS->rpr_resok4.rpr_contents;
 
 	/* Fixup the eof status from the res_READ4 that res_RPLUS overlays. */
@@ -167,9 +191,9 @@ static void nfs4_complete_read_plus(struct nfs_resop4 *resp,
 	if (info->io_content.what == NFS4_CONTENT_DATA) {
 		contentp->data.d_offset = info->io_content.data.d_offset;
 		contentp->data.d_data.data_len =
-					info->io_content.data.d_data.data_len;
+			info->io_content.data.d_data.data_len;
 		contentp->data.d_data.data_val =
-					info->io_content.data.d_data.data_val;
+			info->io_content.data.d_data.data_val;
 	}
 }
 
@@ -182,7 +206,7 @@ static void nfs4_complete_read_plus(struct nfs_resop4 *resp,
  * @param[in] caller_data	Data for caller
  */
 static void nfs4_read_cb(struct fsal_obj_handle *obj, fsal_status_t ret,
-			  void *read_data, void *caller_data)
+			 void *read_data, void *caller_data)
 {
 	struct nfs4_read_data *data = caller_data;
 	uint32_t flags;
@@ -214,9 +238,8 @@ enum nfs_req_result nfs4_op_read_resume(struct nfs_argop4 *op,
 
 	if (read_data->read_arg.fsal_resume) {
 		/* FSAL is requesting another read2 call on resume */
-		atomic_postclear_uint32_t_bits(&read_data->flags,
-					       ASYNC_PROC_EXIT |
-					       ASYNC_PROC_DONE);
+		atomic_postclear_uint32_t_bits(
+			&read_data->flags, ASYNC_PROC_EXIT | ASYNC_PROC_DONE);
 
 		read_data->obj->obj_ops->read2(read_data->obj, true,
 					       nfs4_read_cb,
@@ -225,9 +248,8 @@ enum nfs_req_result nfs4_op_read_resume(struct nfs_argop4 *op,
 		/* Only atomically set the flags if we actually call read2,
 		 * otherwise we will have indicated as having been DONE.
 		 */
-		flags =
-		    atomic_postset_uint32_t_bits(&read_data->flags,
-						 ASYNC_PROC_EXIT);
+		flags = atomic_postset_uint32_t_bits(&read_data->flags,
+						     ASYNC_PROC_EXIT);
 
 		if ((flags & ASYNC_PROC_DONE) != ASYNC_PROC_DONE) {
 			/* The read was not finished before we got here. When
@@ -268,9 +290,8 @@ enum nfs_req_result nfs4_op_read_plus_resume(struct nfs_argop4 *op,
 
 	if (read_data->read_arg.fsal_resume) {
 		/* FSAL is requesting another read2 call on resume */
-		atomic_postclear_uint32_t_bits(&read_data->flags,
-					       ASYNC_PROC_EXIT |
-					       ASYNC_PROC_DONE);
+		atomic_postclear_uint32_t_bits(
+			&read_data->flags, ASYNC_PROC_EXIT | ASYNC_PROC_DONE);
 
 		read_data->obj->obj_ops->read2(read_data->obj, true,
 					       nfs4_read_cb,
@@ -279,9 +300,8 @@ enum nfs_req_result nfs4_op_read_plus_resume(struct nfs_argop4 *op,
 		/* Only atomically set the flags if we actually call read2,
 		 * otherwise we will have indicated as having been DONE.
 		 */
-		flags =
-		    atomic_postset_uint32_t_bits(&read_data->flags,
-						 ASYNC_PROC_EXIT);
+		flags = atomic_postset_uint32_t_bits(&read_data->flags,
+						     ASYNC_PROC_EXIT);
 
 		if ((flags & ASYNC_PROC_DONE) != ASYNC_PROC_DONE) {
 			/* The read was not finished before we got here. When
@@ -330,25 +350,28 @@ enum nfs_req_result nfs4_op_read_plus_resume(struct nfs_argop4 *op,
  *
  */
 
-static enum nfs_req_result op_dsread(struct nfs_argop4 *op,
-				     compound_data_t *data,
-				     struct nfs_resop4 *resp)
+static enum nfs_req_result
+op_dsread(struct nfs_argop4 *op, compound_data_t *data, struct nfs_resop4 *resp)
 {
-	READ4args * const arg_READ4 = &op->nfs_argop4_u.opread;
-	READ4res * const res_READ4 = &resp->nfs_resop4_u.opread;
+	READ4args *const arg_READ4 = &op->nfs_argop4_u.opread;
+	READ4res *const res_READ4 = &resp->nfs_resop4_u.opread;
 	/* NFSv4 return code */
 	nfsstat4 nfs_status = 0;
 	/* Buffer into which data is to be read */
 	void *buffer = NULL;
 	/* End of file flag */
 	bool eof = false;
+	READ4resok *resok = &res_READ4->READ4res_u.resok4;
 
 	/* Don't bother calling the FSAL if the read length is 0. */
 
 	if (arg_READ4->count == 0) {
-		res_READ4->READ4res_u.resok4.eof = FALSE;
-		res_READ4->READ4res_u.resok4.data.data_len = 0;
-		res_READ4->READ4res_u.resok4.data.data_val = NULL;
+		resok->eof = FALSE;
+		resok->data.data_len = 0;
+		resok->data.iovcnt = 1;
+		resok->data.iov = &resok->iov0;
+		resok->iov0.iov_len = 0;
+		resok->iov0.iov_base = NULL;
 		res_READ4->status = NFS4_OK;
 		return NFS_REQ_OK;
 	}
@@ -358,26 +381,27 @@ static enum nfs_req_result op_dsread(struct nfs_argop4 *op,
 	/* Must allocate buffer as a multiple of BYTES_PER_XDR_UNIT */
 	buffer = gsh_malloc_aligned(4096, RNDUP(arg_READ4->count));
 
-	res_READ4->READ4res_u.resok4.data.data_val = buffer;
+	resok->iov0.iov_base = buffer;
+	resok->iov0.iov_len = arg_READ4->count;
+	resok->data.data_len = arg_READ4->count;
+	resok->data.iovcnt = 1;
+	resok->data.iov = &resok->iov0;
 
 	nfs_status = op_ctx->ctx_pnfs_ds->s_ops.dsh_read(
-				data->current_ds,
-				&arg_READ4->stateid,
-				arg_READ4->offset,
-				arg_READ4->count,
-				res_READ4->READ4res_u.resok4.data.data_val,
-				&res_READ4->READ4res_u.resok4.data.data_len,
-				&eof);
+		data->current_ds, &arg_READ4->stateid, arg_READ4->offset,
+		arg_READ4->count, resok->iov0.iov_base, &resok->data.data_len,
+		&eof);
 
 	if (nfs_status != NFS4_OK) {
 		gsh_free(buffer);
-		res_READ4->READ4res_u.resok4.data.data_val = NULL;
+		resok->data.data_len = 0;
+		resok->iov0.iov_len = 0;
+		resok->iov0.iov_base = NULL;
+	} else {
+		resok->iov0.iov_len = resok->data.data_len;
 	}
 
-	if (eof)
-		res_READ4->READ4res_u.resok4.eof = TRUE;
-	else
-		res_READ4->READ4res_u.resok4.eof = FALSE;
+	resok->eof = eof;
 
 	res_READ4->status = nfs_status;
 
@@ -403,8 +427,8 @@ static enum nfs_req_result op_dsread_plus(struct nfs_argop4 *op,
 					  struct nfs_resop4 *resp,
 					  struct io_info *info)
 {
-	READ4args * const arg_READ4 = &op->nfs_argop4_u.opread;
-	READ_PLUS4res * const res_RPLUS = &resp->nfs_resop4_u.opread_plus;
+	READ4args *const arg_READ4 = &op->nfs_argop4_u.opread;
+	READ_PLUS4res *const res_RPLUS = &resp->nfs_resop4_u.opread_plus;
 	contents *contentp = &res_RPLUS->rpr_resok4.rpr_contents;
 	/* NFSv4 return code */
 	nfsstat4 nfs_status = 0;
@@ -420,7 +444,7 @@ static enum nfs_req_result op_dsread_plus(struct nfs_argop4 *op,
 		res_RPLUS->rpr_resok4.rpr_eof = FALSE;
 		contentp->what = NFS4_CONTENT_DATA;
 		contentp->data.d_offset = arg_READ4->offset;
-		contentp->data.d_data.data_len =  0;
+		contentp->data.d_data.data_len = 0;
 		contentp->data.d_data.data_val = NULL;
 		res_RPLUS->rpr_status = NFS4_OK;
 		return NFS_REQ_OK;
@@ -431,13 +455,8 @@ static enum nfs_req_result op_dsread_plus(struct nfs_argop4 *op,
 	buffer = gsh_malloc_aligned(4096, RNDUP(arg_READ4->count));
 
 	nfs_status = op_ctx->ctx_pnfs_ds->s_ops.dsh_read_plus(
-				data->current_ds,
-				&arg_READ4->stateid,
-				arg_READ4->offset,
-				arg_READ4->count,
-				buffer,
-				arg_READ4->count,
-				&eof, info);
+		data->current_ds, &arg_READ4->stateid, arg_READ4->offset,
+		arg_READ4->count, buffer, arg_READ4->count, &eof, info);
 
 	res_RPLUS->rpr_status = nfs_status;
 	if (nfs_status != NFS4_OK) {
@@ -456,27 +475,30 @@ static enum nfs_req_result op_dsread_plus(struct nfs_argop4 *op,
 	if (info->io_content.what == NFS4_CONTENT_DATA) {
 		contentp->data.d_offset = info->io_content.data.d_offset;
 		contentp->data.d_data.data_len =
-					info->io_content.data.d_data.data_len;
+			info->io_content.data.d_data.data_len;
 		contentp->data.d_data.data_val =
-					info->io_content.data.d_data.data_val;
+			info->io_content.data.d_data.data_val;
 	}
 	return nfsstat4_to_nfs_req_result(res_RPLUS->rpr_status);
 }
 
+static void read4_io_data_release(void *release_data)
+{
+	/* Nothing to do */
+}
+
 static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 				     compound_data_t *data,
-				     struct nfs_resop4 *resp,
-				     io_direction_t io,
+				     struct nfs_resop4 *resp, io_direction_t io,
 				     struct io_info *info)
 {
-	READ4args * const arg_READ4 = &op->nfs_argop4_u.opread;
-	READ4res * const res_READ4 = &resp->nfs_resop4_u.opread;
+	READ4args *const arg_READ4 = &op->nfs_argop4_u.opread;
+	READ4res *const res_READ4 = &resp->nfs_resop4_u.opread;
 	uint64_t size = 0;
 	uint64_t offset = 0;
 	uint64_t MaxRead = 0;
 	uint64_t MaxOffsetRead = 0;
-	void *bufferdata = NULL;
-	fsal_status_t fsal_status = {0, 0};
+	fsal_status_t fsal_status = { 0, 0 };
 	state_t *state_found = NULL;
 	state_t *state_open = NULL;
 	struct fsal_obj_handle *obj = NULL;
@@ -490,6 +512,7 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 	 * since in that case we should go ahead and exit as expected.
 	 */
 	uint32_t flags = ASYNC_PROC_DONE;
+	READ4resok *resok = &res_READ4->READ4res_u.resok4;
 
 	res_READ4->status = NFS4_OK;
 
@@ -503,8 +526,8 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 	   checks for special stateids) */
 
 	res_READ4->status =
-	    nfs4_Check_Stateid(&arg_READ4->stateid, obj, &state_found, data,
-			       STATEID_SPECIAL_ANY, 0, false, "READ");
+		nfs4_Check_Stateid(&arg_READ4->stateid, obj, &state_found, data,
+				   STATEID_SPECIAL_ANY, 0, false, "READ");
 	if (res_READ4->status != NFS4_OK)
 		return NFS_REQ_ERROR;
 
@@ -512,7 +535,6 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 	   stateid is all-0 or all-1 */
 
 	if (state_found != NULL) {
-
 		if (info)
 			info->io_advise = state_found->state_data.io_advise;
 		switch (state_found->state_type) {
@@ -529,7 +551,7 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 
 		case STATE_TYPE_LOCK:
 			state_open = nfs4_State_Get_Pointer(
-			    state_found->state_data.lock.openstate_key);
+				state_found->state_data.lock.openstate_key);
 
 			if (state_open == NULL) {
 				res_READ4->status = NFS4ERR_BAD_STATEID;
@@ -562,9 +584,9 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 
 		/* This is a read operation, this means that the file
 		   MUST have been opened for reading */
-		if (state_open != NULL
-		    && (state_open->state_data.share.share_access &
-		    OPEN4_SHARE_ACCESS_READ) == 0) {
+		if (state_open != NULL &&
+		    (state_open->state_data.share.share_access &
+		     OPEN4_SHARE_ACCESS_READ) == 0) {
 			/* Even if file is open for write, the client
 			 * may do accidentally read operation (caching).
 			 * Because of this, READ is allowed if not
@@ -580,11 +602,13 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 				if (isDebug(COMPONENT_NFS_V4_LOCK)) {
 					char str[LOG_BUFF_LEN] = "\0";
 					struct display_buffer dspbuf = {
-							sizeof(str), str, str};
+						sizeof(str), str, str
+					};
 					display_stateid(&dspbuf, state_found);
-					LogDebug(COMPONENT_NFS_V4_LOCK,
-						 "READ %s doesn't have OPEN4_SHARE_ACCESS_READ",
-						 str);
+					LogDebug(
+						COMPONENT_NFS_V4_LOCK,
+						"READ %s doesn't have OPEN4_SHARE_ACCESS_READ",
+						str);
 				}
 				goto out;
 			}
@@ -638,15 +662,14 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 	}
 
 	/* Need to permission check the read. */
-	fsal_status = obj->obj_ops->test_access(obj, FSAL_READ_ACCESS,
-					       NULL, NULL, true);
+	fsal_status = obj->obj_ops->test_access(obj, FSAL_READ_ACCESS, NULL,
+						NULL, true);
 
 	if (fsal_status.major == ERR_FSAL_ACCESS) {
 		/* Test for execute permission */
-		fsal_status = fsal_access(obj,
-				  FSAL_MODE_MASK_SET(FSAL_X_OK) |
-				  FSAL_ACE4_MASK_SET
-				  (FSAL_ACE_PERM_EXECUTE));
+		fsal_status = fsal_access(
+			obj, FSAL_MODE_MASK_SET(FSAL_X_OK) |
+				     FSAL_ACE4_MASK_SET(FSAL_ACE_PERM_EXECUTE));
 	}
 
 	if (FSAL_IS_ERROR(fsal_status)) {
@@ -664,17 +687,16 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 
 	if (MaxOffsetRead < UINT64_MAX) {
 		LogFullDebug(COMPONENT_NFS_V4,
-			     "Read offset=%" PRIu64
-			     " size=%" PRIu64 " MaxOffSet=%" PRIu64,
-			     offset, size,
-			     MaxOffsetRead);
+			     "Read offset=%" PRIu64 " size=%" PRIu64
+			     " MaxOffSet=%" PRIu64,
+			     offset, size, MaxOffsetRead);
 
 		if ((offset + size) > MaxOffsetRead) {
-			LogEvent(COMPONENT_NFS_V4,
-				 "A client tried to violate max file size %"
-				 PRIu64 " for exportid #%hu",
-				 MaxOffsetRead,
-				 op_ctx->ctx_export->export_id);
+			LogEvent(
+				COMPONENT_NFS_V4,
+				"A client tried to violate max file size %" PRIu64
+				" for exportid #%hu",
+				MaxOffsetRead, op_ctx->ctx_export->export_id);
 			res_READ4->status = NFS4ERR_FBIG;
 			goto out;
 		}
@@ -688,7 +710,7 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 		if (info == NULL ||
 		    info->io_content.what != NFS4_CONTENT_HOLE) {
 			LogFullDebug(COMPONENT_NFS_V4,
-				     "read requested size = %"PRIu64
+				     "read requested size = %" PRIu64
 				     " read allowed size = %" PRIu64,
 				     size, MaxRead);
 			size = MaxRead;
@@ -712,16 +734,17 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 	if (size == 0) {
 		/** @todo Should we handle this case for READ_PLUS? */
 		/* A size = 0 can not lead to EOF */
-		res_READ4->READ4res_u.resok4.eof = false;
-		res_READ4->READ4res_u.resok4.data.data_len = 0;
-		res_READ4->READ4res_u.resok4.data.data_val = NULL;
+		resok->eof = false;
+		resok->data.data_len = 0;
+		resok->data.iovcnt = 1;
+		resok->data.iov = &resok->iov0;
+		resok->iov0.iov_len = 0;
+		resok->iov0.iov_base = NULL;
 		res_READ4->status = NFS4_OK;
 		goto out;
 	}
 
 	/* Some work is to be done */
-	bufferdata = gsh_malloc_aligned(4096, RNDUP(size));
-
 	if (!anonymous_started && data->minorversion == 0) {
 		owner = get_state_owner_ref(state_found);
 		if (owner != NULL) {
@@ -730,15 +753,26 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 		}
 	}
 
+	/* Set up result using internal iovec of length 1 that allows FSAL
+	 * layer to allocate the read buffer.
+	 */
+	resok->data.data_len = size;
+	resok->data.iovcnt = 1;
+	resok->data.iov = &resok->iov0;
+	resok->data.iov[0].iov_len = size;
+	resok->data.iov[0].iov_base = NULL;
+	resok->data.last_iov_buf_size = 0;
+	resok->data.release = read4_io_data_release;
+
 	/* Set up args, allocate from heap, iov_len will be 1 */
-	read_data = gsh_calloc(1, sizeof(*read_data) + sizeof(struct iovec));
+	read_data = gsh_calloc(1, sizeof(*read_data));
 	LogFullDebug(COMPONENT_NFS_V4, "Allocated read_data %p", read_data);
 	read_arg = &read_data->read_arg;
 	read_arg->state = state_found;
 	read_arg->offset = offset;
-	read_arg->iov_count = 1;
-	read_arg->iov[0].iov_len = size;
-	read_arg->iov[0].iov_base = bufferdata;
+	read_arg->iov_count = resok->data.iovcnt;
+	read_arg->last_iov_buf_size = &resok->data.last_iov_buf_size;
+	read_arg->iov = resok->data.iov;
 	read_arg->io_amount = 0;
 	read_arg->end_of_file = false;
 
@@ -757,15 +791,15 @@ static enum nfs_req_result nfs4_read(struct nfs_argop4 *op,
 again:
 
 	/* Do the actual read */
-	obj->obj_ops->read2(obj, bypass, nfs4_read_cb, read_arg, read_data);
+	fsal_read2(obj, bypass, nfs4_read_cb, read_arg, read_data);
 
 	/* Only atomically set the flags if we actually call read2, otherwise
 	 * we will have indicated as having been DONE.
 	 */
-	flags =
-	    atomic_postset_uint32_t_bits(&read_data->flags, ASYNC_PROC_EXIT);
+	flags = atomic_postset_uint32_t_bits(&read_data->flags,
+					     ASYNC_PROC_EXIT);
 
- out:
+out:
 
 	if (state_open != NULL) {
 		dec_state_t_ref(state_open);
@@ -785,9 +819,8 @@ again:
 
 	if (read_data != NULL && read_arg->fsal_resume) {
 		/* FSAL is requesting another read2 call */
-		atomic_postclear_uint32_t_bits(&read_data->flags,
-					       ASYNC_PROC_EXIT |
-					       ASYNC_PROC_DONE);
+		atomic_postclear_uint32_t_bits(
+			&read_data->flags, ASYNC_PROC_EXIT | ASYNC_PROC_DONE);
 		/* Make the call with the same params, though the FSAL will be
 		 * signaled by fsal_resume being set.
 		 */
@@ -795,7 +828,7 @@ again:
 	}
 
 	return nfsstat4_to_nfs_req_result(res_READ4->status);
-}				/* nfs4_op_read */
+} /* nfs4_op_read */
 
 /**
  * @brief The NFS4_OP_READ operation
@@ -818,8 +851,7 @@ enum nfs_req_result nfs4_op_read(struct nfs_argop4 *op, compound_data_t *data,
 	/* Say we are managing NFS4_OP_READ */
 	resp->resop = NFS4_OP_READ;
 
-	if ((data->minorversion > 0)
-	    && nfs4_Is_Fh_DSHandle(&data->currentFH)) {
+	if ((data->minorversion > 0) && nfs4_Is_Fh_DSHandle(&data->currentFH)) {
 		/* DS handle, call op_dsread */
 		return op_dsread(op, data, resp);
 	}
@@ -853,54 +885,18 @@ void xdr_READ4res_uio_release(struct xdr_uio *uio, u_int flags)
 	int ix;
 
 	LogFullDebug(COMPONENT_NFS_V4,
-		     "Releasing %p, references %"PRIi32", count %d",
-		     uio, uio->uio_references, (int) uio->uio_count);
+		     "Releasing %p, references %" PRIi32 ", count %d", uio,
+		     uio->uio_references, (int)uio->uio_count);
 
 	if (!(--uio->uio_references)) {
-		for (ix = 0; ix < uio->uio_count; ix++) {
-			gsh_free(uio->uio_vio[ix].vio_base);
+		if (!(op_ctx && op_ctx->is_rdma_buff_used)) {
+			for (ix = 0; ix < uio->uio_count; ix++)
+				gsh_free(uio->uio_vio[ix].vio_base);
 		}
 		gsh_free(uio);
 	}
 }
 
-struct xdr_uio *xdr_READ4res_uio_setup(struct READ4resok *objp)
-{
-	struct xdr_uio *uio;
-	u_int size = objp->data.data_len;
-	/* The size to actually be written must be a multiple of
-	 * BYTES_PER_XDR_UNIT
-	 */
-	u_int size2 = RNDUP(size);
-	int i;
-
-	if (size2 != size) {
-		/* Must zero out extra bytes */
-		for (i = size; i < size2; i++)
-			objp->data.data_val[i] = 0;
-	}
-
-	uio = gsh_calloc(1, sizeof(struct xdr_uio) + sizeof(struct xdr_vio));
-	uio->uio_release = xdr_READ4res_uio_release;
-	uio->uio_count = 1;
-	uio->uio_vio[0].vio_base = objp->data.data_val;
-	uio->uio_vio[0].vio_head = objp->data.data_val;
-	uio->uio_vio[0].vio_tail = objp->data.data_val + size2;
-	uio->uio_vio[0].vio_wrap = objp->data.data_val + size2;
-	uio->uio_vio[0].vio_length = objp->data.data_len;
-	uio->uio_vio[0].vio_type = VIO_DATA;
-
-	/* Take over read data buffer */
-	objp->data.data_val = NULL;
-	objp->data.data_len = 0;
-
-	LogFullDebug(COMPONENT_NFS_V4,
-		     "Allocated %p, references %"PRIi32", count %d",
-		     uio, uio->uio_references, (int) uio->uio_count);
-
-	return uio;
-}
-
 /**
  * @brief Free data allocated for READ result.
  *
@@ -912,11 +908,7 @@ struct xdr_uio *xdr_READ4res_uio_setup(struct READ4resok *objp)
  */
 void nfs4_op_read_Free(nfs_resop4 *res)
 {
-	READ4res *resp = &res->nfs_resop4_u.opread;
-
-	if (resp->status == NFS4_OK)
-		if (resp->READ4res_u.resok4.data.data_val != NULL)
-			gsh_free(resp->READ4res_u.resok4.data.data_val);
+	/* Nothing to clean up. */
 }
 
 /**
@@ -944,8 +936,7 @@ enum nfs_req_result nfs4_op_read_plus(struct nfs_argop4 *op,
 	/* Say we are managing NFS4_OP_READ_PLUS */
 	resp->resop = NFS4_OP_READ_PLUS;
 
-	if ((data->minorversion > 0)
-	    && nfs4_Is_Fh_DSHandle(&data->currentFH)) {
+	if ((data->minorversion > 0) && nfs4_Is_Fh_DSHandle(&data->currentFH)) {
 		/* DS handle, call op_dsread */
 		return op_dsread_plus(op, data, resp, &info);
 	}
@@ -963,9 +954,8 @@ enum nfs_req_result nfs4_op_read_plus(struct nfs_argop4 *op,
 	if (req_result == NFS_REQ_OK) {
 		struct nfs4_read_data *read_data = data->op_data;
 
-		nfs4_complete_read_plus(resp, read_data != NULL
-					      ? &read_data->info
-					      : &info);
+		nfs4_complete_read_plus(
+			resp, read_data != NULL ? &read_data->info : &info);
 	}
 
 	if (req_result != NFS_REQ_ASYNC_WAIT && data->op_data != NULL) {
@@ -987,9 +977,13 @@ void nfs4_op_read_plus_Free(nfs_resop4 *res)
 	READ_PLUS4res *resp = &res->nfs_resop4_u.opread_plus;
 	contents *conp = &resp->rpr_resok4.rpr_contents;
 
-	if (resp->rpr_status == NFS4_OK && conp->what == NFS4_CONTENT_DATA)
-		if (conp->data.d_data.data_val != NULL)
-			gsh_free(conp->data.d_data.data_val);
+	if (resp->rpr_status == NFS4_OK && conp->what == NFS4_CONTENT_DATA) {
+		if (!op_ctx->is_rdma_buff_used) {
+			if (conp->data.d_data.data_val != NULL)
+				gsh_free(conp->data.d_data.data_val);
+		}
+		conp->data.d_data.data_val = NULL;
+	}
 }
 
 /**
@@ -1008,8 +1002,8 @@ enum nfs_req_result nfs4_op_io_advise(struct nfs_argop4 *op,
 				      compound_data_t *data,
 				      struct nfs_resop4 *resp)
 {
-	IO_ADVISE4args * const arg_IO_ADVISE = &op->nfs_argop4_u.opio_advise;
-	IO_ADVISE4res * const res_IO_ADVISE = &resp->nfs_resop4_u.opio_advise;
+	IO_ADVISE4args *const arg_IO_ADVISE = &op->nfs_argop4_u.opio_advise;
+	IO_ADVISE4res *const res_IO_ADVISE = &resp->nfs_resop4_u.opio_advise;
 	fsal_status_t fsal_status = { 0, 0 };
 	struct io_hints hints;
 	state_t *state_found = NULL;
@@ -1030,8 +1024,8 @@ enum nfs_req_result nfs4_op_io_advise(struct nfs_argop4 *op,
 
 	/* Do basic checks on a filehandle Only files can be set */
 
-	res_IO_ADVISE->iaa_status = nfs4_sanity_check_FH(data, REGULAR_FILE,
-							 true);
+	res_IO_ADVISE->iaa_status =
+		nfs4_sanity_check_FH(data, REGULAR_FILE, true);
 	if (res_IO_ADVISE->iaa_status != NFS4_OK)
 		goto done;
 
@@ -1039,10 +1033,9 @@ enum nfs_req_result nfs4_op_io_advise(struct nfs_argop4 *op,
 	/* Check stateid correctness and get pointer to state (also
 	   checks for special stateids) */
 
-	res_IO_ADVISE->iaa_status =
-	    nfs4_Check_Stateid(&arg_IO_ADVISE->iaa_stateid, obj,
-				&state_found, data,  STATEID_SPECIAL_ANY,
-				0, false, "IO_ADVISE");
+	res_IO_ADVISE->iaa_status = nfs4_Check_Stateid(
+		&arg_IO_ADVISE->iaa_stateid, obj, &state_found, data,
+		STATEID_SPECIAL_ANY, 0, false, "IO_ADVISE");
 	if (res_IO_ADVISE->iaa_status != NFS4_OK)
 		goto done;
 
@@ -1066,14 +1059,14 @@ enum nfs_req_result nfs4_op_io_advise(struct nfs_argop4 *op,
 done:
 	LogDebug(COMPONENT_NFS_V4,
 		 "Status  %s hints 0x%X offset %" PRIu64 " count %" PRIu64,
-		 nfsstat4_to_str(res_IO_ADVISE->iaa_status),
-		 hints.hints, hints.offset, hints.count);
+		 nfsstat4_to_str(res_IO_ADVISE->iaa_status), hints.hints,
+		 hints.offset, hints.count);
 
 	if (state_found != NULL)
 		dec_state_t_ref(state_found);
 
 	return nfsstat4_to_nfs_req_result(res_IO_ADVISE->iaa_status);
-}				/* nfs4_op_io_advise */
+} /* nfs4_op_io_advise */
 
 /**
  * @brief Free memory allocated for IO_ADVISE result
@@ -1088,13 +1081,11 @@ void nfs4_op_io_advise_Free(nfs_resop4 *resp)
 	/* Nothing to be done */
 }
 
-
-enum nfs_req_result nfs4_op_seek(struct nfs_argop4 *op,
-				 compound_data_t *data,
+enum nfs_req_result nfs4_op_seek(struct nfs_argop4 *op, compound_data_t *data,
 				 struct nfs_resop4 *resp)
 {
-	SEEK4args * const arg_SEEK = &op->nfs_argop4_u.opseek;
-	SEEK4res * const res_SEEK = &resp->nfs_resop4_u.opseek;
+	SEEK4args *const arg_SEEK = &op->nfs_argop4_u.opseek;
+	SEEK4res *const res_SEEK = &resp->nfs_resop4_u.opseek;
 	fsal_status_t fsal_status = { 0, 0 };
 	state_t *state_found = NULL;
 	struct fsal_obj_handle *obj = NULL;
@@ -1119,9 +1110,8 @@ enum nfs_req_result nfs4_op_seek(struct nfs_argop4 *op,
 	   checks for special stateids) */
 
 	res_SEEK->sr_status =
-	    nfs4_Check_Stateid(&arg_SEEK->sa_stateid, obj,
-				&state_found, data,  STATEID_SPECIAL_ANY,
-				0, false, "SEEK");
+		nfs4_Check_Stateid(&arg_SEEK->sa_stateid, obj, &state_found,
+				   data, STATEID_SPECIAL_ANY, 0, false, "SEEK");
 	if (res_SEEK->sr_status != NFS4_OK)
 		goto done;
 
@@ -1130,7 +1120,7 @@ enum nfs_req_result nfs4_op_seek(struct nfs_argop4 *op,
 		info.io_content.what = arg_SEEK->sa_what;
 
 		if (arg_SEEK->sa_what == NFS4_CONTENT_DATA ||
-				arg_SEEK->sa_what == NFS4_CONTENT_HOLE) {
+		    arg_SEEK->sa_what == NFS4_CONTENT_HOLE) {
 			info.io_content.hole.di_offset = arg_SEEK->sa_offset;
 		} else
 			info.io_content.adb.adb_offset = arg_SEEK->sa_offset;
@@ -1144,8 +1134,7 @@ enum nfs_req_result nfs4_op_seek(struct nfs_argop4 *op,
 		res_SEEK->sr_resok4.sr_offset = info.io_content.hole.di_offset;
 	}
 done:
-	LogDebug(COMPONENT_NFS_V4,
-		 "Status  %s type %d offset %" PRIu64,
+	LogDebug(COMPONENT_NFS_V4, "Status  %s type %d offset %" PRIu64,
 		 nfsstat4_to_str(res_SEEK->sr_status), arg_SEEK->sa_what,
 		 arg_SEEK->sa_offset);
 
@@ -1154,4 +1143,3 @@ done:
 
 	return nfsstat4_to_nfs_req_result(res_SEEK->sr_status);
 }
-
