@@ -56,17 +56,21 @@
  * @return per RFC5661, pp. 372-3
  */
 
-enum nfs_req_result nfs4_op_remove(struct nfs_argop4 *op,
-				   compound_data_t *data,
+enum nfs_req_result nfs4_op_remove(struct nfs_argop4 *op, compound_data_t *data,
 				   struct nfs_resop4 *resp)
 {
-	REMOVE4args * const arg_REMOVE4 = &op->nfs_argop4_u.opremove;
-	REMOVE4res * const res_REMOVE4 = &resp->nfs_resop4_u.opremove;
+	REMOVE4args *const arg_REMOVE4 = &op->nfs_argop4_u.opremove;
+	REMOVE4res *const res_REMOVE4 = &resp->nfs_resop4_u.opremove;
 	struct fsal_obj_handle *parent_obj = NULL;
-	fsal_status_t fsal_status = {0, 0};
+	fsal_status_t fsal_status = { 0, 0 };
+	struct fsal_attrlist parent_pre_attrs, parent_post_attrs;
+	bool is_parent_pre_attrs_valid, is_parent_post_attrs_valid;
 
 	resp->resop = NFS4_OP_REMOVE;
 
+	fsal_prepare_attrs(&parent_pre_attrs, ATTR_CHANGE);
+	fsal_prepare_attrs(&parent_post_attrs, ATTR_CHANGE);
+
 	/* Do basic checks on a filehandle
 	 * Delete arg_REMOVE4.target in directory pointed by currentFH
 	 * Make sure the currentFH is pointed a directory
@@ -93,32 +97,51 @@ enum nfs_req_result nfs4_op_remove(struct nfs_argop4 *op,
 	/* We have to keep track of the 'change' file attribute
 	 * for reply structure
 	 */
-	memset(&res_REMOVE4->REMOVE4res_u.resok4.cinfo.before,
-	       0,
+	memset(&res_REMOVE4->REMOVE4res_u.resok4.cinfo.before, 0,
 	       sizeof(changeid4));
 
 	res_REMOVE4->REMOVE4res_u.resok4.cinfo.before =
-	    fsal_get_changeid4(parent_obj);
+		fsal_get_changeid4(parent_obj);
 
 	fsal_status = fsal_remove(parent_obj,
-				  arg_REMOVE4->target.utf8string_val);
+				  arg_REMOVE4->target.utf8string_val,
+				  &parent_pre_attrs, &parent_post_attrs);
 
 	if (FSAL_IS_ERROR(fsal_status)) {
 		res_REMOVE4->status = nfs4_Errno_status(fsal_status);
 		goto out_put_grace;
 	}
 
-	res_REMOVE4->REMOVE4res_u.resok4.cinfo.after =
-	    fsal_get_changeid4(parent_obj);
+	is_parent_pre_attrs_valid =
+		FSAL_TEST_MASK(parent_pre_attrs.valid_mask, ATTR_CHANGE);
+	if (is_parent_pre_attrs_valid) {
+		res_REMOVE4->REMOVE4res_u.resok4.cinfo.before =
+			(changeid4)parent_pre_attrs.change;
+	}
+
+	is_parent_post_attrs_valid =
+		FSAL_TEST_MASK(parent_post_attrs.valid_mask, ATTR_CHANGE);
+	if (is_parent_post_attrs_valid) {
+		res_REMOVE4->REMOVE4res_u.resok4.cinfo.after =
+			(changeid4)parent_post_attrs.change;
+	} else {
+		res_REMOVE4->REMOVE4res_u.resok4.cinfo.after =
+			fsal_get_changeid4(parent_obj);
+	}
+
+	res_REMOVE4->REMOVE4res_u.resok4.cinfo.atomic =
+		is_parent_pre_attrs_valid && is_parent_post_attrs_valid ? TRUE :
+									  FALSE;
 
-	/* Operation was not atomic .... */
-	res_REMOVE4->REMOVE4res_u.resok4.cinfo.atomic = FALSE;
 out_put_grace:
+	fsal_release_attrs(&parent_pre_attrs);
+	fsal_release_attrs(&parent_post_attrs);
+
 	nfs_put_grace_status();
 out:
 
 	return nfsstat4_to_nfs_req_result(res_REMOVE4->status);
-}				/* nfs4_op_remove */
+} /* nfs4_op_remove */
 
 /**
  * @brief Free memory allocated for REMOVE result
