@@ -82,9 +82,15 @@ uint64_t clientid_verifier;
  */
 pool_t *client_id_pool;
 
-
 static uint64_t num_confirmed_client_ids;
 
+uint32_t num_of_curr_expired_clients;
+/**
+ * @brief Global list to store expired client IDs and it's mutex
+ */
+struct glist_head expired_client_ids_list;
+pthread_mutex_t expired_client_ids_list_lock;
+
 /**
  * @brief Return the NFSv4 status for the client id error code
  *
@@ -147,8 +153,8 @@ const char *clientid_error_to_str(clientid_status_t err)
  * @return Corresponding string.
  */
 
-const char *clientid_confirm_state_to_str(nfs_clientid_confirm_state_t
-					  confirmed)
+const char *
+clientid_confirm_state_to_str(nfs_clientid_confirm_state_t confirmed)
 {
 	switch (confirmed) {
 	case CONFIRMED_CLIENT_ID:
@@ -186,8 +192,7 @@ int display_client_id_rec(struct display_buffer *dspbuf,
 		return b_left;
 
 	b_left = display_printf(
-		dspbuf,
-		"} %s Client={",
+		dspbuf, "} %s ClientRec={",
 		clientid_confirm_state_to_str(clientid->cid_confirmed));
 
 	if (b_left <= 0)
@@ -203,21 +208,28 @@ int display_client_id_rec(struct display_buffer *dspbuf,
 	else
 		delta = time(NULL) - clientid->cid_last_renew;
 
-	b_left = display_printf(dspbuf,
-				"} t_delta=%d reservations=%d refcount=%"PRIu32,
-				delta, clientid->cid_lease_reservations,
-				atomic_fetch_int32_t(&clientid->cid_refcount));
+	b_left = display_printf(
+		dspbuf,
+		"} t_delta=%d reservations=%d cid_refcount=%d files_opened=%u,",
+		delta, clientid->cid_lease_reservations,
+		atomic_fetch_int32_t(&clientid->cid_refcount),
+		atomic_fetch_uint32_t(&clientid->cid_open_state_counter));
+
+	if (b_left <= 0)
+		return b_left;
+
+	b_left = display_printf(dspbuf, "} cred_flavor=%u",
+				clientid->cid_credential.flavor);
 
 	if (b_left <= 0)
 		return b_left;
 
 	if (clientid->cid_minorversion == 0) {
-		b_left = display_printf(dspbuf,
-					" cb_prog=%u r_addr=%s r_netid=%s",
-					clientid->cid_cb.v40.cb_program,
-					clientid->cid_cb.v40.cb_client_r_addr,
-					netid_nc_table[clientid->cid_cb.v40
-						.cb_addr.nc].netid);
+		b_left = display_printf(
+			dspbuf, " cb_prog=%u r_addr=%s r_netid=%s",
+			clientid->cid_cb.v40.cb_program,
+			clientid->cid_cb.v40.cb_client_r_addr,
+			netid_nc_table[clientid->cid_cb.v40.cb_addr.nc].netid);
 	}
 
 	return b_left;
@@ -235,8 +247,7 @@ int display_clientid_name(struct display_buffer *dspbuf,
 			  nfs_client_id_t *clientid)
 {
 	return display_opaque_value(
-		dspbuf,
-		clientid->cid_client_record->cr_client_val,
+		dspbuf, clientid->cid_client_record->cr_client_val,
 		clientid->cid_client_record->cr_client_val_len);
 }
 
@@ -263,11 +274,11 @@ int32_t inc_client_id_ref(nfs_client_id_t *clientid)
 
 	if (isFullDebug(COMPONENT_CLIENTID)) {
 		char str[LOG_BUFF_LEN] = "\0";
-		struct display_buffer dspbuf = {sizeof(str), str, str};
+		struct display_buffer dspbuf = { sizeof(str), str, str };
 
 		display_client_id_rec(&dspbuf, clientid);
 		LogFullDebug(COMPONENT_CLIENTID,
-			     "Increment refcount Clientid {%s} to %" PRId32,
+			     "Increment cid_refcount Clientid {%s} to %" PRId32,
 			     str, cid_refcount);
 	}
 
@@ -332,11 +343,11 @@ void free_client_id(nfs_client_id_t *clientid)
 		struct glist_head *glistn = NULL;
 
 		glist_for_each_safe(glist, glistn,
-				    &clientid->cid_cb.v41.cb_session_list) {
-			nfs41_session_t *session = glist_entry(glist,
-							       nfs41_session_t,
-							       session_link);
-			nfs41_Session_Del(session->session_id);
+				    &clientid->cid_cb.v41.cb_session_list)
+		{
+			nfs41_session_t *session = glist_entry(
+				glist, nfs41_session_t, session_link);
+			nfs41_Session_Del(session);
 		}
 	}
 
@@ -361,7 +372,7 @@ void free_client_id(nfs_client_id_t *clientid)
 int32_t dec_client_id_ref(nfs_client_id_t *clientid)
 {
 	char str[LOG_BUFF_LEN] = "\0";
-	struct display_buffer dspbuf = {sizeof(str), str, str};
+	struct display_buffer dspbuf = { sizeof(str), str, str };
 	int32_t cid_refcount;
 
 	if (isFullDebug(COMPONENT_CLIENTID))
@@ -370,8 +381,8 @@ int32_t dec_client_id_ref(nfs_client_id_t *clientid)
 	cid_refcount = atomic_dec_int32_t(&clientid->cid_refcount);
 
 	LogFullDebug(COMPONENT_CLIENTID,
-		     "Decrement refcount Clientid {%s} refcount to %" PRId32,
-		     str, cid_refcount);
+		     "Decrement refcount Clientid {%s} cid_refcount to %d", str,
+		     cid_refcount);
 
 	assert(cid_refcount >= 0);
 
@@ -385,7 +396,7 @@ int32_t dec_client_id_ref(nfs_client_id_t *clientid)
 	if (clientid->cid_confirmed == EXPIRED_CLIENT_ID) {
 		/* Is not in any hash table, so we can just delete it */
 		LogFullDebug(COMPONENT_CLIENTID,
-			     "Free Clientid refcount now=0 {%s}", str);
+			     "Free Clientid cid_refcount now=0 {%s}", str);
 
 		free_client_id(clientid);
 	} else {
@@ -423,7 +434,7 @@ uint32_t client_id_value_hash_func(hash_parameter_t *hparam,
 
 	memcpy(&clientid, key->addr, sizeof(clientid));
 
-	return (uint32_t) clientid % hparam->index_size;
+	return (uint32_t)clientid % hparam->index_size;
 }
 
 /**
@@ -468,8 +479,8 @@ uint64_t client_id_rbt_hash_func(hash_parameter_t *hparam,
  */
 int compare_client_id(struct gsh_buffdesc *buff1, struct gsh_buffdesc *buff2)
 {
-	clientid4 cl1 = *((clientid4 *) (buff1->addr));
-	clientid4 cl2 = *((clientid4 *) (buff2->addr));
+	clientid4 cl1 = *((clientid4 *)(buff1->addr));
+	clientid4 cl2 = *((clientid4 *)(buff2->addr));
 
 	return (cl1 == cl2) ? 0 : 1;
 }
@@ -483,7 +494,7 @@ int compare_client_id(struct gsh_buffdesc *buff1, struct gsh_buffdesc *buff2)
 int display_client_id_key(struct display_buffer *dspbuf,
 			  struct gsh_buffdesc *buff)
 {
-	return display_clientid(dspbuf, *((clientid4 *) (buff->addr)));
+	return display_clientid(dspbuf, *((clientid4 *)(buff->addr)));
 }
 
 /**
@@ -577,6 +588,10 @@ nfs_client_id_t *create_client_id(clientid4 clientid,
 	/* Get a reference to the client record */
 	(void)inc_client_record_ref(client_rec->cid_client_record);
 
+	/* Init the list head for expired_client */
+	glist_init(&client_rec->expired_client);
+	client_rec->marked_for_delayed_cleanup = false;
+
 	return client_rec;
 }
 
@@ -600,10 +615,10 @@ clientid_status_t nfs_client_id_insert(nfs_client_id_t *clientid)
 
 	if (nfs_param.nfsv4_param.max_client_ids &&
 	    atomic_fetch_uint64_t(&num_confirmed_client_ids) >
-		 nfs_param.nfsv4_param.max_client_ids) {
+		    nfs_param.nfsv4_param.max_client_ids) {
 		LogDebug(COMPONENT_CLIENTID,
-			 "Max client_id limit reached - clientid %"
-			 PRIx64, clientid->cid_clientid);
+			 "Max client_id limit reached - clientid %" PRIx64,
+			 clientid->cid_clientid);
 
 		/* Free the clientid record and return */
 		free_client_id(clientid);
@@ -624,8 +639,8 @@ clientid_status_t nfs_client_id_insert(nfs_client_id_t *clientid)
 	if (rc != HASHTABLE_SUCCESS) {
 		LogDebug(COMPONENT_CLIENTID,
 			 "Could not insert unconfirmed clientid %" PRIx64
-			 " error=%s", clientid->cid_clientid,
-			 hash_table_err_to_str(rc));
+			 " error=%s",
+			 clientid->cid_clientid, hash_table_err_to_str(rc));
 
 		/* Free the clientid record and return */
 		free_client_id(clientid);
@@ -672,8 +687,8 @@ int remove_confirmed_client_id(nfs_client_id_t *clientid)
 	if (rc != HASHTABLE_SUCCESS) {
 		LogDebug(COMPONENT_CLIENTID,
 			 "Could not remove unconfirmed clientid %" PRIx64
-			 " error=%s", clientid->cid_clientid,
-			 hash_table_err_to_str(rc));
+			 " error=%s",
+			 clientid->cid_clientid, hash_table_err_to_str(rc));
 		return rc;
 	}
 
@@ -713,8 +728,8 @@ int remove_unconfirmed_client_id(nfs_client_id_t *clientid)
 	if (rc != HASHTABLE_SUCCESS) {
 		LogCrit(COMPONENT_CLIENTID,
 			"Could not remove unconfirmed clientid %" PRIx64
-			" error=%s", clientid->cid_clientid,
-			hash_table_err_to_str(rc));
+			" error=%s",
+			clientid->cid_clientid, hash_table_err_to_str(rc));
 		return rc;
 	}
 
@@ -767,7 +782,8 @@ clientid_status_t nfs_client_id_confirm(nfs_client_id_t *clientid,
 	if (rc != HASHTABLE_SUCCESS) {
 		if (isDebug(COMPONENT_CLIENTID)) {
 			char str[LOG_BUFF_LEN] = "\0";
-			struct display_buffer dspbuf = {sizeof(str), str, str};
+			struct display_buffer dspbuf = { sizeof(str), str,
+							 str };
 
 			display_client_id_rec(&dspbuf, clientid);
 
@@ -788,7 +804,8 @@ clientid_status_t nfs_client_id_confirm(nfs_client_id_t *clientid,
 	if (rc != HASHTABLE_SUCCESS) {
 		if (isDebug(COMPONENT_CLIENTID)) {
 			char str[LOG_BUFF_LEN] = "\0";
-			struct display_buffer dspbuf = {sizeof(str), str, str};
+			struct display_buffer dspbuf = { sizeof(str), str,
+							 str };
 
 			display_client_id_rec(&dspbuf, clientid);
 
@@ -838,11 +855,11 @@ bool clientid_has_state(nfs_client_id_t *clientid)
 	 */
 
 	/* Check if any open owners have active open state. */
-	glist_for_each(glist, &clientid->cid_openowners) {
-		live_state = owner_has_state(glist_entry(
-			glist,
-			state_owner_t,
-			so_owner.so_nfs4_owner.so_perclient));
+	glist_for_each(glist, &clientid->cid_openowners)
+	{
+		live_state = owner_has_state(
+			glist_entry(glist, state_owner_t,
+				    so_owner.so_nfs4_owner.so_perclient));
 
 		if (live_state)
 			break;
@@ -859,6 +876,98 @@ bool clientid_has_state(nfs_client_id_t *clientid)
 	return live_state;
 }
 
+/*
+ * @brief compare routine used to sort expired client items
+ *
+ * Function used to sort the expired client items according
+ * to lease renew time.  Conforms to the glist_compare
+ * function signature so it can be used with glist_insert_sorted
+ *
+ * @param a: Pointer to the glist of a expired client
+ * @param b: Pointer to the glist of another expired client
+ *           to compare the first to
+ */
+int expired_client_item_compare(struct glist_head *a, struct glist_head *b)
+{
+	nfs_client_id_t *client_item_a;
+	nfs_client_id_t *client_item_b;
+
+	client_item_a = glist_entry(a, nfs_client_id_t, expired_client);
+	client_item_b = glist_entry(b, nfs_client_id_t, expired_client);
+	if (client_item_a->cid_last_renew <= client_item_b->cid_last_renew)
+		return -1;
+
+	return 1;
+}
+
+/*
+ * @brief API to print the expired client items
+ *
+ * @param[in] NA
+ *
+ * @retval NA
+ */
+void print_expired_client_list(void)
+{
+	/* expired_client iterator */
+	struct glist_head *expired_client_i = NULL;
+	/* Next expired_client */
+	struct glist_head *expired_client_n = NULL;
+
+	glist_for_each_safe(expired_client_i, expired_client_n,
+			    &expired_client_ids_list)
+	{
+		char str[LOG_BUFF_LEN] = "\0";
+		struct display_buffer dspbuf = { sizeof(str), str, str };
+
+		/* The client to expire finally */
+		struct nfs_client_id_t *expired_client =
+			glist_entry(expired_client_i, struct nfs_client_id_t,
+				    expired_client);
+
+		display_client_id_rec(&dspbuf, expired_client);
+		LogFullDebug(COMPONENT_CLIENTID, "Expired Client Entry %s",
+			     str);
+	}
+}
+
+/**
+ * @brief Remove client from expired client list.
+ *
+ * @param[in] active_clientid The client id of interest
+ *
+ * @retval NA
+ */
+void remove_client_from_expired_client_list(nfs_client_id_t *active_clientid)
+{
+	/* expired_client iterator */
+	struct glist_head *expired_client_i = NULL;
+	/* Next expired_client */
+	struct glist_head *expired_client_n = NULL;
+
+	PTHREAD_MUTEX_lock(&expired_client_ids_list_lock);
+	glist_for_each_safe(expired_client_i, expired_client_n,
+			    &expired_client_ids_list)
+	{
+		struct nfs_client_id_t *expired_client =
+			glist_entry(expired_client_i, struct nfs_client_id_t,
+				    expired_client);
+
+		if (active_clientid->cid_clientid !=
+		    expired_client->cid_clientid) {
+			continue;
+		}
+
+		/* Found the client to be removed */
+		glist_del(&expired_client->expired_client);
+		expired_client->marked_for_delayed_cleanup = false;
+		/* Drop ref of the expired_client as it's gone valid */
+		dec_client_id_ref(expired_client);
+		atomic_dec_uint32_t(&num_of_curr_expired_clients);
+	}
+	PTHREAD_MUTEX_unlock(&expired_client_ids_list_lock);
+}
+
 /**
  * @brief Client expires, need to take care of owners
  *
@@ -868,10 +977,12 @@ bool clientid_has_state(nfs_client_id_t *clientid)
  *
  * @param[in] clientid The client id to expire
  * @param[in] make_stale  Set if client id expire is due to ip move.
+ * @param[in] force_expire  Expire up the client id by force.
  *
  * @return true if the clientid is successfully expired.
  */
-bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale)
+bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale,
+			  bool force_expire)
 {
 	int rc, held;
 	struct gsh_buffdesc buffkey;
@@ -879,8 +990,7 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale)
 	struct gsh_buffdesc old_value;
 	hash_table_t *ht_expire;
 	char str[LOG_BUFF_LEN] = "\0";
-	struct display_buffer dspbuf = {sizeof(str), str, str};
-	bool str_valid = false;
+	struct display_buffer dspbuf = { sizeof(str), str, str };
 	struct req_op_context op_context;
 
 	/* Initialize op_context */
@@ -899,6 +1009,46 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale)
 		return false;
 	}
 
+	if (!make_stale && !force_expire &&
+	    nfs_param.nfsv4_param.expired_client_threshold) {
+		/* Judging the amount of states the client owns.
+		 * If it has large number of opened files, we may not want
+		 * to hold the memory for a client that has gone away. */
+		if (atomic_fetch_uint32_t(&clientid->cid_open_state_counter) <
+		    nfs_param.nfsv4_param.max_open_files_for_expired_client) {
+			/* We have an expired client to be added to list */
+			atomic_inc_uint32_t(&num_of_curr_expired_clients);
+
+			/* Take a ref for clientid and add to list */
+			inc_client_id_ref(clientid);
+			clientid->marked_for_delayed_cleanup = true;
+			PTHREAD_MUTEX_unlock(&clientid->cid_mutex);
+
+			if (isFullDebug(COMPONENT_CLIENTID)) {
+				display_client_id_rec(&dspbuf, clientid);
+				LogFullDebug(
+					COMPONENT_CLIENTID,
+					"Adding Expired Client{%s} for delayed cleanup, Threshold(%u) Curr_Expired(%u).",
+					str,
+					nfs_param.nfsv4_param
+						.expired_client_threshold,
+					atomic_fetch_uint32_t(
+						&num_of_curr_expired_clients));
+			}
+			PTHREAD_MUTEX_lock(&expired_client_ids_list_lock);
+			/* Sort entries based on cid_last_renew */
+			glist_insert_sorted(&expired_client_ids_list,
+					    &clientid->expired_client,
+					    &expired_client_item_compare);
+			PTHREAD_MUTEX_unlock(&expired_client_ids_list_lock);
+			if (isDebug(COMPONENT_CLIENTID))
+				print_expired_client_list();
+
+			release_op_context();
+			return false;
+		}
+	}
+
 	if (isDebug(COMPONENT_CLIENTID)) {
 		display_client_id_rec(&dspbuf, clientid);
 		LogDebug(COMPONENT_CLIENTID, "Expiring {%s}", str);
@@ -934,17 +1084,16 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale)
 		if ((rc != HASHTABLE_SUCCESS) &&
 		    (clientid->cid_confirmed == STALE_CLIENT_ID)) {
 			/* Try in the unconfirmed hash table */
-			rc = HashTable_Del(ht_unconfirmed_client_id,
-					   &buffkey,
-					   &old_key,
-					   &old_value);
+			rc = HashTable_Del(ht_unconfirmed_client_id, &buffkey,
+					   &old_key, &old_value);
 		}
 
 		if (rc != HASHTABLE_SUCCESS) {
 			LogFatal(COMPONENT_CLIENTID,
-				"Could not remove expired clientid %" PRIx64
-				" error=%s", clientid->cid_clientid,
-				hash_table_err_to_str(rc));
+				 "Could not remove expired clientid %" PRIx64
+				 " error=%s",
+				 clientid->cid_clientid,
+				 hash_table_err_to_str(rc));
 		} else if (ht_expire == ht_confirmed_client_id)
 			atomic_dec_uint64_t(&num_confirmed_client_ids);
 	}
@@ -958,6 +1107,7 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale)
 	 */
 	while (true) {
 		state_owner_t *owner;
+		int32_t refcount;
 
 		PTHREAD_MUTEX_lock(&clientid->cid_mutex);
 
@@ -965,7 +1115,6 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale)
 					  state_owner_t,
 					  so_owner.so_nfs4_owner.so_perclient);
 
-
 		if (owner == NULL) {
 			PTHREAD_MUTEX_unlock(&clientid->cid_mutex);
 			break;
@@ -993,21 +1142,24 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale)
 
 		state_nfs4_owner_unlock_all(owner);
 
-		if (isFullDebug(COMPONENT_CLIENTID)) {
+		refcount = atomic_fetch_int32_t(&owner->so_refcount);
+
+		if ((refcount > 1) || (isFullDebug(COMPONENT_CLIENTID))) {
 			char str[LOG_BUFF_LEN] = "\0";
-			struct display_buffer dspbuf = {sizeof(str), str, str};
-			int32_t refcount =
-			    atomic_fetch_int32_t(&owner->so_refcount);
+			struct display_buffer dspbuf = { sizeof(str), str,
+							 str };
 
 			display_owner(&dspbuf, owner);
 
 			if (refcount > 1)
 				LogWarn(COMPONENT_CLIENTID,
-					"Expired State, Possibly extra references to {%s}",
+					"Expired State - Lock Owners, Possibly extra references to {%s}",
 					str);
 			else
-				LogFullDebug(COMPONENT_CLIENTID,
-					     "Expired State for {%s}", str);
+				LogFullDebug(
+					COMPONENT_CLIENTID,
+					"Expired State - Lock Owners, for {%s}",
+					str);
 		}
 
 		dec_state_owner_ref(owner);
@@ -1024,6 +1176,7 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale)
 	 */
 	while (true) {
 		state_owner_t *owner;
+		int32_t refcount;
 
 		PTHREAD_MUTEX_lock(&clientid->cid_mutex);
 
@@ -1058,21 +1211,25 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale)
 
 		release_openstate(owner);
 
-		if (isFullDebug(COMPONENT_CLIENTID)) {
+		refcount = atomic_fetch_int32_t(&owner->so_refcount);
+
+		if ((refcount > 1) || (isFullDebug(COMPONENT_CLIENTID))) {
 			char str[LOG_BUFF_LEN] = "\0";
-			struct display_buffer dspbuf = {sizeof(str), str, str};
-			int32_t refcount =
-			    atomic_fetch_int32_t(&owner->so_refcount);
+			struct display_buffer dspbuf = { sizeof(str), str,
+							 str };
 
 			display_owner(&dspbuf, owner);
 
 			if (refcount > 1)
-				LogFatal(COMPONENT_CLIENTID,
-					 "Expired State, Possibly extra references to {%s}",
-					 str);
+				LogFatal(
+					COMPONENT_CLIENTID,
+					"Expired State - Open Owners, Possibly extra references to {%s}",
+					str);
 			else
-				LogFullDebug(COMPONENT_CLIENTID,
-					     "Expired State for {%s}", str);
+				LogFullDebug(
+					COMPONENT_CLIENTID,
+					"Expired State - Open Owners, for {%s}",
+					str);
 		}
 
 		dec_state_owner_ref(owner);
@@ -1092,16 +1249,16 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale)
 		struct glist_head *glistn = NULL;
 
 		glist_for_each_safe(glist, glistn,
-				    &clientid->cid_cb.v41.cb_session_list) {
-			nfs41_session_t *session = glist_entry(glist,
-							       nfs41_session_t,
-							       session_link);
+				    &clientid->cid_cb.v41.cb_session_list)
+		{
+			nfs41_session_t *session = glist_entry(
+				glist, nfs41_session_t, session_link);
 
-			if (!nfs41_Session_Del(session->session_id)) {
+			if (!nfs41_Session_Del(session)) {
+				display_reset_buffer(&dspbuf);
 				display_client_id_rec(&dspbuf, clientid);
 				LogCrit(COMPONENT_SESSIONS,
-					"Expire session failed for {%s}",
-					str);
+					"Expire session failed for {%s}", str);
 			}
 		}
 
@@ -1121,11 +1278,11 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale)
 	}
 
 	if (isDebug(COMPONENT_CLIENTID)) {
+		display_reset_buffer(&dspbuf);
 		display_client_id_rec(&dspbuf, clientid);
 		LogDebug(COMPONENT_CLIENTID,
 			 "Expired (done), about to release last reference {%s}",
 			 str);
-		str_valid = true;
 	}
 
 	/* Release the hash table reference to the clientid. */
@@ -1133,8 +1290,8 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale)
 		(void)dec_client_id_ref(clientid);
 
 	if (isFullDebug(COMPONENT_CLIENTID)) {
-		if (!str_valid)
-			display_printf(&dspbuf, "clientid %p", clientid);
+		display_reset_buffer(&dspbuf);
+		display_client_id_rec(&dspbuf, clientid);
 		LogFullDebug(COMPONENT_CLIENTID,
 			     "Expired (done), released last reference {%s}",
 			     str);
@@ -1144,6 +1301,145 @@ bool nfs_client_id_expire(nfs_client_id_t *clientid, bool make_stale)
 	return true;
 }
 
+/**
+ * @brief Expire the expired clients added to the client list
+ *
+ * Once the threshold of number of expired clients reaches,
+ * this API is invoked to actually start cleaning them up.
+ *
+ * @param[in] conflicted_client The conflicted client id to expire.
+ *				If passed NULL, judge and clean all expired
+ *				ones in the list.
+ *
+ * @return the count of clientids expired.
+ */
+int reap_expired_client_list(nfs_client_id_t *conflicted_client)
+{
+	/* expired_client iterator */
+	struct glist_head *expired_client_i = NULL;
+	/* Next expired_client */
+	struct glist_head *expired_client_n = NULL;
+	nfs_client_record_t *client_rec;
+	int count = 0;
+
+	/* If feature disabled or no expired clients present
+	 * then skip the expired list reaper task
+	 */
+	if (!((nfs_param.nfsv4_param.expired_client_threshold) &&
+	      (atomic_fetch_uint32_t(&num_of_curr_expired_clients)))) {
+		return count;
+	} else {
+		LogFullDebug(
+			COMPONENT_CLIENTID,
+			"Reaping expired client list with client(%p) Curr_Expired(%u) Threshold(%u)",
+			conflicted_client,
+			atomic_fetch_uint32_t(&num_of_curr_expired_clients),
+			nfs_param.nfsv4_param.expired_client_threshold);
+	}
+
+	PTHREAD_MUTEX_lock(&expired_client_ids_list_lock);
+	if (isDebug(COMPONENT_CLIENTID))
+		print_expired_client_list();
+
+	/* Let's start cleaning */
+	glist_for_each_safe(expired_client_i, expired_client_n,
+			    &expired_client_ids_list)
+	{
+		char str[LOG_BUFF_LEN] = "\0";
+		struct display_buffer dspbuf = { sizeof(str), str, str };
+
+		/* The client to expire finally */
+		struct nfs_client_id_t *expired_client =
+			glist_entry(expired_client_i, struct nfs_client_id_t,
+				    expired_client);
+
+		/* If conflicting client has been passed, we need expire it */
+		if (conflicted_client) {
+			if (conflicted_client->cid_clientid !=
+			    expired_client->cid_clientid)
+				continue;
+			/* Breaking if max threshold not reached OR client had got
+		 * expired within Max_Alive_Time_For_Expired_Client
+		 */
+		} else if (!(((time(NULL) - expired_client->cid_last_renew) >=
+			      nfs_param.nfsv4_param
+				      .max_alive_time_for_expired_client) ||
+			     (atomic_fetch_uint32_t(
+				      &num_of_curr_expired_clients) >
+			      nfs_param.nfsv4_param.expired_client_threshold))) {
+			PTHREAD_MUTEX_unlock(&expired_client_ids_list_lock);
+			LogFullDebug(COMPONENT_CLIENTID,
+				     "No expired clients ready for cleanup");
+			return count;
+		}
+
+		PTHREAD_MUTEX_lock(&expired_client->cid_mutex);
+		/* Recheck once again before cleaning up, if it became active */
+		if (valid_lease(expired_client, true)) {
+			PTHREAD_MUTEX_unlock(&expired_client->cid_mutex);
+			LogFullDebug(COMPONENT_CLIENTID,
+				     "Skipping client(%p), as it's gone valid.",
+				     expired_client);
+			glist_del(&expired_client->expired_client);
+			expired_client->marked_for_delayed_cleanup = false;
+			/* Drop ref of the expired_client as it's gone valid */
+			dec_client_id_ref(expired_client);
+			atomic_dec_uint32_t(&num_of_curr_expired_clients);
+			continue;
+		}
+
+		if (isDebug(COMPONENT_CLIENTID)) {
+			display_client_id_rec(&dspbuf, expired_client);
+			LogFullDebug(COMPONENT_CLIENTID, "Expired Client is %s",
+				     str);
+		}
+
+		/* Get the client record */
+		client_rec = expired_client->cid_client_record;
+
+		/* if record is STALE, the linkage to client_record is
+		 * removed already. Acquire a ref on client record
+		 * before we drop the mutex on clientid
+		 */
+		if (client_rec != NULL)
+			inc_client_record_ref(client_rec);
+
+		PTHREAD_MUTEX_unlock(&expired_client->cid_mutex);
+
+		if (client_rec != NULL)
+			PTHREAD_MUTEX_lock(&client_rec->cr_mutex);
+
+		nfs_client_id_expire(expired_client, false, true);
+
+		if (client_rec != NULL) {
+			PTHREAD_MUTEX_unlock(&client_rec->cr_mutex);
+			dec_client_record_ref(client_rec);
+		}
+
+		if (isFullDebug(COMPONENT_CLIENTID)) {
+			display_reset_buffer(&dspbuf);
+			display_client_id_rec(&dspbuf, expired_client);
+			LogFullDebug(COMPONENT_CLIENTID,
+				     "Delayed reaper, Expired {%s}", str);
+		}
+
+		glist_del(&expired_client->expired_client);
+		expired_client->marked_for_delayed_cleanup = false;
+
+		/* Drop ref of the expired_client taken before adding to list */
+		dec_client_id_ref(expired_client);
+
+		atomic_dec_uint32_t(&num_of_curr_expired_clients);
+		count++;
+
+		/* If conflicting client has been expired off, let's break */
+		if (conflicted_client)
+			break;
+	}
+	PTHREAD_MUTEX_unlock(&expired_client_ids_list_lock);
+	return count;
+}
+
 /**
  * @brief Get a clientid from a hash table
  *
@@ -1159,16 +1455,17 @@ clientid_status_t nfs_client_id_get(hash_table_t *ht, clientid4 clientid,
 	struct gsh_buffdesc buffkey;
 	struct gsh_buffdesc buffval;
 	clientid_status_t status;
-	uint64_t epoch_low = nfs_ServerEpoch & 0xFFFFFFFF;
-	uint64_t cid_epoch = (uint64_t) (clientid >> (clientid4) 32);
+	uint64_t unique_prefix = get_unique_server_id() & 0xFFFFFFFF;
+	uint64_t cid_epoch = (uint64_t)(clientid >> (clientid4)32);
 	nfs_client_id_t *pclientid;
 
-	/* Don't even bother to look up clientid if epochs don't match */
-	if (cid_epoch != epoch_low) {
+	/* Don't bother to look up clientid if unique prefixes don't match */
+	if (cid_epoch != unique_prefix) {
 		if (isDebug(COMPONENT_HASHTABLE))
-			LogFullDebug(COMPONENT_CLIENTID,
-				     "%s NOTFOUND (epoch doesn't match, assumed STALE)",
-				     ht->parameter.ht_name);
+			LogFullDebug(
+				COMPONENT_CLIENTID,
+				"%s NOTFOUND (epoch doesn't match, assumed STALE)",
+				ht->parameter.ht_name);
 		*client_rec = NULL;
 		return CLIENT_ID_STALE;
 	}
@@ -1277,21 +1574,22 @@ int display_clientid(struct display_buffer *dspbuf, clientid4 clientid)
 {
 	int b_left = display_buffer_remain(dspbuf);
 	uint32_t counter = clientid & UINT32_MAX;
-	uint32_t epoch = clientid >> (clientid4) 32;
+	uint32_t unique = clientid >> (clientid4)32;
 
 	if (b_left <= 0)
 		return b_left;
 
-	return display_printf(dspbuf, "Epoch=0x%08"PRIx32" Counter=0x%08"PRIx32,
-			      epoch, counter);
+	return display_printf(dspbuf,
+			      "Unique=0x%08" PRIx32 " Counter=0x%08" PRIx32,
+			      unique, counter);
 }
 
 /**
  * @brief Builds a new clientid4 value
  *
- * We use the clientid counter and the server epoch, the latter
- * ensures that clientids from old instances of Ganesha are marked as
- * invalid.
+ * We use the clientid counter and the server epoch or a value supplied in the
+ * config, the latter should ensure that clientids from old instances of
+ * Ganesha are marked as invalid.
  *
  * @return The new clientid.
  */
@@ -1299,9 +1597,7 @@ int display_clientid(struct display_buffer *dspbuf, clientid4 clientid)
 clientid4 new_clientid(void)
 {
 	clientid4 newid = atomic_inc_uint32_t(&clientid_counter);
-	uint64_t epoch_low = nfs_ServerEpoch & UINT32_MAX;
-
-	return newid + (epoch_low << (clientid4) 32);
+	return newid + (clientid4)(get_unique_server_id() << 32);
 }
 
 /**
@@ -1340,14 +1636,13 @@ int display_client_record(struct display_buffer *dspbuf,
 	if (b_left <= 0)
 		return b_left;
 
-	b_left = display_opaque_value(dspbuf,
-				      record->cr_client_val,
+	b_left = display_opaque_value(dspbuf, record->cr_client_val,
 				      record->cr_client_val_len);
 
 	if (b_left <= 0)
 		return b_left;
 
-	return display_printf(dspbuf, " refcount=%" PRId32,
+	return display_printf(dspbuf, " cr_refcount=%" PRId32,
 			      atomic_fetch_int32_t(&record->cr_refcount));
 }
 
@@ -1363,10 +1658,10 @@ int32_t inc_client_record_ref(nfs_client_record_t *record)
 
 	if (isFullDebug(COMPONENT_CLIENTID)) {
 		char str[LOG_BUFF_LEN] = "\0";
-		struct display_buffer dspbuf = {sizeof(str), str, str};
+		struct display_buffer dspbuf = { sizeof(str), str, str };
 
 		display_client_record(&dspbuf, record);
-		LogFullDebug(COMPONENT_CLIENTID, "Increment refcount {%s}",
+		LogFullDebug(COMPONENT_CLIENTID, "Increment cr_refcount {%s}",
 			     str);
 	}
 
@@ -1394,7 +1689,7 @@ void free_client_record(nfs_client_record_t *record)
 int32_t dec_client_record_ref(nfs_client_record_t *record)
 {
 	char str[LOG_BUFF_LEN] = "\0";
-	struct display_buffer dspbuf = {sizeof(str), str, str};
+	struct display_buffer dspbuf = { sizeof(str), str, str };
 	struct hash_latch latch;
 	hash_error_t rc;
 	struct gsh_buffdesc buffkey;
@@ -1412,7 +1707,7 @@ int32_t dec_client_record_ref(nfs_client_record_t *record)
 
 	if (refcount > 0) {
 		LogFullDebug(COMPONENT_CLIENTID,
-			     "Decrement refcount now=%" PRId32 " {%s}",
+			     "Decrement cr_refcount now=%" PRId32 " {%s}",
 			     refcount, str);
 
 		return refcount;
@@ -1505,7 +1800,7 @@ uint32_t client_record_value_hash_func(hash_parameter_t *hparam,
 	if (isDebug(COMPONENT_HASHTABLE))
 		LogFullDebug(COMPONENT_CLIENTID, "value = %" PRIu64, res);
 
-	return (uint32_t) res;
+	return (uint32_t)res;
 }
 
 /**
@@ -1689,9 +1984,8 @@ static void client_cb(struct fridgethr_context *ctx)
  * @param state [IN] param block to pass
  */
 
-void
-nfs41_foreach_client_callback(bool(*cb) (nfs_client_id_t *cl, void *state),
-			      void *state)
+void nfs41_foreach_client_callback(bool (*cb)(nfs_client_id_t *cl, void *state),
+				   void *state)
 {
 	uint32_t i;
 	hash_table_t *ht = ht_confirmed_client_id;
@@ -1710,7 +2004,8 @@ nfs41_foreach_client_callback(bool(*cb) (nfs_client_id_t *cl, void *state),
 		PTHREAD_RWLOCK_wrlock(&(ht->partitions[i].ht_lock));
 
 		/* go through all entries in the red-black-tree */
-		RBT_LOOP(head_rbt, pn) {
+		RBT_LOOP(head_rbt, pn)
+		{
 			pdata = RBT_OPAQ(pn);
 			pclientid = pdata->val.addr;
 			RBT_INCREMENT(pn);
@@ -1724,8 +2019,7 @@ nfs41_foreach_client_callback(bool(*cb) (nfs_client_id_t *cl, void *state),
 				cb_arg->pclientid = pclientid;
 				inc_client_id_ref(pclientid);
 				rc = fridgethr_submit(state_async_fridge,
-						 client_cb,
-						 cb_arg);
+						      client_cb, cb_arg);
 				if (rc != 0) {
 					LogCrit(COMPONENT_CLIENTID,
 						"unable to start client cb thread %d",
@@ -1761,8 +2055,7 @@ static hash_parameter_t cr_hash_param = {
  */
 int nfs_Init_client_id(void)
 {
-	ht_confirmed_client_id =
-		hashtable_init(&cid_confirmed_hash_param);
+	ht_confirmed_client_id = hashtable_init(&cid_confirmed_hash_param);
 
 	if (ht_confirmed_client_id == NULL) {
 		LogCrit(COMPONENT_INIT,
@@ -1770,8 +2063,7 @@ int nfs_Init_client_id(void)
 		return -1;
 	}
 
-	ht_unconfirmed_client_id =
-		hashtable_init(&cid_unconfirmed_hash_param);
+	ht_unconfirmed_client_id = hashtable_init(&cid_unconfirmed_hash_param);
 
 	if (ht_unconfirmed_client_id == NULL) {
 		LogCrit(COMPONENT_INIT,
@@ -1788,10 +2080,55 @@ int nfs_Init_client_id(void)
 	}
 
 	client_id_pool =
-	    pool_basic_init("NFS4 Client ID Pool", sizeof(nfs_client_id_t));
+		pool_basic_init("NFS4 Client ID Pool", sizeof(nfs_client_id_t));
+
+	PTHREAD_MUTEX_init(&expired_client_ids_list_lock, NULL);
+	glist_init(&expired_client_ids_list);
 
 	return CLIENT_ID_SUCCESS;
 }
 
+/**
+ * @brief Get the total count of files open by the clients in the hashtables.
+ *
+ * Loop over all RBT nodes in HashTable buckets to get the count of open files
+ *
+ * @return Total NFSv4 Open Files Count
+ */
+uint64_t get_total_count_of_open_states(void)
+{
+	hash_table_t *ht = ht_confirmed_client_id;
+	struct rbt_head *head_rbt;
+	struct hash_data *addr = NULL;
+	uint32_t i;
+	struct rbt_node *pn;
+	nfs_client_id_t *client_id;
+	uint64_t count = 0;
+	char str[LOG_BUFF_LEN] = "\0";
+	struct display_buffer dspbuf = { sizeof(str), str, str };
+
+	/* For each bucket of the hashtable - ht_confirmed_client_id */
+	for (i = 0; i < ht->parameter.index_size; i++) {
+		/* acquire read lock */
+		PTHREAD_RWLOCK_rdlock(&(ht->partitions[i].ht_lock));
+
+		head_rbt = &(ht->partitions[i].rbt);
+
+		/* go through all entries in the red-black-tree */
+		RBT_LOOP(head_rbt, pn)
+		{
+			addr = RBT_OPAQ(pn);
+			client_id = addr->val.addr;
+			display_client_id_rec(&dspbuf, client_id);
+			LogEvent(COMPONENT_CLIENTID, "Dump Client Entry %s",
+				 str);
+			count += client_id->cid_open_state_counter;
+			display_reset_buffer(&dspbuf);
+			RBT_INCREMENT(pn);
+		}
+		PTHREAD_RWLOCK_unlock(&(ht->partitions[i].ht_lock));
+	}
+	return count;
+}
 
 /** @} */
