@@ -55,14 +55,11 @@ char *save_token(char *token, bool esc, struct parser_state *st)
 {
 	struct token_tab *tokp, *new_tok;
 
-	for (tokp = st->root_node->tokens;
-	     tokp != NULL;
-	     tokp = tokp->next) {
+	for (tokp = st->root_node->tokens; tokp != NULL; tokp = tokp->next) {
 		if (strcmp(token, tokp->token) == 0)
 			return tokp->token;
 	}
-	new_tok = gsh_calloc(1, (sizeof(struct token_tab) +
-				 strlen(token) + 1));
+	new_tok = gsh_calloc(1, (sizeof(struct token_tab) + strlen(token) + 1));
 	if (new_tok == NULL)
 		return NULL;
 	if (esc) {
@@ -93,12 +90,12 @@ char *save_token(char *token, bool esc, struct parser_state *st)
 					break;
 				}
 			} else if (c == '"' && *sp == '\0')
-				break;  /* skip trailing '"' from regexp */
+				break; /* skip trailing '"' from regexp */
 			*dp++ = c;
 			c = *sp++;
 		}
 	} else {
-		if (*token == '\'')  /* skip and chomp "'" in an SQUOTE */
+		if (*token == '\'') /* skip and chomp "'" in an SQUOTE */
 			token++;
 		strcpy(new_tok->token, token);
 		if (new_tok->token[strlen(new_tok->token) - 1] == '\'')
@@ -112,26 +109,25 @@ char *save_token(char *token, bool esc, struct parser_state *st)
 struct {
 	const char *name;
 	const char *desc;
-} config_term_type[] = {
-	[TERM_TOKEN]  = {"TOKEN", "option name or number"},
-	[TERM_REGEX]  = {"REGEX", "regular expression option}"},
-	[TERM_PATH]   = {"PATH", "file path name"},
-	[TERM_STRING] = {"STRING", "simple string"},
-	[TERM_DQUOTE] = {"DQUOTE", "double quoted string"},
-	[TERM_SQUOTE] = {"SQUOTE", "single quoted string"},
-	[TERM_TRUE]   = {"TRUE", "boolean TRUE"},
-	[TERM_FALSE]  = {"FALSE", "boolean FALSE"},
-	[TERM_DECNUM] = {"DECNUM", "decimal number"},
-	[TERM_HEXNUM] = {"HEXNUM", "hexadecimal number"},
-	[TERM_OCTNUM] = {"OCTNUM", "octal number"},
-	[TERM_V4_ANY] = {"V4_ANY", "IPv4 any address"},
-	[TERM_V4ADDR] = {"V4ADDR", "IPv4 numeric address"},
-	[TERM_V4CIDR] = {"V4CIDR", "IPv4 CIDR subnet"},
-	[TERM_V6ADDR] = {"V6ADDR", "IPv6 numeric address"},
-	[TERM_V6CIDR] = {"V6CIDR", "IPv6 CIDR subnet"},
-	[TERM_FSID]   = {"FSID", "file system ID"},
-	[TERM_NETGROUP] = {"NETGROUP", "NIS netgroup"}
-};
+} config_term_type[] = { [TERM_TOKEN] = { "TOKEN", "option name or number" },
+			 [TERM_REGEX] = { "REGEX",
+					  "regular expression option}" },
+			 [TERM_PATH] = { "PATH", "file path name" },
+			 [TERM_STRING] = { "STRING", "simple string" },
+			 [TERM_DQUOTE] = { "DQUOTE", "double quoted string" },
+			 [TERM_SQUOTE] = { "SQUOTE", "single quoted string" },
+			 [TERM_TRUE] = { "TRUE", "boolean TRUE" },
+			 [TERM_FALSE] = { "FALSE", "boolean FALSE" },
+			 [TERM_DECNUM] = { "DECNUM", "decimal number" },
+			 [TERM_HEXNUM] = { "HEXNUM", "hexadecimal number" },
+			 [TERM_OCTNUM] = { "OCTNUM", "octal number" },
+			 [TERM_V4_ANY] = { "V4_ANY", "IPv4 any address" },
+			 [TERM_V4ADDR] = { "V4ADDR", "IPv4 numeric address" },
+			 [TERM_V4CIDR] = { "V4CIDR", "IPv4 CIDR subnet" },
+			 [TERM_V6ADDR] = { "V6ADDR", "IPv6 numeric address" },
+			 [TERM_V6CIDR] = { "V6CIDR", "IPv6 CIDR subnet" },
+			 [TERM_FSID] = { "FSID", "file system ID" },
+			 [TERM_NETGROUP] = { "NETGROUP", "NIS netgroup" } };
 
 const char *config_term_name(enum term_type type)
 {
@@ -146,8 +142,7 @@ const char *config_term_desc(enum term_type type)
 /**
  *  Displays the content of a list of blocks.
  */
-static void print_node(FILE *output,
-		       struct config_node *node,
+static void print_node(FILE *output, struct config_node *node,
 		       unsigned int indent)
 {
 	struct config_node *sub_node;
@@ -156,7 +151,8 @@ static void print_node(FILE *output,
 	if (node->type == TYPE_BLOCK) {
 		fprintf(output, "%*s<BLOCK '%s' %s:%d>\n", indent, " ",
 			node->u.nterm.name, node->filename, node->linenumber);
-		glist_for_each_safe(nsi, nsn, &node->u.nterm.sub_nodes) {
+		glist_for_each_safe(nsi, nsn, &node->u.nterm.sub_nodes)
+		{
 			sub_node = glist_entry(nsi, struct config_node, node);
 			print_node(output, sub_node, indent + 3);
 		}
@@ -165,7 +161,8 @@ static void print_node(FILE *output,
 	} else if (node->type == TYPE_STMT) {
 		fprintf(output, "%*s<STMT '%s' %s:%d>\n", indent, " ",
 			node->u.nterm.name, node->filename, node->linenumber);
-		glist_for_each_safe(nsi, nsn, &node->u.nterm.sub_nodes) {
+		glist_for_each_safe(nsi, nsn, &node->u.nterm.sub_nodes)
+		{
 			sub_node = glist_entry(nsi, struct config_node, node);
 			print_node(output, sub_node, indent + 3);
 		}
@@ -174,11 +171,11 @@ static void print_node(FILE *output,
 	} else {
 		/* a statement value */
 		fprintf(output, "%*s(%s)'%s' '%s'\n", indent, " ",
-			(node->u.term.type != 0
-			 ? config_term_type[node->u.term.type].name
-			 : "unknown"),
-			(node->u.term.op_code != NULL
-			 ? node->u.term.op_code : " "),
+			(node->u.term.type != 0 ?
+				 config_term_type[node->u.term.type].name :
+				 "unknown"),
+			(node->u.term.op_code != NULL ? node->u.term.op_code :
+							" "),
 			node->u.term.varvalue);
 	}
 }
@@ -205,7 +202,8 @@ void print_parse_tree(FILE *output, struct config_root *tree)
 	fprintf(output, "   </TOKEN_TABLE>\n");
 	fprintf(output, "</SUMMARY>\n");
 	fprintf(output, "<PARSE_TREE>\n");
-	glist_for_each_safe(nsi, nsn, &tree->root.u.nterm.sub_nodes) {
+	glist_for_each_safe(nsi, nsn, &tree->root.u.nterm.sub_nodes)
+	{
 		node = glist_entry(nsi, struct config_node, node);
 		print_node(output, node, 3);
 	}
@@ -227,7 +225,8 @@ static void free_node(struct config_node *node)
 		struct config_node *sub_node;
 		struct glist_head *nsi, *nsn;
 
-		glist_for_each_safe(nsi, nsn, &node->u.nterm.sub_nodes) {
+		glist_for_each_safe(nsi, nsn, &node->u.nterm.sub_nodes)
+		{
 			sub_node = glist_entry(nsi, struct config_node, node);
 			glist_del(&sub_node->node);
 			free_node(sub_node);
@@ -244,13 +243,14 @@ void free_parse_tree(struct config_root *tree)
 	struct config_node *node;
 	struct glist_head *nsi, *nsn;
 
-	glist_for_each_safe(nsi, nsn, &tree->root.u.nterm.sub_nodes) {
+	glist_for_each_safe(nsi, nsn, &tree->root.u.nterm.sub_nodes)
+	{
 		node = glist_entry(nsi, struct config_node, node);
 		glist_del(&node->node);
 		free_node(node);
 	}
 	gsh_free(tree->root.filename);
-	if(tree->conf_dir != NULL)
+	if (tree->conf_dir != NULL)
 		gsh_free(tree->conf_dir);
 	file = tree->files;
 	while (file != NULL) {
@@ -269,8 +269,8 @@ void free_parse_tree(struct config_root *tree)
 	return;
 }
 
-void config_error(FILE *fp, const char *filename, int linenum,
-			 char *fmt, va_list args)
+void config_error(FILE *fp, const char *filename, int linenum, char *fmt,
+		  va_list args)
 {
 	char str[LOG_BUFF_LEN];
 
@@ -281,8 +281,6 @@ void config_error(FILE *fp, const char *filename, int linenum,
 	if (likely(component_log_level[COMPONENT_CONFIG] < NIV_FULL_DEBUG))
 		return;
 
-	DisplayLogComponentLevel(COMPONENT_CONFIG,
-				 filename, linenum, (char *)__func__,
-				 NIV_FULL_DEBUG, "%s", str);
+	DisplayLogComponentLevel(COMPONENT_CONFIG, filename, linenum,
+				 (char *)__func__, NIV_FULL_DEBUG, "%s", str);
 }
-
