@@ -50,39 +50,44 @@
 #include "nfs_core.h"
 #include "abstract_atomic.h"
 #include "server_stats_private.h"
+#include "idmapper_monitoring.h"
 
 /**
  * @brief User entry in the IDMapper cache
  */
 
 struct cache_user {
-	struct gsh_buffdesc uname;	/*< Username */
-	uid_t uid;		/*< Corresponding UID */
-	gid_t gid;		/*< Corresponding GID */
-	bool gid_set;		/*< if the GID has been set */
-	struct avltree_node uname_node;	/*< Node in the name tree */
-	struct avltree_node uid_node;	/*< Node in the UID tree */
-	bool in_uidtree;		/* true iff this is in uid_tree */
+	struct gsh_buffdesc uname; /*< Username */
+	uid_t uid; /*< Corresponding UID */
+	gid_t gid; /*< Corresponding GID */
+	bool gid_set; /*< if the GID has been set */
+	struct avltree_node uname_node; /*< Node in the name tree */
+	struct avltree_node uid_node; /*< Node in the UID tree */
+	bool in_uidtree; /* true iff this is in uid_tree */
 	time_t epoch;
+	TAILQ_ENTRY(cache_user) queue_entry; /* Node in user-fifo-queue */
 };
 
-#define user_expired(user) (time(NULL) - (user)->epoch > \
-		nfs_param.core_param.manage_gids_expiration)
+#define user_expired(user)            \
+	(time(NULL) - (user)->epoch > \
+	 nfs_param.directory_services_param.idmapped_user_time_validity)
 
 /**
  * @brief Group entry in the IDMapper cache
  */
 
 struct cache_group {
-	struct gsh_buffdesc gname;	/*< Group name */
-	gid_t gid;		/*< Group ID */
-	struct avltree_node gname_node;	/*< Node in the name tree */
-	struct avltree_node gid_node;	/*< Node in the GID tree */
+	struct gsh_buffdesc gname; /*< Group name */
+	gid_t gid; /*< Group ID */
+	struct avltree_node gname_node; /*< Node in the name tree */
+	struct avltree_node gid_node; /*< Node in the GID tree */
+	TAILQ_ENTRY(cache_group) queue_entry; /* Node in group-fifo-queue */
 	time_t epoch;
 };
 
-#define group_expired(group) (time(NULL) - (group)->epoch > \
-		nfs_param.core_param.manage_gids_expiration)
+#define group_expired(group)           \
+	(time(NULL) - (group)->epoch > \
+	 nfs_param.directory_services_param.idmapped_group_time_validity)
 
 /**
  * @brief Number of entries in the UID cache, should be prime.
@@ -90,6 +95,24 @@ struct cache_group {
 
 #define id_cache_size 1009
 
+/**
+ * @brief A user fifo queue ordered by insertion timestamp
+ *
+ * This fifo queue also mimics the order of expiration time of the cache
+ * entries, since the expiration time is a linear function of the insertion
+ * time.
+ *
+ *   Expiration_time = Insertion_time + Cache_time_validity (constant)
+ *
+ * The head of the queue contains the entry with least time-validity.
+ * The tail of the queue contains the entry with most time-validity.
+ * The eviction happens from the head, and insertion happens at the tail.
+ */
+static TAILQ_HEAD(, cache_user) user_fifo_queue;
+
+/* Similar to above, this is the fifo queue containing group entries */
+static TAILQ_HEAD(, cache_group) group_fifo_queue;
+
 /**
  * @brief UID cache, may only be accessed with idmapper_user_lock
  * held.  If idmapper_user_lock is held for read, it must be accessed
@@ -143,37 +166,6 @@ static struct avltree gname_tree;
 
 static struct avltree gid_tree;
 
-/**
- * @brief Compare two buffers
- *
- * Handle the case where one buffer is a left sub-buffer of another
- * buffer by counting the longer one as larger.
- *
- * @param[in] buff1 A buffer
- * @param[in] buffa Another buffer
- *
- * @retval -1 if buff1 is less than buffa
- * @retval 0 if buff1 and buffa are equal
- * @retval 1 if buff1 is greater than buffa
- */
-
-static inline int buffdesc_comparator(const struct gsh_buffdesc *buffa,
-				      const struct gsh_buffdesc *buff1)
-{
-	int mr = memcmp(buff1->addr, buffa->addr, MIN(buff1->len,
-						      buffa->len));
-	if (unlikely(mr == 0)) {
-		if (buff1->len < buffa->len)
-			return -1;
-		else if (buff1->len > buffa->len)
-			return 1;
-		else
-			return 0;
-	} else {
-		return mr;
-	}
-}
-
 /**
  * @brief Comparison for user names
  *
@@ -189,13 +181,11 @@ static int uname_comparator(const struct avltree_node *node1,
 			    const struct avltree_node *nodea)
 {
 	struct cache_user *user1 =
-	    avltree_container_of(node1, struct cache_user,
-				 uname_node);
+		avltree_container_of(node1, struct cache_user, uname_node);
 	struct cache_user *usera =
-	    avltree_container_of(nodea, struct cache_user,
-				 uname_node);
+		avltree_container_of(nodea, struct cache_user, uname_node);
 
-	return buffdesc_comparator(&user1->uname, &usera->uname);
+	return gsh_buffdesc_comparator(&user1->uname, &usera->uname);
 }
 
 /**
@@ -213,11 +203,9 @@ static int uid_comparator(const struct avltree_node *node1,
 			  const struct avltree_node *nodea)
 {
 	struct cache_user *user1 =
-	    avltree_container_of(node1, struct cache_user,
-				 uid_node);
+		avltree_container_of(node1, struct cache_user, uid_node);
 	struct cache_user *usera =
-	    avltree_container_of(nodea, struct cache_user,
-				 uid_node);
+		avltree_container_of(nodea, struct cache_user, uid_node);
 
 	if (user1->uid < usera->uid)
 		return -1;
@@ -242,13 +230,11 @@ static inline int gname_comparator(const struct avltree_node *node1,
 				   const struct avltree_node *nodea)
 {
 	struct cache_group *group1 =
-	    avltree_container_of(node1, struct cache_group,
-				 gname_node);
+		avltree_container_of(node1, struct cache_group, gname_node);
 	struct cache_group *groupa =
-	    avltree_container_of(nodea, struct cache_group,
-				 gname_node);
+		avltree_container_of(nodea, struct cache_group, gname_node);
 
-	return buffdesc_comparator(&group1->gname, &groupa->gname);
+	return gsh_buffdesc_comparator(&group1->gname, &groupa->gname);
 }
 
 /**
@@ -266,11 +252,9 @@ static int gid_comparator(const struct avltree_node *node1,
 			  const struct avltree_node *nodea)
 {
 	struct cache_group *group1 =
-	    avltree_container_of(node1, struct cache_group,
-				 gid_node);
+		avltree_container_of(node1, struct cache_group, gid_node);
 	struct cache_group *groupa =
-	    avltree_container_of(nodea, struct cache_group,
-				 gid_node);
+		avltree_container_of(nodea, struct cache_group, gid_node);
 
 	if (group1->gid < groupa->gid)
 		return -1;
@@ -280,6 +264,99 @@ static int gid_comparator(const struct avltree_node *node1,
 		return 0;
 }
 
+/**
+ * @brief Remove user entry from all user cache data structures
+ *
+ * @note The caller must hold idmapper_user_lock for write.
+ */
+static void remove_cache_user(struct cache_user *user)
+{
+	avltree_remove(&user->uname_node, &uname_tree);
+	if (user->in_uidtree) {
+		uid_cache[user->uid % id_cache_size] = NULL;
+		avltree_remove(&user->uid_node, &uid_tree);
+	}
+	/* Remove from users fifo queue */
+	TAILQ_REMOVE(&user_fifo_queue, user, queue_entry);
+	gsh_free(user);
+}
+
+/**
+ * @brief Remove group entry from all group cache data structures
+ *
+ * @note The caller must hold idmapper_group_lock for write.
+ */
+static void remove_cache_group(struct cache_group *group)
+{
+	gid_cache[group->gid % id_cache_size] = NULL;
+	avltree_remove(&group->gid_node, &gid_tree);
+	avltree_remove(&group->gname_node, &gname_tree);
+	/* Remove from groups fifo queue */
+	TAILQ_REMOVE(&group_fifo_queue, group, queue_entry);
+	gsh_free(group);
+}
+
+/**
+ * @brief Reaps the cache user entries
+ *
+ * Since the user-fifo queue stores entries in increasing order of time
+ * validity, the reaper reaps from the queue head in the same order. It
+ * stops when it first encounters a non-expired entry.
+ */
+static void reap_users_cache(void)
+{
+	struct cache_user *user;
+
+	LogFullDebug(COMPONENT_IDMAPPER,
+		     "Idmapper user-cache reaper run started");
+	PTHREAD_RWLOCK_wrlock(&idmapper_user_lock);
+
+	for (user = TAILQ_FIRST(&user_fifo_queue); user != NULL;) {
+		if (!user_expired(user))
+			break;
+		remove_cache_user(user);
+		user = TAILQ_FIRST(&user_fifo_queue);
+	}
+	PTHREAD_RWLOCK_unlock(&idmapper_user_lock);
+	LogFullDebug(COMPONENT_IDMAPPER,
+		     "Idmapper user-cache reaper run ended");
+}
+
+/**
+ * @brief Reaps the cache group entries
+ *
+ * Since the group-fifo queue stores entries in increasing order of time
+ * validity, the reaper reaps from the queue head in the same order. It
+ * stops when it first encounters a non-expired entry.
+ */
+static void reap_groups_cache(void)
+{
+	struct cache_group *group;
+
+	LogFullDebug(COMPONENT_IDMAPPER,
+		     "Idmapper group-cache reap run started");
+	PTHREAD_RWLOCK_wrlock(&idmapper_group_lock);
+
+	for (group = TAILQ_FIRST(&group_fifo_queue); group != NULL;) {
+		if (!group_expired(group))
+			break;
+		remove_cache_group(group);
+		group = TAILQ_FIRST(&group_fifo_queue);
+	}
+	PTHREAD_RWLOCK_unlock(&idmapper_group_lock);
+	LogFullDebug(COMPONENT_IDMAPPER,
+		     "Idmapper group-cache reaper run ended");
+}
+
+/**
+ * @brief Reaps the cache user, group entries
+ */
+void idmapper_cache_reap(void)
+{
+	reap_users_cache();
+	reap_groups_cache();
+}
+
 /**
  * @brief Initialize the IDMapper cache
  */
@@ -296,6 +373,9 @@ void idmapper_cache_init(void)
 	avltree_init(&gname_tree, gname_comparator, 0);
 	avltree_init(&gid_tree, gid_comparator, 0);
 	memset(gid_cache, 0, id_cache_size * sizeof(struct avltree_node *));
+
+	TAILQ_INIT(&user_fifo_queue);
+	TAILQ_INIT(&group_fifo_queue);
 }
 
 /**
@@ -320,6 +400,7 @@ bool idmapper_add_user(const struct gsh_buffdesc *name, uid_t uid,
 	struct avltree_node *found_id;
 	struct cache_user *old;
 	struct cache_user *new;
+	struct cache_user *user_fifo_queue_head_node;
 
 	new = gsh_malloc(sizeof(struct cache_user) + name->len);
 	new->epoch = time(NULL);
@@ -368,8 +449,8 @@ bool idmapper_add_user(const struct gsh_buffdesc *name, uid_t uid,
 	if (unlikely(found_name)) {
 		old = avltree_container_of(found_name, struct cache_user,
 					   uname_node);
-		/* Combine old into new if uid's match */
-		if (old->uid == new->uid) {
+		/* Combine non-expired old into new if uid's match */
+		if ((old->uid == new->uid) && !user_expired(old)) {
 			if (!new->gid_set && old->gid_set) {
 				new->gid = old->gid;
 				new->gid_set = true;
@@ -379,32 +460,41 @@ bool idmapper_add_user(const struct gsh_buffdesc *name, uid_t uid,
 		}
 
 		/* Remove the old and insert the new */
-		avltree_remove(found_name, &uname_tree);
-		if (old->in_uidtree) {
-			uid_cache[old->uid % id_cache_size] = NULL;
-			avltree_remove(&old->uid_node, &uid_tree);
-		}
-		gsh_free(old);
+		remove_cache_user(old);
 		found_name = avltree_insert(&new->uname_node, &uname_tree);
 		assert(found_name == NULL);
 	}
 
 	if (!new->in_uidtree) /* all done */
-		return true;
+		goto add_to_queue;
 
 	found_id = avltree_insert(&new->uid_node, &uid_tree);
 	if (unlikely(found_id)) {
 		old = avltree_container_of(found_id, struct cache_user,
 					   uid_node);
-		uid_cache[old->uid % id_cache_size] = NULL;
-		avltree_remove(found_id, &uid_tree);
-		avltree_remove(&old->uname_node, &uname_tree);
-		gsh_free(old);
+		remove_cache_user(old);
 		found_id = avltree_insert(&new->uid_node, &uid_tree);
 		assert(found_id == NULL);
 	}
 	uid_cache[uid % id_cache_size] = &new->uid_node;
 
+add_to_queue:
+
+	TAILQ_INSERT_TAIL(&user_fifo_queue, new, queue_entry);
+
+	/* If we breach max-cache capacity, remove the user queue's head node */
+	if (avltree_size(&uname_tree) >
+	    nfs_param.directory_services_param.cache_users_max_count) {
+		LogDebug(
+			COMPONENT_IDMAPPER,
+			"Cache size limit violated, removing user with least time validity");
+		user_fifo_queue_head_node = TAILQ_FIRST(&user_fifo_queue);
+		const time_t cached_duration =
+			time(NULL) - user_fifo_queue_head_node->epoch;
+		remove_cache_user(user_fifo_queue_head_node);
+		idmapper_monitoring__evicted_cache_entity(
+			IDMAPPING_CACHE_ENTITY_USER, cached_duration);
+	}
 	return true;
 }
 
@@ -426,6 +516,7 @@ bool idmapper_add_group(const struct gsh_buffdesc *name, const gid_t gid)
 	struct avltree_node *found_id;
 	struct cache_group *tmp;
 	struct cache_group *new;
+	struct cache_group *group_fifo_queue_head_node;
 
 	new = gsh_malloc(sizeof(struct cache_group) + name->len);
 	new->epoch = time(NULL);
@@ -452,10 +543,7 @@ bool idmapper_add_group(const struct gsh_buffdesc *name, const gid_t gid)
 	if (unlikely(found_name)) {
 		tmp = avltree_container_of(found_name, struct cache_group,
 					   gname_node);
-		avltree_remove(found_name, &gname_tree);
-		avltree_remove(&tmp->gid_node, &gid_tree);
-		gid_cache[tmp->gid % id_cache_size] = NULL;
-		gsh_free(tmp);
+		remove_cache_group(tmp);
 		found_name = avltree_insert(&new->gname_node, &gname_tree);
 		assert(found_name == NULL);
 	}
@@ -464,16 +552,27 @@ bool idmapper_add_group(const struct gsh_buffdesc *name, const gid_t gid)
 	if (unlikely(found_id)) {
 		tmp = avltree_container_of(found_id, struct cache_group,
 					   gid_node);
-
-		gid_cache[tmp->gid % id_cache_size] = NULL;
-		avltree_remove(found_id, &gid_tree);
-		avltree_remove(&tmp->gname_node, &gname_tree);
-		gsh_free(tmp);
+		remove_cache_group(tmp);
 		found_id = avltree_insert(&new->gid_node, &gid_tree);
 		assert(found_id == NULL);
 	}
 	gid_cache[gid % id_cache_size] = &new->gid_node;
 
+	TAILQ_INSERT_TAIL(&group_fifo_queue, new, queue_entry);
+
+	/* If we breach max-cache capacity, remove the user queue's head node */
+	if (avltree_size(&gname_tree) >
+	    nfs_param.directory_services_param.cache_groups_max_count) {
+		LogDebug(
+			COMPONENT_IDMAPPER,
+			"Cache size limit violated, removing group with least time validity");
+		group_fifo_queue_head_node = TAILQ_FIRST(&group_fifo_queue);
+		const time_t cached_duration =
+			time(NULL) - group_fifo_queue_head_node->epoch;
+		remove_cache_group(group_fifo_queue_head_node);
+		idmapper_monitoring__evicted_cache_entity(
+			IDMAPPING_CACHE_ENTITY_GROUP, cached_duration);
+	}
 	return true;
 }
 
@@ -497,11 +596,9 @@ bool idmapper_add_group(const struct gsh_buffdesc *name, const gid_t gid)
 bool idmapper_lookup_by_uname(const struct gsh_buffdesc *name, uid_t *uid,
 			      const gid_t **gid, bool gss_princ)
 {
-	struct cache_user prototype = {
-		.uname = *name
-	};
-	struct avltree_node *found_node = avltree_lookup(&prototype.uname_node,
-							 &uname_tree);
+	struct cache_user prototype = { .uname = *name };
+	struct avltree_node *found_node =
+		avltree_lookup(&prototype.uname_node, &uname_tree);
 	struct cache_user *found_user;
 	void **cache_slot;
 
@@ -509,7 +606,7 @@ bool idmapper_lookup_by_uname(const struct gsh_buffdesc *name, uid_t *uid,
 		return false;
 
 	found_user =
-	    avltree_container_of(found_node, struct cache_user, uname_node);
+		avltree_container_of(found_node, struct cache_user, uname_node);
 	if (!gss_princ) {
 		/* I assume that if someone likes this user enough to look it
 		   up by name, they'll like it enough to look it up by ID
@@ -518,8 +615,8 @@ bool idmapper_lookup_by_uname(const struct gsh_buffdesc *name, uid_t *uid,
 		   If the name is gss principal it does not have entry
 		   in uid tree */
 
-		cache_slot = (void **)
-			&uid_cache[found_user->uid % id_cache_size];
+		cache_slot =
+			(void **)&uid_cache[found_user->uid % id_cache_size];
 		atomic_store_voidptr(cache_slot, &found_user->uid_node);
 	}
 
@@ -551,17 +648,14 @@ bool idmapper_lookup_by_uname(const struct gsh_buffdesc *name, uid_t *uid,
 bool idmapper_lookup_by_uid(const uid_t uid, const struct gsh_buffdesc **name,
 			    const gid_t **gid)
 {
-	struct cache_user prototype = {
-		.uid = uid
-	};
+	struct cache_user prototype = { .uid = uid };
 	void **cache_slot = (void **)&uid_cache[uid % id_cache_size];
 	struct avltree_node *found_node = atomic_fetch_voidptr(cache_slot);
 	struct cache_user *found_user;
 	bool found = false;
 
 	if (likely(found_node)) {
-		found_user = avltree_container_of(found_node,
-						  struct cache_user,
+		found_user = avltree_container_of(found_node, struct cache_user,
 						  uid_node);
 		if (found_user->uid == uid)
 			found = true;
@@ -573,8 +667,7 @@ bool idmapper_lookup_by_uid(const uid_t uid, const struct gsh_buffdesc **name,
 			return false;
 
 		atomic_store_voidptr(cache_slot, found_node);
-		found_user = avltree_container_of(found_node,
-						  struct cache_user,
+		found_user = avltree_container_of(found_node, struct cache_user,
 						  uid_node);
 	}
 
@@ -604,19 +697,17 @@ bool idmapper_lookup_by_uid(const uid_t uid, const struct gsh_buffdesc **name,
 
 bool idmapper_lookup_by_gname(const struct gsh_buffdesc *name, uid_t *gid)
 {
-	struct cache_group prototype = {
-		.gname = *name
-	};
-	struct avltree_node *found_node = avltree_lookup(&prototype.gname_node,
-							 &gname_tree);
+	struct cache_group prototype = { .gname = *name };
+	struct avltree_node *found_node =
+		avltree_lookup(&prototype.gname_node, &gname_tree);
 	struct cache_group *found_group;
 	void **cache_slot;
 
 	if (unlikely(!found_node))
 		return false;
 
-	found_group =
-	    avltree_container_of(found_node, struct cache_group, gname_node);
+	found_group = avltree_container_of(found_node, struct cache_group,
+					   gname_node);
 
 	/* I assume that if someone likes this group enough to look it
 	   up by name, they'll like it enough to look it up by ID
@@ -648,18 +739,15 @@ bool idmapper_lookup_by_gname(const struct gsh_buffdesc *name, uid_t *gid)
 
 bool idmapper_lookup_by_gid(const gid_t gid, const struct gsh_buffdesc **name)
 {
-	struct cache_group prototype = {
-		.gid = gid
-	};
+	struct cache_group prototype = { .gid = gid };
 	void **cache_slot = (void **)&gid_cache[gid % id_cache_size];
 	struct avltree_node *found_node = atomic_fetch_voidptr(cache_slot);
 	struct cache_group *found_group;
 	bool found = false;
 
 	if (likely(found_node)) {
-		found_group = avltree_container_of(found_node,
-						   struct cache_group,
-						   gid_node);
+		found_group = avltree_container_of(
+			found_node, struct cache_group, gid_node);
 		if (found_group->gid == gid)
 			found = true;
 	}
@@ -670,9 +758,8 @@ bool idmapper_lookup_by_gid(const gid_t gid, const struct gsh_buffdesc **name)
 			return false;
 
 		atomic_store_voidptr(cache_slot, found_node);
-		found_group = avltree_container_of(found_node,
-						   struct cache_group,
-						   gid_node);
+		found_group = avltree_container_of(
+			found_node, struct cache_group, gid_node);
 	}
 
 	if (likely(name))
@@ -697,52 +784,53 @@ void idmapper_clear_cache(void)
 	memset(uid_cache, 0, id_cache_size * sizeof(struct avltree_node *));
 	memset(gid_cache, 0, id_cache_size * sizeof(struct avltree_node *));
 
-	for (node = avltree_first(&uname_tree);
-	     node != NULL;
+	for (node = avltree_first(&uname_tree); node != NULL;
 	     node = avltree_first(&uname_tree)) {
 		struct cache_user *user;
 
-		user = avltree_container_of(node,
-					    struct cache_user, uname_node);
-		avltree_remove(&user->uname_node, &uname_tree);
-		if (user->in_uidtree)
-			avltree_remove(&user->uid_node, &uid_tree);
-		gsh_free(user);
+		user = avltree_container_of(node, struct cache_user,
+					    uname_node);
+		remove_cache_user(user);
 	}
 
 	assert(avltree_first(&uid_tree) == NULL);
 
-	for (node = avltree_first(&gname_tree);
-	     node != NULL;
+	for (node = avltree_first(&gname_tree); node != NULL;
 	     node = avltree_first(&gname_tree)) {
 		struct cache_group *group;
 
-		group = avltree_container_of(node,
-					     struct cache_group, gname_node);
-		avltree_remove(&group->gname_node, &gname_tree);
-		avltree_remove(&group->gid_node, &gid_tree);
-		gsh_free(group);
+		group = avltree_container_of(node, struct cache_group,
+					     gname_node);
+		remove_cache_group(group);
 	}
 
 	assert(avltree_first(&gid_tree) == NULL);
 
 	PTHREAD_RWLOCK_unlock(&idmapper_group_lock);
 	PTHREAD_RWLOCK_unlock(&idmapper_user_lock);
+}
 
+/**
+ * @brief Destroy the IDMapper cache
+ *
+ * This function clears the cache, and destroys its locks.
+ */
+void idmapper_destroy_cache(void)
+{
+	idmapper_clear_cache();
 	PTHREAD_RWLOCK_destroy(&idmapper_user_lock);
 	PTHREAD_RWLOCK_destroy(&idmapper_group_lock);
 }
 
 #ifdef USE_DBUS
 
- /**
+/**
  *@brief Dbus method for showing idmapper cache
  *
  *@param[in]  args
  *@param[out] reply
  */
-static bool show_idmapper(DBusMessageIter *args,
-			  DBusMessage *reply,
+static bool show_idmapper(DBusMessageIter *args, DBusMessage *reply,
 			  DBusError *error)
 {
 	struct timespec timestamp;
@@ -755,21 +843,19 @@ static bool show_idmapper(DBusMessageIter *args,
 	dbus_message_iter_init_append(reply, &iter);
 	now(&timestamp);
 	gsh_dbus_append_timestamp(&iter, &timestamp);
-	dbus_message_iter_open_container(&iter, DBUS_TYPE_ARRAY,
-					"(subu)",
-					&sub_iter);
+	dbus_message_iter_open_container(&iter, DBUS_TYPE_ARRAY, "(subu)",
+					 &sub_iter);
 
 	PTHREAD_RWLOCK_rdlock(&idmapper_user_lock);
 	/* Traverse idmapper cache */
-	for (node = avltree_first(&uname_tree);
-		node != NULL;
-		node = avltree_next(node)) {
+	for (node = avltree_first(&uname_tree); node != NULL;
+	     node = avltree_next(node)) {
 		struct cache_user *user;
 
-		user = avltree_container_of(node,
-				struct cache_user, uname_node);
-		dbus_message_iter_open_container(&sub_iter,
-				DBUS_TYPE_STRUCT, NULL, &id_iter);
+		user = avltree_container_of(node, struct cache_user,
+					    uname_node);
+		dbus_message_iter_open_container(&sub_iter, DBUS_TYPE_STRUCT,
+						 NULL, &id_iter);
 		memcpy(namebuff, user->uname.addr, user->uname.len);
 		if (user->uname.len > 255)
 			/*Truncate the name */
@@ -777,11 +863,11 @@ static bool show_idmapper(DBusMessageIter *args,
 		else
 			*(namebuff + user->uname.len) = '\0';
 
-		dbus_message_iter_append_basic(&id_iter,
-				DBUS_TYPE_STRING, &namebuff);
+		dbus_message_iter_append_basic(&id_iter, DBUS_TYPE_STRING,
+					       &namebuff);
 		val = user->uid;
 		dbus_message_iter_append_basic(&id_iter, DBUS_TYPE_UINT32,
-				&val);
+					       &val);
 
 		if (user->gid_set) {
 			val = user->gid;
@@ -791,11 +877,10 @@ static bool show_idmapper(DBusMessageIter *args,
 			gid_set = false;
 		}
 		dbus_message_iter_append_basic(&id_iter, DBUS_TYPE_BOOLEAN,
-				&gid_set);
+					       &gid_set);
 		dbus_message_iter_append_basic(&id_iter, DBUS_TYPE_UINT32,
-				&val);
-		dbus_message_iter_close_container(&sub_iter,
-				&id_iter);
+					       &val);
+		dbus_message_iter_close_container(&sub_iter, &id_iter);
 	}
 	PTHREAD_RWLOCK_unlock(&idmapper_user_lock);
 	free(namebuff);
@@ -803,16 +888,12 @@ static bool show_idmapper(DBusMessageIter *args,
 	return true;
 }
 
-
 struct gsh_dbus_method cachemgr_show_idmapper = {
 	.name = "showidmapper",
 	.method = show_idmapper,
-	.args = {TIMESTAMP_REPLY,
-		{
-		  .name = "ids",
-		  .type = "a(subu)",
-		  .direction = "out"},
-		END_ARG_LIST}
+	.args = { TIMESTAMP_REPLY,
+		  { .name = "ids", .type = "a(subu)", .direction = "out" },
+		  END_ARG_LIST }
 };
 #endif
 
