@@ -56,26 +56,26 @@
  */
 
 typedef enum protos {
-	P_NFS,			/*< NFS, of course. */
+	P_NFS, /*< NFS, of course. */
 #ifdef _USE_NFS3
-	P_MNT,			/*< Mount (for v3) */
+	P_MNT, /*< Mount (for v3) */
 #endif
 #ifdef _USE_NLM
-	P_NLM,			/*< NLM (for v3) */
+	P_NLM, /*< NLM (for v3) */
 #endif
 #ifdef _USE_RQUOTA
-	P_RQUOTA,		/*< RQUOTA (for v3) */
+	P_RQUOTA, /*< RQUOTA (for v3) */
 #endif
 #ifdef USE_NFSACL3
-	P_NFSACL,		/*< NFSACL (for v3) */
+	P_NFSACL, /*< NFSACL (for v3) */
 #endif
 #ifdef RPC_VSOCK
-	P_NFS_VSOCK,		/*< NFS over vmware, qemu vmci sockets */
+	P_NFS_VSOCK, /*< NFS over vmware, qemu vmci sockets */
 #endif
 #ifdef _USE_NFS_RDMA
-	P_NFS_RDMA,		/*< NFS over RPC/RDMA */
+	P_NFS_RDMA, /*< NFS over RPC/RDMA */
 #endif
-	P_COUNT			/*< Number of protocols */
+	P_COUNT /*< Number of protocols */
 } protos;
 
 /**
@@ -94,6 +94,11 @@ typedef enum protos {
  */
 #define RQUOTA_PORT 875
 
+/**
+ * @brief Default NFS Over RDMA Port.
+ */
+#define NFS_RDMA_PORT 20049
+
 /**
  * @brief Default value for _9p_param.nb_worker
  */
@@ -117,12 +122,12 @@ typedef enum protos {
 /**
  * @brief Default value for core_param.drc.tcp.cachesz
  */
-#define DRC_TCP_CACHESZ 127	/* make prime */
+#define DRC_TCP_CACHESZ 127 /* make prime */
 
 /**
  * @brief Default value for core_param.drc.tcp.hiwat
  */
-#define DRC_TCP_HIWAT 64	/* 1/2(size) */
+#define DRC_TCP_HIWAT 64 /* 1/2(size) */
 
 /**
  * @brief Default value for core_param.drc.tcp.recycle_npart
@@ -132,7 +137,7 @@ typedef enum protos {
 /**
  * @brief Default value for core_param.drc.tcp.expire_s
  */
-#define DRC_TCP_RECYCLE_EXPIRE_S 600	/* 10m */
+#define DRC_TCP_RECYCLE_EXPIRE_S 600 /* 10m */
 
 /**
  * @brief Default value for core_param.drc.tcp.checksum
@@ -152,12 +157,12 @@ typedef enum protos {
 /**
  * @brief Default value for core_param.drc.udp.cachesz
  */
-#define DRC_UDP_CACHESZ 599	/* make prime */
+#define DRC_UDP_CACHESZ 599 /* make prime */
 
 /**
  * @brief Default value for core_param.drc.udp.hiwat
  */
-#define DRC_UDP_HIWAT 16384	/* 1/2(size) */
+#define DRC_UDP_HIWAT 16384 /* 1/2(size) */
 
 /**
  * @brief Default value for core_param.drc.udp.checksum
@@ -183,23 +188,23 @@ typedef enum protos {
  * @brief Turn off all protocols
  */
 
-#define CORE_OPTION_NONE 0x00000000	/*< No operations are supported */
+#define CORE_OPTION_NONE 0x00000000 /*< No operations are supported */
 
 /**
  * @brief Support NFSv3
  */
 
-#define CORE_OPTION_NFSV3 0x00000001	/*< NFSv3 operations are supported */
+#define CORE_OPTION_NFSV3 0x00000001 /*< NFSv3 operations are supported */
 
 /**
  * @brief Support NFSv4
  */
-#define CORE_OPTION_NFSV4 0x00000002	/*< NFSv4 operations are supported */
+#define CORE_OPTION_NFSV4 0x00000002 /*< NFSv4 operations are supported */
 
 /**
  * @brief Support 9p
  */
-#define CORE_OPTION_9P 0x00000004	/*< 9P operations are supported */
+#define CORE_OPTION_9P 0x00000004 /*< 9P operations are supported */
 
 /**
  * @brief NFS AF_VSOCK
@@ -220,11 +225,24 @@ typedef enum protos {
 #define CORE_OPTION_ALL_NFS_VERS CORE_OPTION_NFSV4
 #endif
 
-#define UDP_LISTENER_NONE	0
-#define UDP_LISTENER_ALL	0x00000001
-#define UDP_LISTENER_MOUNT	0x00000002
+#define UDP_LISTENER_NONE 0
+#define UDP_LISTENER_ALL 0x00000001
+#define UDP_LISTENER_MOUNT 0x00000002
 #define UDP_LISTENER_MASK (UDP_LISTENER_ALL | UDP_LISTENER_MOUNT)
 
+#ifdef _USE_NFS_RDMA
+#define NFS_RDMA_ENABLE_FOR_NONE 0
+#define NFS_RDMA_ENABLE_FOR_NFSV3 0x00000001
+/* Validations for V4.x happens based on below values being 2 << x */
+#define NFS_RDMA_ENABLE_FOR_NFSV40 0x00000002
+#define NFS_RDMA_ENABLE_FOR_NFSV41 0x00000004
+#define NFS_RDMA_ENABLE_FOR_NFSV42 0x00000008
+
+#define NFS_RDMA_ENABLE_FOR_ALL \
+	(NFS_RDMA_ENABLE_FOR_NFSV3 | NFS_RDMA_ENABLE_FOR_NFSV40)
+#define NFS_RDMA_ENABLE_BY_DEFAULT NFS_RDMA_ENABLE_FOR_NFSV40
+#endif
+
 typedef struct nfs_core_param {
 	/** The list of hosts allowed to use the HAProxy protocol. These are
 	 *  the hosts running HAProxy, acting as load balancing/proxy. Actual
@@ -356,6 +374,13 @@ typedef struct nfs_core_param {
 		/** TIRPC ioq max simultaneous io threads.  Defaults to
 		    200 and settable by RPC_Ioq_ThrdMax. */
 		uint32_t ioq_thrd_max;
+#ifdef _USE_NFS_RDMA
+		/** RDMA credits */
+		uint32_t rdma_credits;
+		/** Maximum number of RDMA connections for TIRPC.
+		    Defaults to 64 and settable by RPC_Max_RDMA_Connections. */
+		uint32_t max_rdma_connections;
+#endif
 		struct {
 			/** Partitions in GSS ctx cache table (default 13). */
 			uint32_t ctx_hash_partitions;
@@ -487,10 +512,35 @@ typedef struct nfs_core_param {
 #ifdef USE_MONITORING
 	/** Monitoring port number. */
 	uint16_t monitoring_port;
+	/** Enable creating metrics labels on the fly based on client-ip,
+	 * export name, etc.
+	 * Provides more debugging information, but significantly reduces
+	 * performance.
+	*/
+	bool enable_dynamic_metrics;
 #endif
 	/** if  Manage_Gids=True and group resolution fails,
 	 *  then use gid data from rpc request */
 	bool enable_rpc_cred_fallback;
+	/** unique server id, if 0 will use start time **/
+	uint32_t unique_server_id;
+	/** When enabled, a client (from the same source IP address), is
+	 *  allowed to be connected to a single Ganesha server at a specific
+	 *  point in time.
+	 *  See details in connection_manager.h
+	 */
+	bool enable_connection_manager;
+	/** Timeout for waiting until client is fully disconnected from other
+	 *  Ganesha servers.
+	 */
+	uint32_t connection_manager_timeout_sec;
+#ifdef _USE_NFS_RDMA
+	/** NFS Versions to supported for NFSoRDMA.
+	    Defaults to NFS_RDMA_ENABLE_BY_DEFAULT and is settable with
+	    NFS_RDMA_Protocol_Versions
+	    (as a comma-separated list of 3,4.0,4.1,4.2) */
+	unsigned int nfs_rdma_supported_protocol_versions;
+#endif
 } nfs_core_parameter_t;
 
 /** @} */
@@ -529,12 +579,12 @@ typedef struct nfs_core_param {
 /**
  * @brief NFSv4 minor versions
  */
-#define NFSV4_MINOR_VERSION_ZERO	(1 << 0)
-#define NFSV4_MINOR_VERSION_ONE	(1 << 1)
-#define NFSV4_MINOR_VERSION_TWO	(1 << 2)
-#define NFSV4_MINOR_VERSION_ALL	(NFSV4_MINOR_VERSION_ZERO | \
-					 NFSV4_MINOR_VERSION_ONE | \
-					 NFSV4_MINOR_VERSION_TWO)
+#define NFSV4_MINOR_VERSION_ZERO (1 << 0)
+#define NFSV4_MINOR_VERSION_ONE (1 << 1)
+#define NFSV4_MINOR_VERSION_TWO (1 << 2)
+#define NFSV4_MINOR_VERSION_ALL                               \
+	(NFSV4_MINOR_VERSION_ZERO | NFSV4_MINOR_VERSION_ONE | \
+	 NFSV4_MINOR_VERSION_TWO)
 
 typedef struct nfs_version4_parameter {
 	/** Whether to disable the NFSv4 grace period.  Defaults to
@@ -553,8 +603,8 @@ typedef struct nfs_version4_parameter {
 	/** The eir_server_owner. Defaults to NULL and is settable
 	    with server_owner. */
 	char *server_owner;
-	/** Domain to use if we aren't using the nfsidmap.  Defaults
-	    to DOMAINNAME_DEFAULT and is set with DomainName. */
+	/** This config param is deprecated. Use `domainname` defined
+	    in `directory_services_param` struct. */
 	char *domainname;
 	/** Path to the idmap configuration file.  Defaults to
 	    IDMAPCONF_DEFAULT, settable with IdMapConf */
@@ -599,8 +649,54 @@ typedef struct nfs_version4_parameter {
 	bool enforce_utf8_vld;
 	/** Max number of Client IDs allowed on the system */
 	uint32_t max_client_ids;
+	/** Max number of files that could be opened by a client. Beyond this
+	 * limit, client gets denied if it tries to open too many files.
+	 */
+	uint32_t max_open_states_per_client;
+	/** Threshold for number of expired clients to reach,
+	 *  in order to start with the actual expiration
+	 */
+	uint32_t expired_client_threshold;
+	/** Number of open files that an unresponsive client could have,
+	 * beyond which Ganesha need not keep them in memory or expire it.
+	 */
+	uint32_t max_open_files_for_expired_client;
+	/** Max amount of time till which to keep the unresponsive client
+	 * in memory, beyond which Ganesha would start reaping & expire it off.
+	 */
+	uint64_t max_alive_time_for_expired_client;
+
 } nfs_version4_parameter_t;
 
+typedef struct directory_services_param {
+	/** Domain to use if we aren't using the nfsidmap. Defaults
+	    to NULL and is set with DomainName. */
+	char *domainname;
+	/** Whether to enable idmapping. Defaults to true. */
+	bool idmapping_active;
+	/** Cache validity in seconds for idmapped user entries */
+	time_t idmapped_user_time_validity;
+	/** Cache validity in seconds for idmapped group entries */
+	time_t idmapped_group_time_validity;
+	/** Max number of cached idmapped users */
+	uint32_t cache_users_max_count;
+	/** Max number of cached idmapped groups */
+	uint32_t cache_groups_max_count;
+	/** Max number of cached user-groups entries */
+	uint32_t cache_user_groups_max_count;
+	/** Cache validity in seconds for negative entries */
+	time_t negative_cache_time_validity;
+	/** Max number of negative cache users (that failed idmapping) */
+	uint32_t negative_cache_users_max_count;
+	/** Max number of negative cache groups (that failed idmapping) */
+	uint32_t negative_cache_groups_max_count;
+	/** Cache reaping interval in seconds for idmapped users and groups */
+	time_t cache_reaping_interval;
+	/** Whether to use fully qualified names for idmapping with pw-utils.
+	    Defaults to false. */
+	bool pwutils_use_fully_qualified_names;
+} directory_services_param_t;
+
 /** @} */
 
 typedef struct nfs_param {
@@ -612,11 +708,14 @@ typedef struct nfs_param {
 #ifdef _HAVE_GSSAPI
 	/** kerberos configuration.  Settable in the NFS_KRB5 stanza. */
 	nfs_krb5_parameter_t krb5_param;
-#endif				/* _HAVE_GSSAPI */
+#endif /* _HAVE_GSSAPI */
+	/** Directory_services configuration, settable in the
+	    DIRECTORY_SERVICES stanza. */
+	directory_services_param_t directory_services_param;
 } nfs_parameter_t;
 
 extern nfs_parameter_t nfs_param;
 
-#endif				/* GSH_CONFIG_H */
+#endif /* GSH_CONFIG_H */
 
 /** @} */
